*********************************************************************************
																				*
* Replication do file for cleaning the                                  		*
* CaseId and Justice centered Supreme Court database							*
																				*  
* Brett Ford and Vanessa Baird 							    *			 
* with Daphne Dozier and Allie Palmer                                                                  *
* Software used: Stata/SE 17.0                                                  *
*********************************************************************************

global sc_Orig  	"/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/DataOrig/"
global sc_Working  	"/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/DataWorking/"
global sc_TempDo  	"/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/DataTemp/TempDo/"
global sc_DataTemp  	"/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/DataTemp/"

* This directory contains original cleaned data sets: after it is posted here, its file name contains the date and is not changed    

global sc_PostedClean "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Data/Clean/"

* This directory is where my downloads go
global download_folder "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/OutlookDownloads/"


********************************************************************************
********************************************************************************
********************************************************************************
* Justice data  
********************************************************************************
********************************************************************************
********************************************************************************




* Original data downloaded Jan 31 2023
http://scdb.wustl.edu/data.php

use "${download_folder}SCDB_2022_01_justiceCentered_Citation.dta"

save "${sc_Orig}SCDB_2022_Justice_orig.dta", replace


save "${sc_DataTemp}2023_SCDB_Baird_Justice2021.dta", replace
save "${sc_Working}2023_SCDB_Baird_Justice2021Working.dta", replace



********************************************************************************
* svalue = codes for eleven policy areas 
********************************************************************************

* First, I handle some of the messy issues where svalue is missing or the issue is attorney's fees (if someone is suing for attorney fees for a first Amendment issue, I put them in the first amendment, etc.


gen svalue = 0 

label define svalue ///
1 "Discrimination"  /// 
2 "Free Speech"  /// 
3 "Privacy"  /// 
4 "Criminal Rights"  /// 
5 "Labor" /// 
6 "Environment" /// 
7 "Econreg" /// 
8 "Taxation" /// 
9 "Due Process and Government Liability"  /// 
10 "Judicial Power"  /// 
11 "Federalism"

label var svalue "Policy Area"
label values svalue svalue

********************************************************************************
********************************************************************************
********************************************************************************

** Attorney code translation 

********************************************************************************
********************************************************************************
********************************************************************************

* give all civil rights attorneys fees, initially to rights - svalue == 1
* then, if they belong somewhere else, this can follow

replace svalue =  2 if issue == 60020 | (lawSupp == 200 | lawSupp == 201)
replace svalue = 1 if  issue == 60010

* if an attorney is suing someone on the basis of the 14th Amendment, this is listed under discrimination

replace svalue = 1 if issueArea ==6 & lawSupp == 230 &  (petitioner == 111 | respondent ==111)
replace svalue = 1 if issueArea ==6 & lawSupp == 231 &  (petitioner == 111 | respondent ==111)

* All else is within issue = 60010 

* These are environmental issues or parties suing for attorney's fees 
* Notice the rule is any of these laws or when one of the parties is an environmental group 
replace svalue =5 if issueArea == 6 & (lawSupp == 304 |lawSupp == 338)
replace svalue =5 if issueArea == 6 & (petitioner == 222 | respondent == 222)

* Econ regulation attorneys fees codes 
* lawSupp = 307= Bankrupcy
* lawSupp = 310 = Clayton
* lawSupp = 353 = Miller
* lawSupp = 365 = Securities a
* lawSupp = 600 for infrequent litigant

replace svalue = 7 if (issueArea == 6) & (( lawSupp == 365 | lawSupp == 310 | lawSupp == 353 | lawSupp == 307 ))
	
* Either petitioner or respondent is consumer or creditor 
replace svalue = 7  if ((issueArea == 6 &  lawSupp ==600) & (petitioner == 134 | respondent == 134 )) 	
replace svalue = 7 if ((issueArea == 6 &  lawSupp ==600) & (petitioner == 135 | respondent == 135 )) 	

* 172 is inventor 173 is investor 
replace svalue = 7 if ((issueArea == 6 &  lawSupp ==.) & (petitioner == 173 | respondent == 173 )) 	

* This is when an inventor sues someone who is not the patent office, which is petitioner or respondent == 394; that is government liability 
replace svalue = 7 if ((issueArea == 6 &  lawSupp ==600) &  (petitioner ~= 394 & respondent ~= 394  ) & (petitioner == 172 | respondent == 172 )) 	

* lawSupp = 345 = InternalRev
replace svalue = 8 if issueArea == 6 & (lawSupp == 345)

* This is a veteran suing for attorney's fees ; putting it in government liability
* also if an inventor is suing the patent office, this goes in goverrnment liability
* also if a veteran or social security person sues for attorney fees, this goes in goverrnment liability

* social security  if petitioner == 406  
* veteran if petitioner == 414

replace svalue = 9 if ((issue == 60010)  & (petitioner == 414 | respondent == 414  ))
replace svalue = 9 if ((issue == 60010) & ( (petitioner == 172 | respondent == 172  ) & (petitioner == 394 | respondent == 394  ) ) )
replace svalue = 9 if ((issue == 60010) & ( (petitioner == 406 | respondent == 406  ) | (petitioner == 414 | respondent == 414  ) ) )

* if the law is regarding Supreme Court rules and the attorney is suing, it is against a state, a court, or another government agency
replace svalue = 9 if issueArea ==6 & lawSupp == 403 &  (petitioner == 111 | respondent ==111)
* if the lawSupp is missing, and an attorney is suing this is also against a government agency or court or state 
replace svalue = 9 if issueArea ==6 & lawSupp == . &  (petitioner == 111 | respondent ==111)

tab svalue 

********************************************************************************
********************************************************************************
********************************************************************************
* Some issues are missing so I am putting them in the best possible place

* This may need to be updated, especially for when lawSupp is 600 or missing 

********************************************************************************
********************************************************************************
********************************************************************************

* This is for diagnosing missing issues 
* I am generally using information about the law in question or 
* information about who the parties are to make these evaluations.

* Then, if something is inconsistent 
* with the general principles of the assignment of policy codes 
* and the actual issue codes, doing this second ensures that the general principles change the problems. 

gen issue_miss =0
replace issue_miss =1 if issue == . 

* Putting checks and balances into the due process and government liability

* government liability and due process 
* us being sued if peitioner or respondent == 27
replace  svalue = 9 if (issue == . & svalue ==0) & (petitioner == 27 | respondent == 27) 

* in these, a non-citizen is suing government 
replace  svalue = 9 if (issue == . & svalue ==0) & (petitioner == 368 | respondent == 368) 
replace  svalue = 4 if (issue == . & svalue ==0) & (petitioner == 100 | respondent == 100)

* if a railroad is suing or being sued, this is economic
replace  svalue = 7  if (issue == . & svalue ==0) & (petitioner == 231 | respondent == 231)                       

* this case is about suing in a corporate about att-client privilege in anti-trust case , so econ reg 
replace  svalue = 7  if  petitioner ==16 & respondent ==  220 
* if the Fed trade commission is one of the parties, we will call it economic regulation
replace  svalue = 7   if  petitioner ==357 | respondent ==  357 

* If a state is suing or being sued and this is heard at the SC, then this is federalism
* Do this before below as it would include issues related to economics 
replace  svalue = 11 if (issue == . & svalue ==0) & (petitioner == 28 | respondent == 28) 
replace  svalue = 11 if (issue == . & svalue ==0) & (petitioner == 5 | respondent == 5) 

* if INS, then due proc and gov liability 
replace  svalue = 9 if issue == . & petitioner == 368 | respondent ==368 

* This case is about Tony curtis suing his book publisher
replace  svalue = 7  if issue == . & petitioner == 117 & respondent ==28 

* drug company  
replace  svalue = 7 if issue == . & petitioner == 142 & respondent ==143 

* Do this after above in case a gov entity is being sued: this is a business party 
replace  svalue = 7 if issue == . & petitioner == 122 | respondent ==122 

* this is an airline 
replace  svalue = 7 if issue == . & petitioner == 104 | respondent ==104 

* investment company=119	  insurance company, surety =171
replace  svalue = 7 if issue == . & petitioner == 171 | respondent ==171 
replace  svalue = 7  if issue == . & petitioner == 119 | respondent ==119 

*  debtor 138	  bank  113 
replace  svalue = 7 if issue == . & petitioner == 138 | respondent ==138 
replace  svalue = 7 if issue == . & petitioner == 113 | respondent ==113 

* manufacturer=184	 distributor =141
replace  svalue = 7 if issue == . & petitioner == 184 | respondent ==141 
replace  svalue = 7 if issue == . & petitioner == 141 | respondent ==184 

* taxes : party is the IRS
replace  svalue = 8  if issue == . & petitioner == 369 | respondent ==369 

	   
* If a labor org is one of the parties, then this is labor 

replace   svalue = 6  if (issue == . & svalue ==0) & (petitioner == 249 | respondent == 249) 

* if an employee is pet or repsondent, it is labor 
replace   svalue = 6 if (issue == . & svalue ==0) & (petitioner == 145| respondent == 145) 

* this party is an employer,  labor 
replace   svalue = 6 if (issue == . & svalue ==0) & (petitioner == 151 | respondent == 151) 

* A state v us or vice versa is federalism

replace   svalue = 11 if (issue == . & svalue ==0) & (petitioner == 28 & respondent == 27) 
replace   svalue = 11 if (issue == . & svalue ==0) & (petitioner == 27 & respondent == 28) 


replace   svalue = 1 if (issueArea == 2 & (issue ~= 20400 & issue ~= 20060 & issue ~= 20100 & issue ~= 20140  ///
& issue ~= 20180 & issue ~= 20190  ///
& issue ~= 20320 & issue ~= 20330 & issue ~= 20340 & issue ~= 20350 & issue ~= 20360  ///
& issue ~= 20370 & issue ~= 20380 & issue ~= 20390 )) 

* This case is civil rights because it is about suing Trump's attempt to exclude noncitizens from census
replace svalue =1  if  petitioner ==207 & respondent ==  23 

********************************************************************************
********************************************************************************
********************************************************************************
* Translation of Spaeth codes into codes used for Baird (2004, 2007)
********************************************************************************
********************************************************************************
********************************************************************************


* First amendment : note that some of the attorneys codes were moved to Discrimination as they are civil rights; 1 case is changed 
replace svalue = 2 if issueArea == 3 | issue == 60020 

* Privacy 
replace svalue = 3 if issue > 50000 & issue < 60000 

* Criminal 
replace svalue = 4 if (issue > 10000 & issue <= 20000) | (issue == 40040)

* Workers and poverty law: consumers, unions, employment discrimination, indigen t rights 
replace svalue = 5 if issueArea == 7 | issue == 80090 | issue == 80170 ///
| issue == 20060 | issue == 20100 | issue == 20140 ///
| issue== 20180 | issue == 20190 ///
| issue == 20320 | issue == 20330 | issue == 20340 | issue == 20350 | issue == 20360 | issue == 20370 | issue == 20380 | issue == 20390

* Environment 
*80130	natural resources - environmental protection (cf. national supremacy: natural resources, national supremacy: pollution)
*80250	federal and some few state regulation of transportation regulation: pipeline (cf. federal public utilities regulation: gas pipeline)
*80270	federal and some few state regulation of public utilities regulation: electric power
*80280	federal and some few state regulation of public utilities regulation: nuclear power
*80290	federal and some few state regulation of public utilities regulation: oil producer
*80300	federal and some few state regulation of public utilities regulation: gas producer
*80310	federal and some few state regulation of public utilities regulation: gas pipeline (cf. federal transportation regulation: pipeline)
*100080	national supremacy: natural resources (cf. natural resources - environmental protection)	
*100090	national supremacy: pollution, air or water (cf. natural resources - environmental protection)	
*100100	national supremacy: public utilities (cf. federal public utilities regulation)	

replace svalue =  6 if issue ==  80130 | issue ==  80250  | issue ==  80270 | issue ==  80280 | issue == 80290 ///
| issue == 80300 | issue == 80310 | issue == 100080 | issue == 100090 | issue == 100100 

* Economic regulation 
replace svalue = 7 if (issueArea == 8 & ( issue ~= 80090 & issue ~= 80060 & issue ~= 80100 & issue ~= 80130 & issue ~= 80250 & issue ~= 80270 & issue ~= 80280 & issue ~= 80290 ///
& issue ~= 80300 & issue ~= 80310 & issue ~= 80310 & issue ~= 80310 & issue ~= 80310 & issue ~= 80310 & issue ~= 80310 ) )

* Taxation 
*80100	state or local government tax
replace svalue = 8 if issueArea == 12 | issue == 80100 | issue == 100060 | issue == 100110 

** Non criminal due process, government power and liability 
replace svalue =  9 if (issueArea == 4 & issue ~= 40040) | issue == 80060 | issue == 20400 | issue == 130010 | issue == 130015 

** Judicial Power 
replace  svalue =  10 if issueArea == 9 

** Federalism 
replace  svalue =  11 if ((issueArea == 10) & (issue ~= 100080 & issue ~= 100060 & issue ~= 100090 & issue ~= 100100 & issue ~= 100110)) | (issueArea == 11) 


********************************************************************************
********************************************************************************
********************************************************************************
* svalue_gen = codes for five more general policy areas 
********************************************************************************
********************************************************************************
********************************************************************************

* vars

gen svalue_gen = 1 if svalue ==1
replace svalue_gen = 2 if svalue ==2 | svalue ==3
replace svalue_gen = 3 if svalue ==4
replace svalue_gen = 4 if svalue > 4 & svalue < 9
replace svalue_gen = 5 if svalue > 8

label define svalue_gen 1 "Discrimination" 2 "Speech and privacy" 3 "Criminal" 4 "Economic and taxes" 5 "Power"
label values svalue_gen svalue_gen

gen disc_gen = 0 
gen liberties_gen = 0 
gen crim_gen = 0 
gen econ_gen = 0 
gen powers_gen = 0 

replace disc_gen = 1 if svalue ==1
replace liberties_gen = 1 if svalue ==2 | svalue ==3
replace crim_gen = 1 if svalue ==4
replace econ_gen = 1 if svalue > 4 & svalue < 9
replace powers_gen = 1 if svalue > 8


********************************************************************************
********************************************************************************
********************************************************************************
* Case outcomes 
********************************************************************************
********************************************************************************
********************************************************************************




********************************************************************************
* how split the outcome is: these are case attributes
********************************************************************************


* n54 n56 n63 n78 n81 n72 unam 


gen n54= 0 
gen n56= 0 
gen n63= 0 
gen n78= 0 
gen n81= 0 
gen n72= 0 
gen unam= 0 

replace n54 = 1 if (vote_coalition == 33 | vote_coalition == 43 | vote_coalition == 44 | vote_coalition == 54) 
label var n54 "Split of 0,1: 5-4, 3-3, 4-3, 4-4"

replace n63 = 1 if (vote_coalition == 42 | vote_coalition == 52 | vote_coalition == 53 | vote_coalition == 63) 
label var n63 "Split of 2,3: 6-3, 4-2, 5-2, 5-3, but NOT 4-1"

replace n72 = 1 if (vote_coalition == 72 | vote_coalition == 62)
label var n72 "Split of 4,5: 7-2, 6-2, but NOT 5-1"

replace n81 = 1 if (vote_coalition == 81 | vote_coalition == 41 | vote_coalition == 51 | vote_coalition == 61 | vote_coalition == 71 ) 

label var n81 "Split with lone dissent: 8-1, 4-1 5-1, 6-1, 7-1" 

replace unam = 1 if (vote_coalition == 50 | vote_coalition == 60 | vote_coalition == 70 | vote_coalition == 80 | vote_coalition == 90) 
label var unam "Unanimous vote outcome"  

replace n56 = 1 if n54 == 1 | n63 == 1 

label var n56 "Contentious: 3 or 4 dissenting, including 4-2 and 5-2"

replace n78 = 1 if n72 == 1 | n81 == 1 

label var n78  "Not as contentious: 1 or 2 dissenting" 


gen  vote_coalition =  (majVotes * 10) + minVotes
label var vote_coalition "Coalition size: maj-min == majmin" 

gen vote_contentious = 1 if unam ==1
replace vote_contentious = 2 if n81 ==1
replace vote_contentious = 3 if n72 ==1
replace vote_contentious = 4 if n63 ==1
replace vote_contentious = 5 if n54 ==1

label define vote_contentious 1 "1.Unanimous" 2 "2. 1 dissent" 3 "2 dissents" 4 "3 dissents" 5 "4 dissents" 
label values vote_contentious vote_contentious


gen lib = 0 if decisionDirection == 1
replace lib = 1 if decisionDirection == 2
replace lib = .5 if decisionDirection == 3

label define lib 0 "Conservative" 1 "Liberal"
label values lib lib

gen con = (lib*-1)+1

label define con 1 "Conservative" 0 "Liberal"
label values con con 

gen lib_lct = 0 if lcDispositionDirection == 1
replace lib_lct = 1 if lcDispositionDirection == 2
replace lib_lct = .5 if lcDispositionDirection == 3
label values lib_lct lib

gen con_lct = (lib_lct*-1)+1

label values con_lct con 





********************************************************************************
* Vote outcomes and case liberalism
********************************************************************************




********************************************************************************
********************************************************************************
********************************************************************************
* Justices' votes 
********************************************************************************
********************************************************************************
********************************************************************************

* justice_lib vote_majority vote_majoritylib vote_majoritycon vote_coalition lib con lib_lct con_lct 

gen justice_lib = 0 if direction == 1
replace justice_lib = 1 if direction == 2

label define justice_lib 0 "Conservative" 1 "Liberal"

label values justice_lib justice_lib

gen vote_majority = 0
replace vote_majority = 1 if vote == 1

gen vote_majoritylib = 0
replace vote_majoritylib = 1 if vote_majority ==1 & justice_lib==1

gen vote_majoritycon = 0
replace vote_majoritycon = 1 if vote_majority ==1 & justice_lib==0




********************************************************************************
* concurring and dissenting 
********************************************************************************

* special_concur reg_concur any_concur 
* disnum disc disl connum conl conc

gen disnum = 0
replace disnum = 1 if vote ==2

gen connum = 0
replace connum = 1 if vote ==3 | vote ==4
label var disnum "Number of dissenting opinions"
label var connum "Number of concurring opinions"




gen disc = 0
gen disl = 0
replace disc = disnum if decisionDirection == 2
replace disl = disnum if decisionDirection == 1 


gen conl = 0
gen conc = 0
replace conc = connum if decisionDirection == 1 
replace conl = connum if decisionDirection == 2 

label var disc "Number of conservative dissents from liberal outcomes"
label var disl "Number of liberal dissents from conservative outcomes"


label var conl "Number of concurrences in liberal outcomes"
label var conc "Number of concurrences from conservative outcomes"

gen special_concur = 0
replace special_concur = 1 if vote == 4

gen reg_concur = 0
replace reg_concur = 1 if vote == 3

gen any_concur = 0
replace any_concur = 1 if vote == 4 | vote ==3


********************************************************************************
********************************************************************************
********************************************************************************
* Opinions: majority, concurring (special and regular), and dissenting 
********************************************************************************
********************************************************************************
********************************************************************************

* majOpin anyopin dissent_opin concur_opin libdissent_opin
* concur_opin libdissent_opin condissent_opin 
* special_concur_opin reg_concur_opin any_concur_opin 
* dissent_opin01 lonely_dissent_cat 
* NoDissent Dissent4 Dissent4Opin Dissent3 Dissent3Opin Dissent2 
* Dissent2Opin Dissent1 Dissent1Opin dissent_opin 


* some notes about how to use specific information about the nature of concurrence and whether they coincide with opinion writing
* The direction of a concurring opinion is complicated. It may be written to push the outcome in a more liberal direction for a conservative outcome
* Such as when a median justice writes a concurrence from a liberal case - that is different from the ideological extremes trying to push for more extreme rationales.
* or it may be written to push the outcome more conservative or more liberal than the outcome.

recode opinion (1=0 "No opinion") (2 = 1 "Opinion") (3=.5) , gen (anyopin)

label var anyopin "Any opinion; .5 = coauthored"

gen special_concur_opin = 0
replace special_concur_opin = 1 if vote == 4 & anyopin >0

gen reg_concur_opin = 0
replace reg_concur_opin = 1 if vote == 3 & anyopin >0

gen any_concur_opin = 0
replace any_concur_opin = 1 if vote == 4 | vote ==3 & anyopin >0

gen concur_opin = 0
replace concur_opin = 1 if (anyopin == 1 & (vote ==3 | vote ==4))
replace concur_opin = .5 if (anyopin == .5 & (vote ==3 | vote ==4))

gen majOpin = anyopin if vote ==1
replace  majOpin = 0 if vote ~=1



gen dissent_opin = 0
replace dissent_opin = 1 if anyopin == 1 & vote ==2 
replace dissent_opin = .5 if anyopin == .5 & vote ==2


label var dissent_opin "Wrote dissenting opinion"
label var concur_opin "Wrote concurring opinion"

gen libdissent_opin = 0
replace libdissent_opin = 1 if anyopin == 1 & vote ==2 & lib ==0
replace libdissent_opin = .5 if anyopin == .5 & vote ==2 & lib ==0

label var libdissent_opin "Liberal dissent from conservative outcome"

gen condissent_opin = 0
replace condissent_opin = 1 if anyopin == 1 & vote ==2 & lib ==1
replace condissent_opin = .5 if anyopin == .5 & vote ==2 & lib ==1

label var condissent_opin "Conservative dissent from liberal outcome"



* Note that this is for Justice data as it connect their personal vote and opinion writing. 

gen lonely_dissent_cat = 0
replace  lonely_dissent_cat = 1 if vote ==2 & vote_contentious == 5 // Dissented with four others 
replace  lonely_dissent_cat = 2 if vote ==2 & anyopin ==1 & vote_contentious == 5 // Dissented with four others and wrote opinion 

replace  lonely_dissent_cat = 3 if vote ==2 & vote_contentious == 4 // Dissented with three others 
replace  lonely_dissent_cat = 4 if vote ==2 & anyopin ==1 & vote_contentious == 4 // Dissented with three others and wrote opinion 

replace  lonely_dissent_cat = 5 if vote ==2 & vote_contentious == 3 // Dissented with two others 
replace  lonely_dissent_cat = 6 if vote ==2 & anyopin ==1 & vote_contentious == 3 // Dissented with two others and wrote opinion 

replace  lonely_dissent_cat = 7 if vote ==2 & vote_contentious == 2 // Dissented alone 
replace  lonely_dissent_cat = 8 if vote ==2 & anyopin ==1 & vote_contentious == 2 // Dissented alone and wrote opinion 

label define lonely_dissent_cat 0 "0.Did not dissent"  /// 
								1 "1.Dissented with four"  /// 
								2 "2.Dissented with four, wrote opinion"  /// 
								3 "3.Dissented with three"  /// 
								4 "4.Dissented with three, wrote opinion"  /// 								
								5 "5.Dissented with two "  /// 								 
								6 "6.Dissented with two, wrote opinion"  /// 								
								7 "7.Dissented alone"  /// 
								8 "8.Dissented alone, wrote opinion" 

label values lonely_dissent_cat lonely_dissent_cat

tab lonely_dissent_cat, gen (lonely_dis_dummy)

rename lonely_dis_dummy1 NoDissent   
rename lonely_dis_dummy2 Dissent4   
rename lonely_dis_dummy3 Dissent4Opin     
rename lonely_dis_dummy4 Dissent3   
rename lonely_dis_dummy5 Dissent3Opin   
rename lonely_dis_dummy6 Dissent2    
rename lonely_dis_dummy7 Dissent2Opin   
rename lonely_dis_dummy8 Dissent1   
rename lonely_dis_dummy9 Dissent1Opin  





********************************************************************************
********************************************************************************
********************************************************************************
* Source variables 
********************************************************************************
********************************************************************************
********************************************************************************

* vars: add circuit spec 

* source_cat_gen source_circ source_district source_state source_circuit_spec


gen source_cat_gen = 1
replace source_cat_gen = 2 if caseSource > 40
replace source_cat_gen = 3 if caseSource > 299

label define source_cat_gen 1 "Federal Circuit" 2 "Federal district court" 3 "State court"


label values  source_cat_gen source_cat_gen
label var source_cat_gen "Court in which case is initially filed"



tab source_cat_gen, gen (source_cat_gen)

rename source_cat_gen1 source_circ
rename source_cat_gen2 source_district
rename source_cat_gen3 source_state



gen source_circuit_spec = 0
replace source_circuit_spec = 1 if caseSource==21
replace source_circuit_spec = 2 if caseSource==22
replace source_circuit_spec = 3 if caseSource==23
replace source_circuit_spec = 4 if caseSource==24
replace source_circuit_spec = 5 if caseSource==25
replace source_circuit_spec = 6 if caseSource==26
replace source_circuit_spec = 7 if caseSource==27
replace source_circuit_spec = 8 if caseSource==28
replace source_circuit_spec = 9 if caseSource==29
replace source_circuit_spec = 10 if caseSource==30
replace source_circuit_spec = 11 if caseSource==31
replace source_circuit_spec = 12 if caseSource==32
replace source_circuit_spec = 13 if caseSource < 20


label define source_circuit_spec 0 "0.Not circuit: state or federal district court"  /// 
								1 "1.First Circuit"  /// 
								2 "2.Second Circuit"  /// 
								3 "3.Third Circuit"  /// 
								4 "4.Fourth Circuit"  /// 
								5 "5.Fifth Circuit"  /// 
								6 "6.Sixth Circuit"  /// 
								7 "7.Seventh Circuit"  /// 
								8 "8.Eighth Circuit"  /// 
								9 "9.Ninth Circuit"  /// 
								10 "10.Tenth Circuit"  /// 
								11 "11.Eleventh Circuit"  /// 
								12 "12.D.C. Circuit"  ///
								13 "13.Other Circuit"  

label values source_circuit_spec source_circuit_spec

tab source_circuit_spec if source_circuit_spec > 0, gen (source_circuit_spec) 

rename source_circuit_spec1 FirstCircuit
rename source_circuit_spec2 SecondCircuit
rename source_circuit_spec3 ThirdCircuit
rename source_circuit_spec4 FourthCircuit
rename source_circuit_spec5 FifthCircuit
rename source_circuit_spec6 SixthCircuit
rename source_circuit_spec7 SeventhCircuit
rename source_circuit_spec8 EighthCircuit
rename source_circuit_spec9 NinthCircuit
rename source_circuit_spec10 TenthCircuit
rename source_circuit_spec11 EleventhCircuit
rename source_circuit_spec12 DCCircuit
rename source_circuit_spec13 OtherCircuit



********************************************************************************
********************************************************************************
********************************************************************************
* The following creates party variables 
********************************************************************************
********************************************************************************
********************************************************************************



generate 	pet_code	=	1 	if	petitioner	 ==	1
replace 	pet_code	=	2 	if	petitioner	 ==	2
replace 	pet_code	=	3 	if	petitioner	 ==	3
replace 	pet_code	=	2 	if	petitioner	 ==	4
replace 	pet_code	=	3 	if	petitioner	 ==	5
replace 	pet_code	=	4 	if	petitioner	 ==	6
replace 	pet_code	=	2 	if	petitioner	 ==	7
replace 	pet_code	=	6 	if	petitioner	 ==	8
replace 	pet_code	=	6 	if	petitioner	 ==	9
replace 	pet_code	=	6 	if	petitioner	 ==	10
replace 	pet_code	=	6 	if	petitioner	 ==	11
replace 	pet_code	=	1 	if	petitioner	 ==	12
replace 	pet_code	=	6 	if	petitioner	 ==	13
replace 	pet_code	=	1 	if	petitioner	 ==	14
replace 	pet_code	=	1 	if	petitioner	 ==	15
replace 	pet_code	=	4 	if	petitioner	 ==	16
replace 	pet_code	=	2 	if	petitioner	 ==	17
replace 	pet_code	=	3 	if	petitioner	 ==	18
replace 	pet_code	=	1 	if	petitioner	 ==	19
replace 	pet_code	=	4 	if	petitioner	 ==	20
replace 	pet_code	=	3 	if	petitioner	 ==	21
replace 	pet_code	=	1 	if	petitioner	 ==	22
replace 	pet_code	=	1 	if	petitioner	 ==	23
replace 	pet_code	=	8 	if	petitioner	 ==	24
replace 	pet_code	=	6 	if	petitioner	 ==	25
replace 	pet_code	=	2 	if	petitioner	 ==	26
replace 	pet_code	=	1 	if	petitioner	 ==	27
replace 	pet_code	=	2 	if	petitioner	 ==	28
replace 	pet_code	=	5 	if	petitioner	 ==	100
replace 	pet_code	=	5 	if	petitioner	 ==	101
replace 	pet_code	=	6 	if	petitioner	 ==	102
replace 	pet_code	=	5 	if	petitioner	 ==	103
replace 	pet_code	=	5 	if	petitioner	 ==	104
replace 	pet_code	=	5 	if	petitioner	 ==	105
replace 	pet_code	=	6 	if	petitioner	 ==	106
replace 	pet_code	=	5 	if	petitioner	 ==	107
replace 	pet_code	=	5 	if	petitioner	 ==	108
replace 	pet_code	=	5 	if	petitioner	 ==	109
replace 	pet_code	=	6 	if	petitioner	 ==	110
replace 	pet_code	=	9 	if	petitioner	 ==	111
replace 	pet_code	=	9 	if	petitioner	 ==	112
replace 	pet_code	=	5 	if	petitioner	 ==	113
replace 	pet_code	=	9 	if	petitioner	 ==	114
replace 	pet_code	=	5 	if	petitioner	 ==	115
replace 	pet_code	=	9 	if	petitioner	 ==	116
replace 	pet_code	=	5 	if	petitioner	 ==	117
replace 	pet_code	=	5 	if	petitioner	 ==	118
replace 	pet_code	=	5 	if	petitioner	 ==	119
replace 	pet_code	=	5 	if	petitioner	 ==	120
replace 	pet_code	=	5 	if	petitioner	 ==	121
replace 	pet_code	=	5 	if	petitioner	 ==	122
replace 	pet_code	=	5 	if	petitioner	 ==	123
replace 	pet_code	=	5 	if	petitioner	 ==	124
replace 	pet_code	=	5 	if	petitioner	 ==	125
replace 	pet_code	=	6 	if	petitioner	 ==	126
replace 	pet_code	=	9 	if	petitioner	 ==	127
replace 	pet_code	=	5 	if	petitioner	 ==	128
replace 	pet_code	=	6 	if	petitioner	 ==	129
replace 	pet_code	=	7 	if	petitioner	 ==	130
replace 	pet_code	=	5 	if	petitioner	 ==	131
replace 	pet_code	=	5 	if	petitioner	 ==	132
replace 	pet_code	=	5 	if	petitioner	 ==	133
replace 	pet_code	=	6 	if	petitioner	 ==	134
replace 	pet_code	=	5 	if	petitioner	 ==	135
replace 	pet_code	=	6 	if	petitioner	 ==	136
replace 	pet_code	=	6 	if	petitioner	 ==	137
replace 	pet_code	=	6 	if	petitioner	 ==	138
replace 	pet_code	=	5 	if	petitioner	 ==	139
replace 	pet_code	=	6 	if	petitioner	 ==	140
replace 	pet_code	=	5 	if	petitioner	 ==	141
replace 	pet_code	=	6 	if	petitioner	 ==	142
replace 	pet_code	=	5 	if	petitioner	 ==	143
replace 	pet_code	=	5 	if	petitioner	 ==	144
replace 	pet_code	=	6 	if	petitioner	 ==	145
replace 	pet_code	=	9 	if	petitioner	 ==	146
replace 	pet_code	=	5 	if	petitioner	 ==	147
replace 	pet_code	=	5 	if	petitioner	 ==	148
replace 	pet_code	=	6 	if	petitioner	 ==	149
replace 	pet_code	=	7 	if	petitioner	 ==	150
replace 	pet_code	=	5 	if	petitioner	 ==	151
replace 	pet_code	=	6 	if	petitioner	 ==	152
replace 	pet_code	=	6 	if	petitioner	 ==	153
replace 	pet_code	=	6 	if	petitioner	 ==	154
replace 	pet_code	=	6 	if	petitioner	 ==	155
replace 	pet_code	=	9 	if	petitioner	 ==	156
replace 	pet_code	=	9 	if	petitioner	 ==	157
replace 	pet_code	=	5 	if	petitioner	 ==	158
replace 	pet_code	=	8 	if	petitioner	 ==	159
replace 	pet_code	=	5 	if	petitioner	 ==	160
replace 	pet_code	=	5 	if	petitioner	 ==	161
replace 	pet_code	=	6 	if	petitioner	 ==	162
replace 	pet_code	=	6 	if	petitioner	 ==	163
replace 	pet_code	=	6 	if	petitioner	 ==	164
replace 	pet_code	=	9 	if	petitioner	 ==	165
replace 	pet_code	=	6 	if	petitioner	 ==	166
replace 	pet_code	=	5 	if	petitioner	 ==	167
replace 	pet_code	=	6 	if	petitioner	 ==	168
replace 	pet_code	=	6 	if	petitioner	 ==	169
replace 	pet_code	=	6 	if	petitioner	 ==	170
replace 	pet_code	=	5 	if	petitioner	 ==	171
replace 	pet_code	=	5 	if	petitioner	 ==	172
replace 	pet_code	=	5 	if	petitioner	 ==	173
replace 	pet_code	=	6 	if	petitioner	 ==	174
replace 	pet_code	=	6 	if	petitioner	 ==	175
replace 	pet_code	=	5 	if	petitioner	 ==	176
replace 	pet_code	=	6 	if	petitioner	 ==	177
replace 	pet_code	=	5 	if	petitioner	 ==	178
replace 	pet_code	=	6 	if	petitioner	 ==	179
replace 	pet_code	=	6 	if	petitioner	 ==	180
replace 	pet_code	=	5 	if	petitioner	 ==	181
replace 	pet_code	=	6 	if	petitioner	 ==	182
replace 	pet_code	=	6 	if	petitioner	 ==	183
replace 	pet_code	=	5 	if	petitioner	 ==	184
replace 	pet_code	=	5 	if	petitioner	 ==	185
replace 	pet_code	=	6 	if	petitioner	 ==	186
replace 	pet_code	=	5 	if	petitioner	 ==	187
replace 	pet_code	=	6 	if	petitioner	 ==	188
replace 	pet_code	=	5 	if	petitioner	 ==	189
replace 	pet_code	=	5 	if	petitioner	 ==	190
replace 	pet_code	=	5 	if	petitioner	 ==	191
replace 	pet_code	=	7 	if	petitioner	 ==	192
replace 	pet_code	=	6 	if	petitioner	 ==	193
replace 	pet_code	=	5 	if	petitioner	 ==	194
replace 	pet_code	=	5 	if	petitioner	 ==	195
replace 	pet_code	=	5 	if	petitioner	 ==	196
replace 	pet_code	=	9 	if	petitioner	 ==	197
replace 	pet_code	=	5 	if	petitioner	 ==	198
replace 	pet_code	=	6 	if	petitioner	 ==	199
replace 	pet_code	=	6 	if	petitioner	 ==	200
replace 	pet_code	=	7 	if	petitioner	 ==	201
replace 	pet_code	=	6 	if	petitioner	 ==	202
replace 	pet_code	=	5 	if	petitioner	 ==	203
replace 	pet_code	=	6 	if	petitioner	 ==	204
replace 	pet_code	=	5 	if	petitioner	 ==	205
replace 	pet_code	=	5 	if	petitioner	 ==	206
replace 	pet_code	=	7 	if	petitioner	 ==	207
replace 	pet_code	=	6 	if	petitioner	 ==	208
replace 	pet_code	=	5 	if	petitioner	 ==	209
replace 	pet_code	=	5 	if	petitioner	 ==	210
replace 	pet_code	=	7 	if	petitioner	 ==	211
replace 	pet_code	=	6 	if	petitioner	 ==	212
replace 	pet_code	=	6 	if	petitioner	 ==	213
replace 	pet_code	=	6 	if	petitioner	 ==	214
replace 	pet_code	=	6 	if	petitioner	 ==	215
replace 	pet_code	=	5 	if	petitioner	 ==	216
replace 	pet_code	=	6 	if	petitioner	 ==	217
replace 	pet_code	=	6 	if	petitioner	 ==	218
replace 	pet_code	=	5 	if	petitioner	 ==	219
replace 	pet_code	=	5 	if	petitioner	 ==	220
replace 	pet_code	=	5 	if	petitioner	 ==	221
replace 	pet_code	=	6 	if	petitioner	 ==	222
replace 	pet_code	=	6 	if	petitioner	 ==	223
replace 	pet_code	=	6 	if	petitioner	 ==	224
replace 	pet_code	=	5 	if	petitioner	 ==	225
replace 	pet_code	=	6 	if	petitioner	 ==	226
replace 	pet_code	=	6 	if	petitioner	 ==	227
replace 	pet_code	=	5 	if	petitioner	 ==	228
replace 	pet_code	=	6 	if	petitioner	 ==	229
replace 	pet_code	=	6 	if	petitioner	 ==	230
replace 	pet_code	=	5 	if	petitioner	 ==	231
replace 	pet_code	=	7 	if	petitioner	 ==	232
replace 	pet_code	=	5 	if	petitioner	 ==	233
replace 	pet_code	=	5 	if	petitioner	 ==	234
replace 	pet_code	=	5 	if	petitioner	 ==	235
replace 	pet_code	=	6 	if	petitioner	 ==	236
replace 	pet_code	=	5 	if	petitioner	 ==	237
replace 	pet_code	=	5 	if	petitioner	 ==	238
replace 	pet_code	=	6 	if	petitioner	 ==	239
replace 	pet_code	=	6 	if	petitioner	 ==	240
replace 	pet_code	=	6 	if	petitioner	 ==	241
replace 	pet_code	=	5 	if	petitioner	 ==	242
replace 	pet_code	=	5 	if	petitioner	 ==	243
replace 	pet_code	=	6 	if	petitioner	 ==	244
replace 	pet_code	=	5 	if	petitioner	 ==	245
replace 	pet_code	=	5 	if	petitioner	 ==	246
replace 	pet_code	=	6 	if	petitioner	 ==	247
replace 	pet_code	=	6 	if	petitioner	 ==	248
replace 	pet_code	=	7 	if	petitioner	 ==	249
replace 	pet_code	=	6 	if	petitioner	 ==	250
replace 	pet_code	=	6 	if	petitioner	 ==	251
replace 	pet_code	=	5 	if	petitioner	 ==	252
replace 	pet_code	=	6 	if	petitioner	 ==	253
replace 	pet_code	=	6 	if	petitioner	 ==	254
replace 	pet_code	=	6 	if	petitioner	 ==	255
replace 	pet_code	=	6 	if	petitioner	 ==	256
replace 	pet_code	=	5 	if	petitioner	 ==	257
replace 	pet_code	=	1 	if	petitioner	 ==	258
replace 	pet_code	=	5 	if	petitioner	 ==	259
replace 	pet_code	=	6 	if	petitioner	 ==	260
replace 	pet_code	=	1 	if	petitioner	 ==	301
replace 	pet_code	=	1 	if	petitioner	 ==	302
replace 	pet_code	=	1 	if	petitioner	 ==	303
replace 	pet_code	=	1 	if	petitioner	 ==	304
replace 	pet_code	=	1 	if	petitioner	 ==	305
replace 	pet_code	=	1 	if	petitioner	 ==	306
replace 	pet_code	=	1 	if	petitioner	 ==	307
replace 	pet_code	=	1 	if	petitioner	 ==	308
replace 	pet_code	=	1 	if	petitioner	 ==	310
replace 	pet_code	=	1 	if	petitioner	 ==	311
replace 	pet_code	=	1 	if	petitioner	 ==	312
replace 	pet_code	=	1 	if	petitioner	 ==	313
replace 	pet_code	=	1 	if	petitioner	 ==	314
replace 	pet_code	=	1 	if	petitioner	 ==	315
replace 	pet_code	=	1 	if	petitioner	 ==	316
replace 	pet_code	=	1 	if	petitioner	 ==	317
replace 	pet_code	=	1 	if	petitioner	 ==	318
replace 	pet_code	=	1 	if	petitioner	 ==	319
replace 	pet_code	=	1 	if	petitioner	 ==	320
replace 	pet_code	=	1 	if	petitioner	 ==	321
replace 	pet_code	=	1 	if	petitioner	 ==	322
replace 	pet_code	=	1 	if	petitioner	 ==	323
replace 	pet_code	=	1 	if	petitioner	 ==	324
replace 	pet_code	=	1 	if	petitioner	 ==	325
replace 	pet_code	=	1 	if	petitioner	 ==	326
replace 	pet_code	=	1 	if	petitioner	 ==	327
replace 	pet_code	=	1 	if	petitioner	 ==	328
replace 	pet_code	=	1 	if	petitioner	 ==	329
replace 	pet_code	=	1 	if	petitioner	 ==	330
replace 	pet_code	=	1 	if	petitioner	 ==	331
replace 	pet_code	=	1 	if	petitioner	 ==	332
replace 	pet_code	=	1 	if	petitioner	 ==	333
replace 	pet_code	=	1 	if	petitioner	 ==	334
replace 	pet_code	=	1 	if	petitioner	 ==	335
replace 	pet_code	=	1 	if	petitioner	 ==	336
replace 	pet_code	=	1 	if	petitioner	 ==	337
replace 	pet_code	=	1 	if	petitioner	 ==	338
replace 	pet_code	=	1 	if	petitioner	 ==	339
replace 	pet_code	=	1 	if	petitioner	 ==	340
replace 	pet_code	=	1 	if	petitioner	 ==	341
replace 	pet_code	=	1 	if	petitioner	 ==	342
replace 	pet_code	=	1 	if	petitioner	 ==	343
replace 	pet_code	=	1 	if	petitioner	 ==	344
replace 	pet_code	=	1 	if	petitioner	 ==	345
replace 	pet_code	=	1 	if	petitioner	 ==	346
replace 	pet_code	=	1 	if	petitioner	 ==	347
replace 	pet_code	=	1 	if	petitioner	 ==	348
replace 	pet_code	=	1 	if	petitioner	 ==	349
replace 	pet_code	=	1 	if	petitioner	 ==	350
replace 	pet_code	=	1 	if	petitioner	 ==	351
replace 	pet_code	=	1 	if	petitioner	 ==	352
replace 	pet_code	=	1 	if	petitioner	 ==	353
replace 	pet_code	=	1 	if	petitioner	 ==	354
replace 	pet_code	=	1 	if	petitioner	 ==	355
replace 	pet_code	=	1 	if	petitioner	 ==	356
replace 	pet_code	=	1 	if	petitioner	 ==	357
replace 	pet_code	=	1 	if	petitioner	 ==	358
replace 	pet_code	=	1 	if	petitioner	 ==	359
replace 	pet_code	=	1 	if	petitioner	 ==	360
replace 	pet_code	=	1 	if	petitioner	 ==	361
replace 	pet_code	=	1 	if	petitioner	 ==	362
replace 	pet_code	=	1 	if	petitioner	 ==	363
replace 	pet_code	=	1 	if	petitioner	 ==	364
replace 	pet_code	=	1 	if	petitioner	 ==	366
replace 	pet_code	=	1 	if	petitioner	 ==	367
replace 	pet_code	=	1 	if	petitioner	 ==	368
replace 	pet_code	=	1 	if	petitioner	 ==	369
replace 	pet_code	=	1 	if	petitioner	 ==	370
replace 	pet_code	=	1 	if	petitioner	 ==	371
replace 	pet_code	=	1 	if	petitioner	 ==	372
replace 	pet_code	=	1 	if	petitioner	 ==	373
replace 	pet_code	=	1 	if	petitioner	 ==	374
replace 	pet_code	=	1 	if	petitioner	 ==	375
replace 	pet_code	=	1 	if	petitioner	 ==	376
replace 	pet_code	=	1 	if	petitioner	 ==	377
replace 	pet_code	=	1 	if	petitioner	 ==	378
replace 	pet_code	=	1 	if	petitioner	 ==	379
replace 	pet_code	=	1 	if	petitioner	 ==	380
replace 	pet_code	=	1 	if	petitioner	 ==	381
replace 	pet_code	=	1 	if	petitioner	 ==	382
replace 	pet_code	=	1 	if	petitioner	 ==	383
replace 	pet_code	=	1 	if	petitioner	 ==	384
replace 	pet_code	=	1 	if	petitioner	 ==	385
replace 	pet_code	=	1 	if	petitioner	 ==	386
replace 	pet_code	=	1 	if	petitioner	 ==	387
replace 	pet_code	=	1 	if	petitioner	 ==	388
replace 	pet_code	=	1 	if	petitioner	 ==	389
replace 	pet_code	=	1 	if	petitioner	 ==	390
replace 	pet_code	=	1 	if	petitioner	 ==	391
replace 	pet_code	=	1 	if	petitioner	 ==	392
replace 	pet_code	=	1 	if	petitioner	 ==	393
replace 	pet_code	=	1 	if	petitioner	 ==	394
replace 	pet_code	=	1 	if	petitioner	 ==	395
replace 	pet_code	=	1 	if	petitioner	 ==	396
replace 	pet_code	=	1 	if	petitioner	 ==	397
replace 	pet_code	=	1 	if	petitioner	 ==	398
replace 	pet_code	=	1 	if	petitioner	 ==	399
replace 	pet_code	=	1 	if	petitioner	 ==	400
replace 	pet_code	=	1 	if	petitioner	 ==	401
replace 	pet_code	=	1 	if	petitioner	 ==	402
replace 	pet_code	=	1 	if	petitioner	 ==	403
replace 	pet_code	=	1 	if	petitioner	 ==	404
replace 	pet_code	=	1 	if	petitioner	 ==	405
replace 	pet_code	=	1 	if	petitioner	 ==	406
replace 	pet_code	=	1 	if	petitioner	 ==	407
replace 	pet_code	=	1 	if	petitioner	 ==	408
replace 	pet_code	=	1 	if	petitioner	 ==	409
replace 	pet_code	=	1 	if	petitioner	 ==	410
replace 	pet_code	=	1 	if	petitioner	 ==	411
replace 	pet_code	=	1 	if	petitioner	 ==	412
replace 	pet_code	=	1 	if	petitioner	 ==	413
replace 	pet_code	=	1 	if	petitioner	 ==	414
replace 	pet_code	=	1 	if	petitioner	 ==	415
replace 	pet_code	=	1 	if	petitioner	 ==	416
replace 	pet_code	=	1 	if	petitioner	 ==	417
replace 	pet_code	=	1 	if	petitioner	 ==	418
replace 	pet_code	=	1 	if	petitioner	 ==	419
replace 	pet_code	=	1 	if	petitioner	 ==	420
replace 	pet_code	=	1 	if	petitioner	 ==	421
replace 	pet_code	=	8 	if	petitioner	 ==	600



generate 	res_code	=	1 	if	respondent	 ==	1
replace 	res_code	=	2 	if	respondent	 ==	2
replace 	res_code	=	3 	if	respondent	 ==	3
replace 	res_code	=	2 	if	respondent	 ==	4
replace 	res_code	=	3 	if	respondent	 ==	5
replace 	res_code	=	4 	if	respondent	 ==	6
replace 	res_code	=	2 	if	respondent	 ==	7
replace 	res_code	=	6 	if	respondent	 ==	8
replace 	res_code	=	6 	if	respondent	 ==	9
replace 	res_code	=	6 	if	respondent	 ==	10
replace 	res_code	=	6 	if	respondent	 ==	11
replace 	res_code	=	1 	if	respondent	 ==	12
replace 	res_code	=	6 	if	respondent	 ==	13
replace 	res_code	=	1 	if	respondent	 ==	14
replace 	res_code	=	1 	if	respondent	 ==	15
replace 	res_code	=	4 	if	respondent	 ==	16
replace 	res_code	=	2 	if	respondent	 ==	17
replace 	res_code	=	3 	if	respondent	 ==	18
replace 	res_code	=	1 	if	respondent	 ==	19
replace 	res_code	=	4 	if	respondent	 ==	20
replace 	res_code	=	3 	if	respondent	 ==	21
replace 	res_code	=	1 	if	respondent	 ==	22
replace 	res_code	=	1 	if	respondent	 ==	23
replace 	res_code	=	8 	if	respondent	 ==	24
replace 	res_code	=	6 	if	respondent	 ==	25
replace 	res_code	=	2 	if	respondent	 ==	26
replace 	res_code	=	1 	if	respondent	 ==	27
replace 	res_code	=	2 	if	respondent	 ==	28
replace 	res_code	=	5 	if	respondent	 ==	100
replace 	res_code	=	5 	if	respondent	 ==	101
replace 	res_code	=	6 	if	respondent	 ==	102
replace 	res_code	=	5 	if	respondent	 ==	103
replace 	res_code	=	5 	if	respondent	 ==	104
replace 	res_code	=	5 	if	respondent	 ==	105
replace 	res_code	=	6 	if	respondent	 ==	106
replace 	res_code	=	5 	if	respondent	 ==	107
replace 	res_code	=	5 	if	respondent	 ==	108
replace 	res_code	=	5 	if	respondent	 ==	109
replace 	res_code	=	6 	if	respondent	 ==	110
replace 	res_code	=	9 	if	respondent	 ==	111
replace 	res_code	=	9 	if	respondent	 ==	112
replace 	res_code	=	5 	if	respondent	 ==	113
replace 	res_code	=	9 	if	respondent	 ==	114
replace 	res_code	=	5 	if	respondent	 ==	115
replace 	res_code	=	9 	if	respondent	 ==	116
replace 	res_code	=	5 	if	respondent	 ==	117
replace 	res_code	=	5 	if	respondent	 ==	118
replace 	res_code	=	5 	if	respondent	 ==	119
replace 	res_code	=	5 	if	respondent	 ==	120
replace 	res_code	=	5 	if	respondent	 ==	121
replace 	res_code	=	5 	if	respondent	 ==	122
replace 	res_code	=	5 	if	respondent	 ==	123
replace 	res_code	=	5 	if	respondent	 ==	124
replace 	res_code	=	5 	if	respondent	 ==	125
replace 	res_code	=	6 	if	respondent	 ==	126
replace 	res_code	=	9 	if	respondent	 ==	127
replace 	res_code	=	5 	if	respondent	 ==	128
replace 	res_code	=	6 	if	respondent	 ==	129
replace 	res_code	=	7 	if	respondent	 ==	130
replace 	res_code	=	5 	if	respondent	 ==	131
replace 	res_code	=	5 	if	respondent	 ==	132
replace 	res_code	=	5 	if	respondent	 ==	133
replace 	res_code	=	6 	if	respondent	 ==	134
replace 	res_code	=	5 	if	respondent	 ==	135
replace 	res_code	=	6 	if	respondent	 ==	136
replace 	res_code	=	6 	if	respondent	 ==	137
replace 	res_code	=	6 	if	respondent	 ==	138
replace 	res_code	=	5 	if	respondent	 ==	139
replace 	res_code	=	6 	if	respondent	 ==	140
replace 	res_code	=	5 	if	respondent	 ==	141
replace 	res_code	=	6 	if	respondent	 ==	142
replace 	res_code	=	5 	if	respondent	 ==	143
replace 	res_code	=	5 	if	respondent	 ==	144
replace 	res_code	=	6 	if	respondent	 ==	145
replace 	res_code	=	9 	if	respondent	 ==	146
replace 	res_code	=	5 	if	respondent	 ==	147
replace 	res_code	=	5 	if	respondent	 ==	148
replace 	res_code	=	6 	if	respondent	 ==	149
replace 	res_code	=	7 	if	respondent	 ==	150
replace 	res_code	=	5 	if	respondent	 ==	151
replace 	res_code	=	6 	if	respondent	 ==	152
replace 	res_code	=	6 	if	respondent	 ==	153
replace 	res_code	=	6 	if	respondent	 ==	154
replace 	res_code	=	6 	if	respondent	 ==	155
replace 	res_code	=	9 	if	respondent	 ==	156
replace 	res_code	=	9 	if	respondent	 ==	157
replace 	res_code	=	5 	if	respondent	 ==	158
replace 	res_code	=	8 	if	respondent	 ==	159
replace 	res_code	=	5 	if	respondent	 ==	160
replace 	res_code	=	5 	if	respondent	 ==	161
replace 	res_code	=	6 	if	respondent	 ==	162
replace 	res_code	=	6 	if	respondent	 ==	163
replace 	res_code	=	6 	if	respondent	 ==	164
replace 	res_code	=	9 	if	respondent	 ==	165
replace 	res_code	=	6 	if	respondent	 ==	166
replace 	res_code	=	5 	if	respondent	 ==	167
replace 	res_code	=	6 	if	respondent	 ==	168
replace 	res_code	=	6 	if	respondent	 ==	169
replace 	res_code	=	6 	if	respondent	 ==	170
replace 	res_code	=	5 	if	respondent	 ==	171
replace 	res_code	=	5 	if	respondent	 ==	172
replace 	res_code	=	5 	if	respondent	 ==	173
replace 	res_code	=	6 	if	respondent	 ==	174
replace 	res_code	=	6 	if	respondent	 ==	175
replace 	res_code	=	5 	if	respondent	 ==	176
replace 	res_code	=	6 	if	respondent	 ==	177
replace 	res_code	=	5 	if	respondent	 ==	178
replace 	res_code	=	6 	if	respondent	 ==	179
replace 	res_code	=	6 	if	respondent	 ==	180
replace 	res_code	=	5 	if	respondent	 ==	181
replace 	res_code	=	6 	if	respondent	 ==	182
replace 	res_code	=	6 	if	respondent	 ==	183
replace 	res_code	=	5 	if	respondent	 ==	184
replace 	res_code	=	5 	if	respondent	 ==	185
replace 	res_code	=	6 	if	respondent	 ==	186
replace 	res_code	=	5 	if	respondent	 ==	187
replace 	res_code	=	6 	if	respondent	 ==	188
replace 	res_code	=	5 	if	respondent	 ==	189
replace 	res_code	=	5 	if	respondent	 ==	190
replace 	res_code	=	5 	if	respondent	 ==	191
replace 	res_code	=	7 	if	respondent	 ==	192
replace 	res_code	=	6 	if	respondent	 ==	193
replace 	res_code	=	5 	if	respondent	 ==	194
replace 	res_code	=	5 	if	respondent	 ==	195
replace 	res_code	=	5 	if	respondent	 ==	196
replace 	res_code	=	9 	if	respondent	 ==	197
replace 	res_code	=	5 	if	respondent	 ==	198
replace 	res_code	=	6 	if	respondent	 ==	199
replace 	res_code	=	6 	if	respondent	 ==	200
replace 	res_code	=	7 	if	respondent	 ==	201
replace 	res_code	=	6 	if	respondent	 ==	202
replace 	res_code	=	5 	if	respondent	 ==	203
replace 	res_code	=	6 	if	respondent	 ==	204
replace 	res_code	=	5 	if	respondent	 ==	205
replace 	res_code	=	5 	if	respondent	 ==	206
replace 	res_code	=	7 	if	respondent	 ==	207
replace 	res_code	=	6 	if	respondent	 ==	208
replace 	res_code	=	5 	if	respondent	 ==	209
replace 	res_code	=	5 	if	respondent	 ==	210
replace 	res_code	=	7 	if	respondent	 ==	211
replace 	res_code	=	6 	if	respondent	 ==	212
replace 	res_code	=	6 	if	respondent	 ==	213
replace 	res_code	=	6 	if	respondent	 ==	214
replace 	res_code	=	6 	if	respondent	 ==	215
replace 	res_code	=	5 	if	respondent	 ==	216
replace 	res_code	=	6 	if	respondent	 ==	217
replace 	res_code	=	6 	if	respondent	 ==	218
replace 	res_code	=	5 	if	respondent	 ==	219
replace 	res_code	=	5 	if	respondent	 ==	220
replace 	res_code	=	5 	if	respondent	 ==	221
replace 	res_code	=	6 	if	respondent	 ==	222
replace 	res_code	=	6 	if	respondent	 ==	223
replace 	res_code	=	6 	if	respondent	 ==	224
replace 	res_code	=	5 	if	respondent	 ==	225
replace 	res_code	=	6 	if	respondent	 ==	226
replace 	res_code	=	6 	if	respondent	 ==	227
replace 	res_code	=	5 	if	respondent	 ==	228
replace 	res_code	=	6 	if	respondent	 ==	229
replace 	res_code	=	6 	if	respondent	 ==	230
replace 	res_code	=	5 	if	respondent	 ==	231
replace 	res_code	=	7 	if	respondent	 ==	232
replace 	res_code	=	5 	if	respondent	 ==	233
replace 	res_code	=	5 	if	respondent	 ==	234
replace 	res_code	=	5 	if	respondent	 ==	235
replace 	res_code	=	6 	if	respondent	 ==	236
replace 	res_code	=	5 	if	respondent	 ==	237
replace 	res_code	=	5 	if	respondent	 ==	238
replace 	res_code	=	6 	if	respondent	 ==	239
replace 	res_code	=	6 	if	respondent	 ==	240
replace 	res_code	=	6 	if	respondent	 ==	241
replace 	res_code	=	5 	if	respondent	 ==	242
replace 	res_code	=	5 	if	respondent	 ==	243
replace 	res_code	=	6 	if	respondent	 ==	244
replace 	res_code	=	5 	if	respondent	 ==	245
replace 	res_code	=	5 	if	respondent	 ==	246
replace 	res_code	=	6 	if	respondent	 ==	247
replace 	res_code	=	6 	if	respondent	 ==	248
replace 	res_code	=	7 	if	respondent	 ==	249
replace 	res_code	=	6 	if	respondent	 ==	250
replace 	res_code	=	6 	if	respondent	 ==	251
replace 	res_code	=	5 	if	respondent	 ==	252
replace 	res_code	=	6 	if	respondent	 ==	253
replace 	res_code	=	6 	if	respondent	 ==	254
replace 	res_code	=	6 	if	respondent	 ==	255
replace 	res_code	=	6 	if	respondent	 ==	256
replace 	res_code	=	5 	if	respondent	 ==	257
replace 	res_code	=	1 	if	respondent	 ==	258
replace 	res_code	=	5 	if	respondent	 ==	259
replace 	res_code	=	6 	if	respondent	 ==	260
replace 	res_code	=	1 	if	respondent	 ==	301
replace 	res_code	=	1 	if	respondent	 ==	302
replace 	res_code	=	1 	if	respondent	 ==	303
replace 	res_code	=	1 	if	respondent	 ==	304
replace 	res_code	=	1 	if	respondent	 ==	305
replace 	res_code	=	1 	if	respondent	 ==	306
replace 	res_code	=	1 	if	respondent	 ==	307
replace 	res_code	=	1 	if	respondent	 ==	308
replace 	res_code	=	1 	if	respondent	 ==	310
replace 	res_code	=	1 	if	respondent	 ==	311
replace 	res_code	=	1 	if	respondent	 ==	312
replace 	res_code	=	1 	if	respondent	 ==	313
replace 	res_code	=	1 	if	respondent	 ==	314
replace 	res_code	=	1 	if	respondent	 ==	315
replace 	res_code	=	1 	if	respondent	 ==	316
replace 	res_code	=	1 	if	respondent	 ==	317
replace 	res_code	=	1 	if	respondent	 ==	318
replace 	res_code	=	1 	if	respondent	 ==	319
replace 	res_code	=	1 	if	respondent	 ==	320
replace 	res_code	=	1 	if	respondent	 ==	321
replace 	res_code	=	1 	if	respondent	 ==	322
replace 	res_code	=	1 	if	respondent	 ==	323
replace 	res_code	=	1 	if	respondent	 ==	324
replace 	res_code	=	1 	if	respondent	 ==	325
replace 	res_code	=	1 	if	respondent	 ==	326
replace 	res_code	=	1 	if	respondent	 ==	327
replace 	res_code	=	1 	if	respondent	 ==	328
replace 	res_code	=	1 	if	respondent	 ==	329
replace 	res_code	=	1 	if	respondent	 ==	330
replace 	res_code	=	1 	if	respondent	 ==	331
replace 	res_code	=	1 	if	respondent	 ==	332
replace 	res_code	=	1 	if	respondent	 ==	333
replace 	res_code	=	1 	if	respondent	 ==	334
replace 	res_code	=	1 	if	respondent	 ==	335
replace 	res_code	=	1 	if	respondent	 ==	336
replace 	res_code	=	1 	if	respondent	 ==	337
replace 	res_code	=	1 	if	respondent	 ==	338
replace 	res_code	=	1 	if	respondent	 ==	339
replace 	res_code	=	1 	if	respondent	 ==	340
replace 	res_code	=	1 	if	respondent	 ==	341
replace 	res_code	=	1 	if	respondent	 ==	342
replace 	res_code	=	1 	if	respondent	 ==	343
replace 	res_code	=	1 	if	respondent	 ==	344
replace 	res_code	=	1 	if	respondent	 ==	345
replace 	res_code	=	1 	if	respondent	 ==	346
replace 	res_code	=	1 	if	respondent	 ==	347
replace 	res_code	=	1 	if	respondent	 ==	348
replace 	res_code	=	1 	if	respondent	 ==	349
replace 	res_code	=	1 	if	respondent	 ==	350
replace 	res_code	=	1 	if	respondent	 ==	351
replace 	res_code	=	1 	if	respondent	 ==	352
replace 	res_code	=	1 	if	respondent	 ==	353
replace 	res_code	=	1 	if	respondent	 ==	354
replace 	res_code	=	1 	if	respondent	 ==	355
replace 	res_code	=	1 	if	respondent	 ==	356
replace 	res_code	=	1 	if	respondent	 ==	357
replace 	res_code	=	1 	if	respondent	 ==	358
replace 	res_code	=	1 	if	respondent	 ==	359
replace 	res_code	=	1 	if	respondent	 ==	360
replace 	res_code	=	1 	if	respondent	 ==	361
replace 	res_code	=	1 	if	respondent	 ==	362
replace 	res_code	=	1 	if	respondent	 ==	363
replace 	res_code	=	1 	if	respondent	 ==	364
replace 	res_code	=	1 	if	respondent	 ==	366
replace 	res_code	=	1 	if	respondent	 ==	367
replace 	res_code	=	1 	if	respondent	 ==	368
replace 	res_code	=	1 	if	respondent	 ==	369
replace 	res_code	=	1 	if	respondent	 ==	370
replace 	res_code	=	1 	if	respondent	 ==	371
replace 	res_code	=	1 	if	respondent	 ==	372
replace 	res_code	=	1 	if	respondent	 ==	373
replace 	res_code	=	1 	if	respondent	 ==	374
replace 	res_code	=	1 	if	respondent	 ==	375
replace 	res_code	=	1 	if	respondent	 ==	376
replace 	res_code	=	1 	if	respondent	 ==	377
replace 	res_code	=	1 	if	respondent	 ==	378
replace 	res_code	=	1 	if	respondent	 ==	379
replace 	res_code	=	1 	if	respondent	 ==	380
replace 	res_code	=	1 	if	respondent	 ==	381
replace 	res_code	=	1 	if	respondent	 ==	382
replace 	res_code	=	1 	if	respondent	 ==	383
replace 	res_code	=	1 	if	respondent	 ==	384
replace 	res_code	=	1 	if	respondent	 ==	385
replace 	res_code	=	1 	if	respondent	 ==	386
replace 	res_code	=	1 	if	respondent	 ==	387
replace 	res_code	=	1 	if	respondent	 ==	388
replace 	res_code	=	1 	if	respondent	 ==	389
replace 	res_code	=	1 	if	respondent	 ==	390
replace 	res_code	=	1 	if	respondent	 ==	391
replace 	res_code	=	1 	if	respondent	 ==	392
replace 	res_code	=	1 	if	respondent	 ==	393
replace 	res_code	=	1 	if	respondent	 ==	394
replace 	res_code	=	1 	if	respondent	 ==	395
replace 	res_code	=	1 	if	respondent	 ==	396
replace 	res_code	=	1 	if	respondent	 ==	397
replace 	res_code	=	1 	if	respondent	 ==	398
replace 	res_code	=	1 	if	respondent	 ==	399
replace 	res_code	=	1 	if	respondent	 ==	400
replace 	res_code	=	1 	if	respondent	 ==	401
replace 	res_code	=	1 	if	respondent	 ==	402
replace 	res_code	=	1 	if	respondent	 ==	403
replace 	res_code	=	1 	if	respondent	 ==	404
replace 	res_code	=	1 	if	respondent	 ==	405
replace 	res_code	=	1 	if	respondent	 ==	406
replace 	res_code	=	1 	if	respondent	 ==	407
replace 	res_code	=	1 	if	respondent	 ==	408
replace 	res_code	=	1 	if	respondent	 ==	409
replace 	res_code	=	1 	if	respondent	 ==	410
replace 	res_code	=	1 	if	respondent	 ==	411
replace 	res_code	=	1 	if	respondent	 ==	412
replace 	res_code	=	1 	if	respondent	 ==	413
replace 	res_code	=	1 	if	respondent	 ==	414
replace 	res_code	=	1 	if	respondent	 ==	415
replace 	res_code	=	1 	if	respondent	 ==	416
replace 	res_code	=	1 	if	respondent	 ==	417
replace 	res_code	=	1 	if	respondent	 ==	418
replace 	res_code	=	1 	if	respondent	 ==	419
replace 	res_code	=	1 	if	respondent	 ==	420
replace 	res_code	=	1 	if	respondent	 ==	421
			

label var res_code "Respondent category"
label var pet_code "Petitioner category"

label define respet_code  1 "US" 2 "State" 3 "Local" 4 "Judicial" 5 "Private business" 6 "Private person" 7 "Non-profit" 8 "Foreign" 9 "Person or business" 

label values  res_code pet_code respet_code








gen us_party1 = 0
gen state_party1 = 0
gen local_party1 = 0
gen jud_party1 = 0
gen bus_party1 = 0
gen person_party1 = 0
gen nonprof_party1 = 0
gen foreign_party1 = 0
gen persbus_party1 = 0

gen us_party2 = 0
gen state_party2 = 0
gen local_party2 = 0
gen jud_party2 = 0
gen bus_party2 = 0
gen person_party2 = 0
gen nonprof_party2 = 0
gen foreign_party2 = 0
gen persbus_party2 = 0

gen us_party = 0
gen state_party = 0
gen local_party = 0
gen jud_party = 0
gen bus_party = 0
gen person_party = 0
gen nonprof_party = 0
gen foreign_party = 0
gen persbus_party = 0


replace 	us_party1	=	1	if	pet_code	==	1
replace 	state_party1	=	1	if	pet_code	==	2
replace 	local_party1	=	1	if	pet_code	==	3
replace 	jud_party1	=	1	if	pet_code	==	4
replace 	bus_party1	=	1	if	pet_code	==	5
replace 	person_party1	=	1	if	pet_code	==	6
replace 	nonprof_party1	=	1	if	pet_code	==	7
replace 	foreign_party1	=	1	if	pet_code	==	8
replace 	persbus_party1	=	1	if	pet_code	==	9
							
							
replace 	us_party2	=	1	if	res_code	==	1
replace 	state_party2	=	1	if	res_code	==	2
replace 	local_party2	=	1	if	res_code	==	3
replace 	jud_party2	=	1	if	res_code	==	4
replace 	bus_party2	=	1	if	res_code	==	5
replace 	person_party2	=	1	if	res_code	==	6
replace 	nonprof_party2	=	1	if	res_code	==	7
replace 	foreign_party2	=	1	if	res_code	==	8
replace 	persbus_party2	=	1	if	res_code	==	9

 							
replace 	us_party	=	1	if	res_code	==	1	|	pet_code	==	1		
replace 	state_party	=	1	if	res_code	==	2	|	pet_code	==	2		
replace 	local_party	=	1	if	res_code	==	3	|	pet_code	==	3		
replace 	jud_party	=	1	if	res_code	==	4	|	pet_code	==	4		
replace 	bus_party	=	1	if	res_code	==	5	|	pet_code	==	5		
replace 	person_party	=	1	if	res_code	==	6	|	pet_code	==	6		
replace 	nonprof_party	=	1	if	res_code	==	7	|	pet_code	==	7		
replace 	foreign_party	=	1	if	res_code	==	8	|	pet_code	==	8		
replace 	persbus_party	=	1	if	res_code	==	9	|	pet_code	==	8		



generate 	us_win	=	0	if	res_code	==	1	|	pet_code	==	1		
generate 	state_win	=	0	if	res_code	==	2	|	pet_code	==	2		
generate 	local_win	=	0	if	res_code	==	3	|	pet_code	==	3		
generate 	jud_win	=	0	if	res_code	==	4	|	pet_code	==	4		
generate 	bus_win	=	0	if	res_code	==	5	|	pet_code	==	5		
generate 	person_win	=	0	if	res_code	==	6	|	pet_code	==	6		
generate 	nonprof_win	=	0	if	res_code	==	7	|	pet_code	==	7		
generate 	foreign_win	=	0	if	res_code	==	8	|	pet_code	==	8		
generate 	persbus_win=	0		if	res_code	==	9	|	pet_code	==	8		

replace 	us_win	=	1	if	pet_code	==	1	&	partyWinning	==	1		
replace 	state_win	=	1	if	pet_code	==	2	&	partyWinning	==	1		
replace 	local_win	=	1	if	pet_code	==	3	&	partyWinning	==	1		
replace 	jud_win	=	1	if	pet_code	==	4	&	partyWinning	==	1		
replace 	bus_win	=	1	if	pet_code	==	5	&	partyWinning	==	1		
replace 	person_win	=	1	if	pet_code	==	6	&	partyWinning	==	1		
replace 	nonprof_win	=	1	if	pet_code	==	7	&	partyWinning	==	1		
replace 	foreign_win	=	1	if	pet_code	==	8	&	partyWinning	==	1		
replace 	persbus_win	=	1	if	pet_code	==	9	&	partyWinning	==	1		


replace 	us_win	=	1	if	res_code	==	1	&	partyWinning	==	0		
replace 	state_win	=	1	if	res_code	==	2	&	partyWinning	==	0		
replace 	local_win	=	1	if	res_code	==	3	&	partyWinning	==	0		
replace 	jud_win	=	1	if	res_code	==	4	&	partyWinning	==	0		
replace 	bus_win	=	1	if	res_code	==	5	&	partyWinning	==	0		
replace 	person_win	=	1	if	res_code	==	6	&	partyWinning	==	0		
replace 	nonprof_win	=	1	if	res_code	==	7	&	partyWinning	==	0		
replace 	foreign_win	=	1	if	res_code	==	8	&	partyWinning	==	0		
replace 	persbus_win	=	1	if	res_code	==	9	&	partyWinning	==	0		



gen buswin_low = 0 if bus_party == 1 
replace buswin_low = 1 if bus_win == 1 & (person_party == 1 | nonprof_party == 1 | persbus_party == 1) 


gen buswin_gov = 0 if bus_party == 1  
replace buswin_gov = 1 if bus_win == 1 & (us_party == 1 | state_party == 1 | local_party == 1) 



* I did it like this because the denominator here cannot include cases where there are no business versus government | individuals parties
* that way, when I aggregate it, it is the percent liberal outcomes OF bus v gov | individuals


gen buswin_lowc = 0 if bus_party == 1  & (person_party == 1 | nonprof_party == 1 | persbus_party == 1) 
gen buswin_lowl = 0 if bus_party == 1  & (person_party == 1 | nonprof_party == 1 | persbus_party == 1) 


replace buswin_lowc = 1 if bus_party == 1  & ( decisionDirection  == 1) &  (person_party == 1 | nonprof_party == 1 | persbus_party == 1) 
replace buswin_lowl = 1 if bus_party == 1  & ( decisionDirection  == 2) &  (person_party == 1 | nonprof_party == 1 | persbus_party == 1) 

gen buswin_govc = 0 if bus_party == 1  & (us_party == 1 | state_party == 1 | local_party == 1) 
gen buswin_govl = 0 if bus_party == 1  & (us_party == 1 | state_party == 1 | local_party == 1) 

replace buswin_govc = 1 if bus_party == 1  & ( decisionDirection  == 1) &  (us_party == 1 | state_party == 1 | local_party == 1) 
replace buswin_govl = 1 if bus_party == 1  & ( decisionDirection  == 2) &  (us_party == 1 | state_party == 1 | local_party == 1) 



label var buswin_low "Business wins against private person or non profit - includes persbus"
label var buswin_gov "Business wins against government"
label var us_party2 "US as a respondent" 
label var state_party2 "State as a respondent" 
label var local_party2 "Local govt as a respondent" 
label var jud_party2 "Judiciary as a respondent" 
label var bus_party2 "Private business as a respondent" 
label var person_party2 "Private person as a respondent" 
label var nonprof_party2 "Nonprofit as a respondent" 
label var foreign_party2 "Foreign entity as a respondent" 
label var persbus_party2 "Either person or business as a respondent" 

label var us_party1 "US as a petitioner" 
label var state_party1 "State as a petitioner " 
label var local_party1 "Local govt as a petitioner " 
label var jud_party1 "Judiciary as a petitioner " 
label var bus_party1 "Private business as a petitioner " 
label var person_party1 "Private person as a petitioner " 
label var nonprof_party1 "Nonprofit as a petitioner " 
label var foreign_party1 "Foreign entity as a petitioner " 
label var persbus_party1 "Either person or business as a petitioner " 


label var us_win "US party wins" 
label var state_win "State party wins" 
label var local_win "Local govt party wins" 
label var jud_win "Judiciary party wins" 
label var bus_win "Private business party wins " 
label var person_win "Private person party wins" 
label var nonprof_win "Nonprofit party wins" 
label var foreign_win "Foreign party wins" 
label var persbus_win "Either person or business party wins" 

label var us_party2 "US as a respondent" 
label var state_party2 "State as a respondent " 
label var local_party2 "Local govt as a respondent " 
label var jud_party2 "Judiciary as a respondent " 
label var bus_party2 "Private business as a respondent " 
label var person_party2 "Private person as a respondent " 
label var nonprof_party2 "Nonprofit as a respondent " 
label var foreign_party2 "Foreign entity as a respondent " 
label var persbus_party2 "Either person or business as a respondent " 




save "${sc_Working}2023_SCDB_Baird_Justice2021Working.dta", replace



********************************************************************************
********************************************************************************
********************************************************************************
* Adding ideal points (MQ, Common space) and medians 
********************************************************************************
********************************************************************************
********************************************************************************


********************************************************************************
* Merging ideal point data: JCS and MQ 
********************************************************************************

********************************************************************************
* Martin Quinn data
********************************************************************************

* Jan 31, 2023 downloaded from 
* https://mqscores.lsa.umich.edu/measures.php


use "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/OutlookDownloads/2022 JCS/justices.dta"
save "${sc_Orig}MQjusticesOrig.dta", replace
drop post_med post_025 post_975 justiceName
rename post_mn mq
rename post_sd mq_sd
drop if term < 1946


save "${sc_Orig}MQ_justices_for_merge.dta", replace

********************************************************************************
* Judicial Common scores 
********************************************************************************

* Jan 31, 2023 Downloaded from 
* https://epstein.usc.edu/jcs

use "${download_folder}2022 JCS/mq scores with jcs.dta"
save "${sc_Orig}Epstein_JCS_justices.dta", replace 
drop post_med post_025 post_975 justiceName post_mn post_sd pres2022 transf predict_base

drop if term < 1946

save "${sc_Orig}Epstein_JCS_justices_for_merge.dta", replace

********************************************************************************
* Merge JCS, MQ, and medians 
********************************************************************************

* Merge common space scores with MQ scores 

use "${sc_Orig}Epstein_JCS_justices_for_merge.dta"
sort term justice
save "${sc_Orig}Epstein_JCS_justices_for_merge.dta", replace


use "${sc_Orig}MQ_justices_for_merge.dta"
sort term justice

merge 1:1 term justice  using  "${sc_Orig}Epstein_JCS_justices_for_merge.dta"
drop _merge
save "${sc_Orig}JCS_MQ_justices_for_merge.dta", replace


********************************************************************************
* Merge median scores with MQ and JCS 
********************************************************************************

use "${download_folder}2022 JCS/jcs 2022/stata/jcs medians.dta"
drop if term < 1946

rename sc_median JCSsc_median
sort term 

save "${sc_Orig}JCS_medians_for_merge.dta", replace 

use "${sc_Orig}JCS_MQ_justices_for_merge.dta"

sort term 
merge m:m term   using  "${sc_Orig}JCS_medians_for_merge.dta"

drop if year < 1946
drop _merge
rename JCSsc_median JCS_SCmedian
save "${sc_Orig}JCS_MQ_medians_merged.dta", replace 

********************************************************************************
* Merge MQ and JCS and medians with justice data
********************************************************************************

use "${sc_Working}2023_SCDB_Baird_Justice2021Working.dta"
sort term justice 
merge m:1 term justice  using  "${sc_Orig}JCS_MQ_medians_merged.dta"

save "${sc_Working}2023_SCDB_Baird_Justice2021Working.dta", replace

********************************************************************************
* Designate medians from MQ to assign SC median
********************************************************************************

* Jan 31, 2023 downloaded from 
* https://mqscores.lsa.umich.edu/measures.php

gen 	 MQ_SCmedian = 	0.246	 	if term == 	1946
replace 	  MQ_SCmedian = 	0.447	 	if term == 	1947
replace 	  MQ_SCmedian = 	0.548	 	if term == 	1948
replace 	  MQ_SCmedian = 	0.881	 	if term == 	1949
replace 	  MQ_SCmedian = 	0.931	 	if term == 	1950
replace 	  MQ_SCmedian = 	0.932	 	if term == 	1951
replace 	  MQ_SCmedian = 	1.066	 	if term == 	1952
replace 	  MQ_SCmedian = 	0.573	 	if term == 	1953
replace 	  MQ_SCmedian = 	0.35	 	if term == 	1954
replace 	  MQ_SCmedian = 	0.559	 	if term == 	1955
replace 	  MQ_SCmedian = 	0.162	 	if term == 	1956
replace 	  MQ_SCmedian = 	0.58	 	if term == 	1957
replace 	  MQ_SCmedian = 	0.643	 	if term == 	1958
replace 	  MQ_SCmedian = 	0.335	 	if term == 	1959
replace 	  MQ_SCmedian = 	0.443	 	if term == 	1960
replace 	  MQ_SCmedian = 	-0.041	 	if term == 	1961
replace 	  MQ_SCmedian = 	-1.079	 	if term == 	1962
replace 	  MQ_SCmedian = 	-1.133	 	if term == 	1963
replace 	  MQ_SCmedian = 	-0.707	 	if term == 	1964
replace 	  MQ_SCmedian = 	-0.56	 	if term == 	1965
replace 	  MQ_SCmedian = 	-0.414	 	if term == 	1966
replace 	  MQ_SCmedian = 	-1.043	 	if term == 	1967
replace 	  MQ_SCmedian = 	-0.896	 	if term == 	1968
replace 	  MQ_SCmedian = 	0.19	 	if term == 	1969
replace 	  MQ_SCmedian = 	0.381	 	if term == 	1970
replace 	  MQ_SCmedian = 	0.64	 	if term == 	1971
replace 	  MQ_SCmedian = 	0.945	 	if term == 	1972
replace 	  MQ_SCmedian = 	0.609	 	if term == 	1973
replace 	  MQ_SCmedian = 	0.615	 	if term == 	1974
replace 	  MQ_SCmedian = 	0.492	 	if term == 	1975
replace 	  MQ_SCmedian = 	0.473	 	if term == 	1976
replace 	  MQ_SCmedian = 	0.233	 	if term == 	1977
replace 	  MQ_SCmedian = 	0.156	 	if term == 	1978
replace 	  MQ_SCmedian = 	0.24	 	if term == 	1979
replace 	  MQ_SCmedian = 	0.231	 	if term == 	1980
replace 	  MQ_SCmedian = 	0.266	 	if term == 	1981
replace 	  MQ_SCmedian = 	0.673	 	if term == 	1982
replace 	  MQ_SCmedian = 	0.877	 	if term == 	1983
replace 	  MQ_SCmedian = 	0.828	 	if term == 	1984
replace 	  MQ_SCmedian = 	0.932	 	if term == 	1985
replace 	  MQ_SCmedian = 	0.878	 	if term == 	1986
replace 	  MQ_SCmedian = 	0.972	 	if term == 	1987
replace 	  MQ_SCmedian = 	1.098	 	if term == 	1988
replace 	  MQ_SCmedian = 	0.876	 	if term == 	1989
replace 	  MQ_SCmedian = 	0.919	 	if term == 	1990
replace 	  MQ_SCmedian = 	0.756	 	if term == 	1991
replace 	  MQ_SCmedian = 	0.838	 	if term == 	1992
replace 	  MQ_SCmedian = 	0.817	 	if term == 	1993
replace 	  MQ_SCmedian = 	0.736	 	if term == 	1994
replace 	  MQ_SCmedian = 	0.685	 	if term == 	1995
replace 	  MQ_SCmedian = 	0.782	 	if term == 	1996
replace 	  MQ_SCmedian = 	0.798	 	if term == 	1997
replace 	  MQ_SCmedian = 	0.861	 	if term == 	1998
replace 	  MQ_SCmedian = 	0.849	 	if term == 	1999
replace 	  MQ_SCmedian = 	0.589	 	if term == 	2000
replace 	  MQ_SCmedian = 	0.371	 	if term == 	2001
replace 	  MQ_SCmedian = 	0.26	 	if term == 	2002
replace 	  MQ_SCmedian = 	0.222	 	if term == 	2003
replace 	  MQ_SCmedian = 	0.11	 	if term == 	2004
replace 	  MQ_SCmedian = 	0.044	 	if term == 	2005
replace 	  MQ_SCmedian = 	0.458	 	if term == 	2006
replace 	  MQ_SCmedian = 	0.411	 	if term == 	2007
replace 	  MQ_SCmedian = 	0.576	 	if term == 	2008
replace 	  MQ_SCmedian = 	0.516	 	if term == 	2009
replace 	  MQ_SCmedian = 	0.577	 	if term == 	2010
replace 	  MQ_SCmedian = 	0.296	 	if term == 	2011
replace 	  MQ_SCmedian = 	0.24	 	if term == 	2012
replace 	  MQ_SCmedian = 	0.068	 	if term == 	2013
replace 	  MQ_SCmedian = 	-0.227	 	if term == 	2014
replace 	  MQ_SCmedian = 	-0.269	 	if term == 	2015
replace 	  MQ_SCmedian = 	-0.059	 	if term == 	2016
replace 	  MQ_SCmedian = 	0.298	 	if term == 	2017
replace 	  MQ_SCmedian = 	0.402	 	if term == 	2018
replace 	  MQ_SCmedian = 	0.355	 	if term == 	2019
replace 	  MQ_SCmedian = 	0.741	 	if term == 	2020
replace 	  MQ_SCmedian = 	0.827	 	if term == 	2021

gen 	 MQ_SCmedian_sd = 	0.257	if term == 	1946
replace 	  MQ_SCmedian_sd = 	0.23	if term == 	1947
replace 	  MQ_SCmedian_sd = 	0.262	if term == 	1948
replace 	  MQ_SCmedian_sd = 	0.302	if term == 	1949
replace 	  MQ_SCmedian_sd = 	0.289	if term == 	1950
replace 	  MQ_SCmedian_sd = 	0.3	if term == 	1951
replace 	  MQ_SCmedian_sd = 	0.374	if term == 	1952
replace 	  MQ_SCmedian_sd = 	0.419	if term == 	1953
replace 	  MQ_SCmedian_sd = 	0.446	if term == 	1954
replace 	  MQ_SCmedian_sd = 	0.484	if term == 	1955
replace 	  MQ_SCmedian_sd = 	0.51	if term == 	1956
replace 	  MQ_SCmedian_sd = 	0.545	if term == 	1957
replace 	  MQ_SCmedian_sd = 	0.578	if term == 	1958
replace 	  MQ_SCmedian_sd = 	0.621	if term == 	1959
replace 	  MQ_SCmedian_sd = 	0.667	if term == 	1960
replace 	  MQ_SCmedian_sd = 	0.709	if term == 	1961
replace 	  MQ_SCmedian_sd = 	0.75	if term == 	1962
replace 	  MQ_SCmedian_sd = 	0.792	if term == 	1963
replace 	  MQ_SCmedian_sd = 	0.82	if term == 	1964
replace 	  MQ_SCmedian_sd = 	0.842	if term == 	1965
replace 	  MQ_SCmedian_sd = 	0.872	if term == 	1966
replace 	  MQ_SCmedian_sd = 	0.902	if term == 	1967
replace 	  MQ_SCmedian_sd = 	0.937	if term == 	1968
replace 	  MQ_SCmedian_sd = 	0.965	if term == 	1969
replace 	  MQ_SCmedian_sd = 	0.996	if term == 	1970
replace 	  MQ_SCmedian_sd = 	1.026	if term == 	1971
replace 	  MQ_SCmedian_sd = 	1.06	if term == 	1972
replace 	  MQ_SCmedian_sd = 	1.09	if term == 	1973
replace 	  MQ_SCmedian_sd = 	1.116	if term == 	1974
replace 	  MQ_SCmedian_sd = 	1.155	if term == 	1975
replace 	  MQ_SCmedian_sd = 	0.278	if term == 	1976
replace 	  MQ_SCmedian_sd = 	0.293	if term == 	1977
replace 	  MQ_SCmedian_sd = 	0.338	if term == 	1978
replace 	  MQ_SCmedian_sd = 	0.372	if term == 	1979
replace 	  MQ_SCmedian_sd = 	0.402	if term == 	1980
replace 	  MQ_SCmedian_sd = 	0.43	if term == 	1981
replace 	  MQ_SCmedian_sd = 	0.446	if term == 	1982
replace 	  MQ_SCmedian_sd = 	0.469	if term == 	1983
replace 	  MQ_SCmedian_sd = 	0.495	if term == 	1984
replace 	  MQ_SCmedian_sd = 	0.502	if term == 	1985
replace 	  MQ_SCmedian_sd = 	0.508	if term == 	1986
replace 	  MQ_SCmedian_sd = 	0.532	if term == 	1987
replace 	  MQ_SCmedian_sd = 	0.564	if term == 	1988
replace 	  MQ_SCmedian_sd = 	0.606	if term == 	1989
replace 	  MQ_SCmedian_sd = 	0.703	if term == 	1990
replace 	  MQ_SCmedian_sd = 	0.295	if term == 	1991
replace 	  MQ_SCmedian_sd = 	0.337	if term == 	1992
replace 	  MQ_SCmedian_sd = 	0.36	if term == 	1993
replace 	  MQ_SCmedian_sd = 	0.384	if term == 	1994
replace 	  MQ_SCmedian_sd = 	0.395	if term == 	1995
replace 	  MQ_SCmedian_sd = 	0.41	if term == 	1996
replace 	  MQ_SCmedian_sd = 	0.428	if term == 	1997
replace 	  MQ_SCmedian_sd = 	0.427	if term == 	1998
replace 	  MQ_SCmedian_sd = 	0.43	if term == 	1999
replace 	  MQ_SCmedian_sd = 	0.447	if term == 	2000
replace 	  MQ_SCmedian_sd = 	0.453	if term == 	2001
replace 	  MQ_SCmedian_sd = 	0.452	if term == 	2002
replace 	  MQ_SCmedian_sd = 	0.441	if term == 	2003
replace 	  MQ_SCmedian_sd = 	0.436	if term == 	2004
replace 	  MQ_SCmedian_sd = 	0.44	if term == 	2005
replace 	  MQ_SCmedian_sd = 	0.441	if term == 	2006
replace 	  MQ_SCmedian_sd = 	0.457	if term == 	2007
replace 	  MQ_SCmedian_sd = 	0.473	if term == 	2008
replace 	  MQ_SCmedian_sd = 	0.524	if term == 	2009
replace 	  MQ_SCmedian_sd = 	0.304	if term == 	2010
replace 	  MQ_SCmedian_sd = 	0.326	if term == 	2011
replace 	  MQ_SCmedian_sd = 	0.335	if term == 	2012
replace 	  MQ_SCmedian_sd = 	0.37	if term == 	2013
replace 	  MQ_SCmedian_sd = 	0.402	if term == 	2014
replace 	  MQ_SCmedian_sd = 	0.439	if term == 	2015
replace 	  MQ_SCmedian_sd = 	0.469	if term == 	2016
replace 	  MQ_SCmedian_sd = 	0.501	if term == 	2017
replace 	  MQ_SCmedian_sd = 	0.535	if term == 	2018
replace 	  MQ_SCmedian_sd = 	0.571	if term == 	2019
replace 	  MQ_SCmedian_sd = 	0.63	if term == 	2020
replace 	  MQ_SCmedian_sd = 	0.675	if term == 	2021



********************************************************************************
Standardize ideal points, from 0-1
********************************************************************************

sum MQ_SCmedian
gen MQ_SCmedian01 = ((MQ_SCmedian- `r(min)') / (`r(max)' - `r(min)')) 

sum jcs 
gen jcs01 = ((jcs - `r(min)') / (`r(max)' - `r(min)')) 


sum mq 
gen mq01 = ((mq - `r(min)') / (`r(max)' - `r(min)')) 

sum JCS_SCmedian
gen JCS_SCmedian01 = ((JCS_SCmedian - `r(min)') / (`r(max)' - `r(min)')) 


********************************************************************************
* Create distance from the medians 
********************************************************************************
* MQ vars 
gen mq_med_diff = mq - MQ_SCmedian
gen mq_med_diff_f = abs(mq_med_diff)

sum mq_med_diff 
 
    gen mq_med_diff01 = ((mq_med_diff - `r(min)') / (`r(max)' - `r(min)')) 


sum mq_med_diff_f 
 
    gen mq_med_diff_f01 = ((mq_med_diff_f - `r(min)') / (`r(max)' - `r(min)')) 



* JCS vars
gen jcs_med_diff = jcs - JCS_SCmedian

gen jcs_med_diff_f = abs(jcs_med_diff)



sum jcs_med_diff 
 
    gen jcs_med_diff01 = ((jcs_med_diff - `r(min)') / (`r(max)' - `r(min)')) 


sum jcs_med_diff_f 
 
    gen jcs_med_diff_f01 = ((jcs_med_diff_f - `r(min)') / (`r(max)' - `r(min)')) 


********************************************************************************
* Creating the doctrinal ideal point measures 
********************************************************************************


gen medmaj_rat_noconcur_jcs = jcs  if vote == 1 | vote ==5
gen medmaj_rat_nospec_jcs = jcs  if vote == 1 | vote ==5 | vote == 3 
gen medmaj_vote_nodis_jcs = jcs  if vote == 1 | vote ==5 | vote == 3  | vote == 4 
gen medmaj_vote_dis_jcs = jcs  if vote == 2 

clonevar medmaj_rat_noconcur_just = medmaj_rat_noconcur_jcs
clonevar medmaj_rat_nospec_just = medmaj_rat_nospec_jcs
clonevar medmaj_vote_nodis_just = medmaj_vote_nodis_jcs

clonevar medmaj_vote_dis_just = medmaj_vote_dis_jcs

label var medmaj_vote_dis_just  "Median of dissent"
 
label var  medmaj_vote_dis_jcs "Median of dissent"


gen ideo_doct = medmaj_rat_nospec_jcs

gen ideo_doct_liberal = ideo_doct if lib ==1
gen ideo_doct_conserv= ideo_doct if lib ==0

gen ideo_doct_disc =  ideo_doct if disc_gen ==1
gen ideo_doct_liberty =  ideo_doct  if liberties_gen  ==1
gen ideo_doct_crim =  ideo_doct  if crim_gen  ==1
gen ideo_doct_econ =  ideo_doct  if econ_gen  ==1
gen ideo_doct_pow =  ideo_doct  if powers_gen ==1


gen libD_disc =  lib if disc_gen ==1
gen libD_liberty =  lib  if liberties_gen  ==1
gen libD_crim =  lib  if crim_gen  ==1
gen libD_econ =  lib  if econ_gen  ==1
gen libD_pow =  lib  if powers_gen ==1


gen conD_disc =  con if disc_gen ==1
gen conD_liberty =  con  if liberties_gen  ==1
gen conD_crim =  con  if crim_gen  ==1
gen conD_econ =  con  if econ_gen  ==1
gen conD_pow =  con  if powers_gen ==1


sum ideo_doct 
gen ideo_doct01 = ((ideo_doct - `r(min)') / (`r(max)' - `r(min)')) 

sum ideo_doct_liberal
gen ideo_doct_liberal01= ((ideo_doct_liberal - `r(min)') / (`r(max)' - `r(min)')) 

sum ideo_doct_conserv
gen ideo_doct_conserv01= ((ideo_doct_conserv - `r(min)') / (`r(max)' - `r(min)')) 



sum ideo_doct_disc 
gen ideo_doct_disc01 = ((ideo_doct_disc  - `r(min)') / (`r(max)' - `r(min)')) 


sum ideo_doct_liberty 
gen ideo_doct_liberty01 = ((ideo_doct_liberty - `r(min)') / (`r(max)' - `r(min)')) 


sum ideo_doct_crim 
gen ideo_doct_crim01 = ((ideo_doct_crim - `r(min)') / (`r(max)' - `r(min)')) 


sum ideo_doct_econ 
gen ideo_doct_econ01 = ((ideo_doct_econ - `r(min)') / (`r(max)' - `r(min)')) 


sum ideo_doct_pow 
gen ideo_doct_pow01 = ((ideo_doct_pow - `r(min)') / (`r(max)' - `r(min)')) 


save "${sc_Working}2023_SCDB_Baird_Justice2021Working.dta", replace



* important: you have to collapse the means and medians by caseId, then collapse based on svalue_gen and term 
* Note when aggregating by caseid, you have to calculate medians of the doctrinal measures.
* Afterwards, you can get the means and the sds.
* I am creating a mean of the mq, jcs variables: what if the mean is different from the median.

* Also, the number of 5-4 decisions should increase as there is a greater amount of deviation from the mean - see Jacobi and Epstein "Super Medians"


********************************************************************************
********************************************************************************
********************************************************************************
* Justice data  
********************************************************************************
********************************************************************************
********************************************************************************

use "${sc_Working}2023_SCDB_Baird_Justice2021Working.dta"

sort caseId

save "${sc_Working}2023_SCDB_Baird_Justice2021Working.dta", replace


collapse (median) medmaj_rat_noconcur_jcs medmaj_rat_nospec_jcs ///
medmaj_vote_nodis_jcs medmaj_vote_dis_jcs ideo_doct ideo_doct01 ///
(sum) special_concur reg_concur any_concur /// 
special_concur_opin reg_concur_opin any_concur_opin  dissent  NoDissent Dissent4 ///
Dissent4Opin Dissent3 Dissent3Opin Dissent2 Dissent2Opin Dissent1 Dissent1Opin  ///
concur_opin libdissent_opin condissent_opin disnum  disc disl connum conl conc, by ( caseId)

save "${sc_Orig}2023_SCDB_Baird_Justice2021_from_justice_to_Caseid_orig.dta", replace

save "${sc_Working}2023_SCDB_Baird_Justice2021_from_justice_to_Caseid_Working.dta", replace
drop in 1
save "${sc_Working}2023_SCDB_Baird_Justice2021_from_justice_to_Caseid_Working.dta", replace




********************************************************************************
********************************************************************************
********************************************************************************
* Justice data  
********************************************************************************
********************************************************************************
********************************************************************************

** prepare for making wide 


use "${sc_Working}2023_SCDB_Baird_Justice2021Working.dta"




save "${sc_Working}2023_SCDB_Baird_Justice2021Working_for_wide.dta", replace

gen  stub= "_alit" if justice == 112
replace  stub= "_bar" if justice == 117
replace  stub= "_blc" if justice == 78
replace  stub= "_blkm" if justice == 100
replace  stub= "_brn" if justice == 92
replace  stub= "_brey" if justice == 110
replace  stub= "_burg" if justice == 99
replace  stub= "_burt" if justice == 86
replace  stub= "_clk" if justice == 88
replace  stub= "_doug" if justice == 81
replace  stub= "_fort" if justice == 97
replace  stub= "_frk" if justice == 80
replace  stub= "_gins" if justice == 109
replace  stub= "_gold" if justice == 96
replace  stub= "_gors" if justice == 115
replace  stub= "_har" if justice == 91
replace  stub= "_jack" if justice == 84
replace  stub= "_kag" if justice == 114
replace  stub= "_kav" if justice == 116
replace  stub= "_ken" if justice == 106
replace  stub= "_mar" if justice == 98
replace  stub= "_mint" if justice == 89
replace  stub= "_murp" if justice == 82
replace  stub= "_ocon" if justice == 104
replace  stub= "_pow" if justice == 101
replace  stub= "_reed" if justice == 79
replace  stub= "_rehn" if justice == 102
replace  stub= "_rob" if justice == 111
replace  stub= "_rut" if justice == 85
replace  stub= "_scal" if justice == 105
replace  stub= "_soto" if justice == 113
replace  stub= "_sout" if justice == 107
replace  stub= "_stev" if justice == 103
replace  stub= "_stwt" if justice == 94
replace  stub= "_thom" if justice == 108
replace  stub= "_vin" if justice == 87
replace  stub= "_war" if justice == 90
replace  stub= "_bw" if justice == 95
replace  stub= "_whit" if justice == 93
replace  stub= "_kbj" if justice == 118

drop if stub =="_kbj"



save "${sc_Working}2023_SCDB_Baird_Justice2021Working_for_wide.dta", replace

sort caseId 
save "${sc_Working}2023_SCDB_Baird_Justice2021Working_for_wide.dta", replace


drop in 1

order vote_majority lib majOpin  reg_concur reg_concur_opin special_concur special_concur_opin dissent_opin, after (caseId )

save "${sc_Working}2023_SCDB_Baird_Justice2021Working_for_wide.dta", replace

sort   caseId 
keep caseId  stub   lib vote_majority  special_concur reg_concur  ///
anyopin special_concur_opin reg_concur_opin   majOpin ///
dissent_opin

drop  any_concur any_concur_opin anyopin concur_opin
sort caseId stub
reshape wide   vote_majority lib majOpin  reg_concur reg_concur_opin ///
special_concur special_concur_opin dissent_opin, i(caseId) j(stub) string
compress

save "${sc_Working}2023_SCDB_Baird_Justice2021_wide.dta", replace



save "${sc_Working}2023_SCDB_Baird_Justice2021_wide_for_merge.dta", replace

save "${sc_Working}2023_SCDB_Baird_Justice2021_from_justice_to_Caseid_Working_for_merge.dta", replace




* old

rename justice_lib lib
rename justice_anyopin anyopin
rename justice_concur_opin concur_opin
rename justice_dissent_opin dissent_opin
rename justice_libdissent_opin libdissent_opin
rename justice_condissent_opin condissent_opin
rename ext_mq_med_diff_folded mq_med_diff_f
rename ext_mq_med_diff_folded01 mq_med_diff_f01
rename ext_jcs_med_diff_folded jcs_med_diff_f
rename ext_jcs_med_diff_folded01 jcs_med_diff_f01
