
*********************************************************************************
																				*
* Replication do file for cleaning the                                  		*
* CaseId Supreme Court database							*
																				*  
* Vanessa Baird 							    *			 
* Software used: Stata/SE 17.0                                                  *
*********************************************************************************


* Original data downloaded Jan 31 2023
* http://scdb.wustl.edu/data.php

********************************************************************************
********************************************************************************
********************************************************************************
* User specific paths 
********************************************************************************
********************************************************************************
********************************************************************************

global sc_Orig  	"/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/DataOrig/"
global sc_Working  	"/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/DataWorking/"
global sc_TempDo  	"/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/DataTemp/TempDo/"

global sc_DataTemp  	"/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/DataTemp/"

* This directory contains original cleaned data sets: after it is posted here, its file name contains the date and is not changed    

global sc_PostedClean "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Data/Clean/"

*This helps trace the original downloaded file from the absolute unchanged original 
global download_folder "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/OutlookDownloads/"



*This is the working CaseId file 

* save "${sc_Working}2023_1_31_SCDB_Baird_JusticeWorking.dta", replace 
*This is the data that have justice variables wide 
* save "${sc_Working}2023_SCDB_Baird_CaseId2021_wide_for_merge.dta", replace


* To do
* Create caseId clean data
* Merge with justices wide and Logan Strother's data 
* attach MQ medians with syntax file



********************************************************************************
********************************************************************************
********************************************************************************
* Case data 
********************************************************************************
********************************************************************************
********************************************************************************


* Original data downloaded Jan 31 2023
* http://scdb.wustl.edu/data.php
use "${download_folder}SCDB_2022_01_caseCentered_Citation.dta"
save "${sc_Orig}/SCDB_2022_Case_orig.dta", replace


save "${sc_DataTemp}2023_SCDB_Baird_CaseId2021.dta", replace
save "${sc_Working}2023_SCDB_Baird_CaseId2021Working.dta", replace



use "${sc_Working}2023_SCDB_Baird_CaseId2021Working.dta"




********************************************************************************
* svalue = codes for eleven policy areas 
********************************************************************************

* First, I handle some of the messy issues where svalue is missing or the issue is attorney's fees (if someone is suing for attorney fees for a first Amendment issue, I put them in the first amendment, etc.


gen svalue = 0 

label define svalue ///
1 "Discrimination"  /// 
2 "Free Speech"  /// 
3 "Privacy"  /// 
4 "Criminal Rights"  /// 
5 "Labor" /// 
6 "Environment" /// 
7 "Econreg" /// 
8 "Taxation" /// 
9 "Due Process and Government Liability"  /// 
10 "Judicial Power"  /// 
11 "Federalism"

label var svalue "Policy Area"
label values svalue svalue

********************************************************************************
********************************************************************************
********************************************************************************

** Attorney code translation 

********************************************************************************
********************************************************************************
********************************************************************************

* give all civil rights attorneys fees, initially to rights - svalue == 1
* then, if they belong somewhere else, this can follow

replace svalue =  2 if issue == 60020 | (lawSupp == 200 | lawSupp == 201)
replace svalue = 1 if  issue == 60010

* if an attorney is suing someone on the basis of the 14th Amendment, this is listed under discrimination

replace svalue = 1 if issueArea ==6 & lawSupp == 230 &  (petitioner == 111 | respondent ==111)
replace svalue = 1 if issueArea ==6 & lawSupp == 231 &  (petitioner == 111 | respondent ==111)

* All else is within issue = 60010 

* These are environmental issues or parties suing for attorney's fees 
* Notice the rule is any of these laws or when one of the parties is an environmental group 
replace svalue =5 if issueArea == 6 & (lawSupp == 304 |lawSupp == 338)
replace svalue =5 if issueArea == 6 & (petitioner == 222 | respondent == 222)

* Econ regulation attorneys fees codes 
* lawSupp = 307= Bankrupcy
* lawSupp = 310 = Clayton
* lawSupp = 353 = Miller
* lawSupp = 365 = Securities a
* lawSupp = 600 for infrequent litigant

replace svalue = 7 if (issueArea == 6) & (( lawSupp == 365 | lawSupp == 310 | lawSupp == 353 | lawSupp == 307 ))
	
* Either petitioner or respondent is consumer or creditor 
replace svalue = 7  if ((issueArea == 6 &  lawSupp ==600) & (petitioner == 134 | respondent == 134 )) 	
replace svalue = 7 if ((issueArea == 6 &  lawSupp ==600) & (petitioner == 135 | respondent == 135 )) 	

* 172 is inventor 173 is investor 
replace svalue = 7 if ((issueArea == 6 &  lawSupp ==.) & (petitioner == 173 | respondent == 173 )) 	

* This is when an inventor sues someone who is not the patent office, which is petitioner or respondent == 394; that is government liability 
replace svalue = 7 if ((issueArea == 6 &  lawSupp ==600) &  (petitioner ~= 394 & respondent ~= 394  ) & (petitioner == 172 | respondent == 172 )) 	

* lawSupp = 345 = InternalRev
replace svalue = 8 if issueArea == 6 & (lawSupp == 345)

* This is a veteran suing for attorney's fees ; putting it in government liability
* also if an inventor is suing the patent office, this goes in goverrnment liability
* also if a veteran or social security person sues for attorney fees, this goes in goverrnment liability

* social security  if petitioner == 406  
* veteran if petitioner == 414

replace svalue = 9 if ((issue == 60010)  & (petitioner == 414 | respondent == 414  ))
replace svalue = 9 if ((issue == 60010) & ( (petitioner == 172 | respondent == 172  ) & (petitioner == 394 | respondent == 394  ) ) )
replace svalue = 9 if ((issue == 60010) & ( (petitioner == 406 | respondent == 406  ) | (petitioner == 414 | respondent == 414  ) ) )

* if the law is regarding Supreme Court rules and the attorney is suing, it is against a state, a court, or another government agency
replace svalue = 9 if issueArea ==6 & lawSupp == 403 &  (petitioner == 111 | respondent ==111)
* if the lawSupp is missing, and an attorney is suing this is also against a government agency or court or state 
replace svalue = 9 if issueArea ==6 & lawSupp == . &  (petitioner == 111 | respondent ==111)

tab svalue 

********************************************************************************
********************************************************************************
********************************************************************************
* Some issues are missing so I am putting them in the best possible place

* This may need to be updated, especially for when lawSupp is 600 or missing 

********************************************************************************
********************************************************************************
********************************************************************************

* This is for diagnosing missing issues 
* I am generally using information about the law in question or 
* information about who the parties are to make these evaluations.

* Then, if something is inconsistent 
* with the general principles of the assignment of policy codes 
* and the actual issue codes, doing this second ensures that the general principles change the problems. 

gen issue_miss =0
replace issue_miss =1 if issue == . 

* Putting checks and balances into the due process and government liability

* government liability and due process 
* us being sued if peitioner or respondent == 27
replace  svalue = 9 if (issue == . & svalue ==0) & (petitioner == 27 | respondent == 27) 

* in these, a non-citizen is suing government 
replace  svalue = 9 if (issue == . & svalue ==0) & (petitioner == 368 | respondent == 368) 
replace  svalue = 4 if (issue == . & svalue ==0) & (petitioner == 100 | respondent == 100)

* if a railroad is suing or being sued, this is economic
replace  svalue = 7  if (issue == . & svalue ==0) & (petitioner == 231 | respondent == 231)                       

* this case is about suing in a corporate about att-client privilege in anti-trust case , so econ reg 
replace  svalue = 7  if  petitioner ==16 & respondent ==  220 
* if the Fed trade commission is one of the parties, we will call it economic regulation
replace  svalue = 7   if  petitioner ==357 | respondent ==  357 

* If a state is suing or being sued and this is heard at the SC, then this is federalism
* Do this before below as it would include issues related to economics 
replace  svalue = 11 if (issue == . & svalue ==0) & (petitioner == 28 | respondent == 28) 
replace  svalue = 11 if (issue == . & svalue ==0) & (petitioner == 5 | respondent == 5) 

* if INS, then due proc and gov liability 
replace  svalue = 9 if issue == . & petitioner == 368 | respondent ==368 

* This case is about Tony curtis suing his book publisher
replace  svalue = 7  if issue == . & petitioner == 117 & respondent ==28 

* drug company  
replace  svalue = 7 if issue == . & petitioner == 142 & respondent ==143 

* Do this after above in case a gov entity is being sued: this is a business party 
replace  svalue = 7 if issue == . & petitioner == 122 | respondent ==122 

* this is an airline 
replace  svalue = 7 if issue == . & petitioner == 104 | respondent ==104 

* investment company=119	  insurance company, surety =171
replace  svalue = 7 if issue == . & petitioner == 171 | respondent ==171 
replace  svalue = 7  if issue == . & petitioner == 119 | respondent ==119 

*  debtor 138	  bank  113 
replace  svalue = 7 if issue == . & petitioner == 138 | respondent ==138 
replace  svalue = 7 if issue == . & petitioner == 113 | respondent ==113 

* manufacturer=184	 distributor =141
replace  svalue = 7 if issue == . & petitioner == 184 | respondent ==141 
replace  svalue = 7 if issue == . & petitioner == 141 | respondent ==184 

* taxes : party is the IRS
replace  svalue = 8  if issue == . & petitioner == 369 | respondent ==369 

	   
* If a labor org is one of the parties, then this is labor 

replace   svalue = 6  if (issue == . & svalue ==0) & (petitioner == 249 | respondent == 249) 

* if an employee is pet or repsondent, it is labor 
replace   svalue = 6 if (issue == . & svalue ==0) & (petitioner == 145| respondent == 145) 

* this party is an employer,  labor 
replace   svalue = 6 if (issue == . & svalue ==0) & (petitioner == 151 | respondent == 151) 

* A state v us or vice versa is federalism

replace   svalue = 11 if (issue == . & svalue ==0) & (petitioner == 28 & respondent == 27) 
replace   svalue = 11 if (issue == . & svalue ==0) & (petitioner == 27 & respondent == 28) 


replace   svalue = 1 if (issueArea == 2 & (issue ~= 20400 & issue ~= 20060 & issue ~= 20100 & issue ~= 20140  ///
& issue ~= 20180 & issue ~= 20190  ///
& issue ~= 20320 & issue ~= 20330 & issue ~= 20340 & issue ~= 20350 & issue ~= 20360  ///
& issue ~= 20370 & issue ~= 20380 & issue ~= 20390 )) 

* This case is civil rights because it is about suing Trump's attempt to exclude noncitizens from census
replace svalue =1  if  petitioner ==207 & respondent ==  23 

********************************************************************************
********************************************************************************
********************************************************************************
* Translation of Spaeth codes into codes used for Baird (2004, 2007)
********************************************************************************
********************************************************************************
********************************************************************************


* First amendment : note that some of the attorneys codes were moved to Discrimination as they are civil rights; 1 case is changed 
replace svalue = 2 if issueArea == 3 | issue == 60020 

* Privacy 
replace svalue = 3 if issue > 50000 & issue < 60000 

* Criminal 
replace svalue = 4 if (issue > 10000 & issue <= 20000) | (issue == 40040)

* Workers and poverty law: consumers, unions, employment discrimination, indigen t rights 
replace svalue = 5 if issueArea == 7 | issue == 80090 | issue == 80170 ///
| issue == 20060 | issue == 20100 | issue == 20140 ///
| issue== 20180 | issue == 20190 ///
| issue == 20320 | issue == 20330 | issue == 20340 | issue == 20350 | issue == 20360 | issue == 20370 | issue == 20380 | issue == 20390

* Environment 
*80130	natural resources - environmental protection (cf. national supremacy: natural resources, national supremacy: pollution)
*80250	federal and some few state regulation of transportation regulation: pipeline (cf. federal public utilities regulation: gas pipeline)
*80270	federal and some few state regulation of public utilities regulation: electric power
*80280	federal and some few state regulation of public utilities regulation: nuclear power
*80290	federal and some few state regulation of public utilities regulation: oil producer
*80300	federal and some few state regulation of public utilities regulation: gas producer
*80310	federal and some few state regulation of public utilities regulation: gas pipeline (cf. federal transportation regulation: pipeline)
*100080	national supremacy: natural resources (cf. natural resources - environmental protection)	
*100090	national supremacy: pollution, air or water (cf. natural resources - environmental protection)	
*100100	national supremacy: public utilities (cf. federal public utilities regulation)	

replace svalue =  6 if issue ==  80130 | issue ==  80250  | issue ==  80270 | issue ==  80280 | issue == 80290 ///
| issue == 80300 | issue == 80310 | issue == 100080 | issue == 100090 | issue == 100100 

* Economic regulation 
replace svalue = 7 if (issueArea == 8 & ( issue ~= 80090 & issue ~= 80060 & issue ~= 80100 & issue ~= 80130 & issue ~= 80250 & issue ~= 80270 & issue ~= 80280 & issue ~= 80290 ///
& issue ~= 80300 & issue ~= 80310 & issue ~= 80310 & issue ~= 80310 & issue ~= 80310 & issue ~= 80310 & issue ~= 80310 ) )

* Taxation 
*80100	state or local government tax
replace svalue = 8 if issueArea == 12 | issue == 80100 | issue == 100060 | issue == 100110 

** Non criminal due process, government power and liability 
replace svalue =  9 if (issueArea == 4 & issue ~= 40040) | issue == 80060 | issue == 20400 | issue == 130010 | issue == 130015 

** Judicial Power 
replace  svalue =  10 if issueArea == 9 

** Federalism 
replace  svalue =  11 if ((issueArea == 10) & (issue ~= 100080 & issue ~= 100060 & issue ~= 100090 & issue ~= 100100 & issue ~= 100110)) | (issueArea == 11) 


tab svalue , gen (svalue_dummy)


rename svalue_dummy1 svalue0
rename svalue_dummy2 svalue_disc
rename svalue_dummy3 svalue_speech
rename svalue_dummy4 svalue_priv
rename svalue_dummy5 svalue_crim
rename svalue_dummy6 svalue_labor
rename svalue_dummy7 svalue_env
rename svalue_dummy8 svalue_econ
rename svalue_dummy9 svalue_tax
rename svalue_dummy10 svalue_govliab
rename svalue_dummy11 svalue_judpow
rename svalue_dummy12 svalue_fed


********************************************************************************
********************************************************************************
********************************************************************************
* svalue_gen = codes for five more general policy areas 
********************************************************************************
********************************************************************************
********************************************************************************

* svalue_gen disc_gen liberties_gen crim_gen econ_gen powers_gen 

gen svalue_gen = 1 if svalue ==1
replace svalue_gen = 2 if svalue ==2 | svalue ==3
replace svalue_gen = 3 if svalue ==4
replace svalue_gen = 4 if svalue > 4 & svalue < 9
replace svalue_gen = 5 if svalue > 8

label define svalue_gen 1 "Discrimination" 2 "Speech and privacy" 3 "Criminal" 4 "Economic and taxes" 5 "Power"
label values svalue_gen svalue_gen

gen disc_gen = 0 
gen liberties_gen = 0 
gen crim_gen = 0 
gen econ_gen = 0 
gen powers_gen = 0 

replace disc_gen = 1 if svalue ==1
replace liberties_gen = 1 if svalue ==2 | svalue ==3
replace crim_gen = 1 if svalue ==4
replace econ_gen = 1 if svalue > 4 & svalue < 9
replace powers_gen = 1 if svalue > 8




********************************************************************************
********************************************************************************
********************************************************************************
* Natural courts and their dummies
* Number of years the natural court has been consistent 
********************************************************************************
********************************************************************************
********************************************************************************





gen 	Vinson1	 = 0
gen 	Vinson3	 = 0

gen 	Warren1	 = 0
gen 	Warren2	 = 0
gen 	Warren3	 = 0

gen 	Warren4	 = 0
gen 	Warren5	 = 0

gen 	Warren6	 = 0

gen 	Warren7	 = 0
gen 	Warren8	 = 0

gen 	Warren9	 = 0

gen 	Warren10	 = 0
gen 	Warren11	 = 0

gen 	Burger1	 = 0
gen 	Burger2	 = 0

gen 	Burger3	 = 0
gen 	Burger4	 = 0


gen 	Burger5	 = 0
gen 	Burger6	 = 0


gen 	Burger7	 = 0


gen 	Rehnquist1	 = 0
gen 	Rehnquist2	 = 0
gen 	Rehnquist3	 = 0


gen 	Rehnquist4	 = 0
gen 	Rehnquist5	 = 0


gen 	Rehnquist6	 = 0
gen 	Rehnquist7	 = 0


gen 	Roberts1	 = 0
gen 	Roberts2	 = 0


gen 	Roberts3	 = 0
gen 	Roberts4	 = 0


gen 	Roberts5	 = 0


gen 	Roberts6	 = 0


gen 	Roberts7	 = 0

gen 	Roberts9	 = 0


replace 	Vinson1	= 1 if 	naturalCourt==	 	1301
replace 	Vinson3	= 1 if 	naturalCourt==	 	1303
replace 	Vinson3	= 1 if 	naturalCourt==	 	1303
replace 	Vinson3	= 1 if 	naturalCourt==	 	1303
replace 	Vinson3	= 1 if 	naturalCourt==	 	1303
replace 	Warren1	= 1 if 	naturalCourt==	 	1401
replace 	Warren2	= 1 if 	naturalCourt==	 	1402
replace 	Warren3	= 1 if 	naturalCourt==	 	1403
replace 	Warren3	= 1 if 	naturalCourt==	 	1403
replace 	Warren3	= 1 if 	naturalCourt==	 	1403
replace 	Warren4	= 1 if 	naturalCourt==	 	1404
replace 	Warren5	= 1 if 	naturalCourt==	 	1405
replace 	Warren5	= 1 if 	naturalCourt==	 	1405
replace 	Warren5	= 1 if 	naturalCourt==	 	1405
replace 	Warren6	= 1 if 	naturalCourt==	 	1406
replace 	Warren6	= 1 if 	naturalCourt==	 	1406
replace 	Warren6	= 1 if 	naturalCourt==	 	1406
replace 	Warren6	= 1 if 	naturalCourt==	 	1406
replace 	Warren7	= 1 if 	naturalCourt==	 	1407
replace 	Warren8	= 1 if 	naturalCourt==	 	1408
replace 	Warren8	= 1 if 	naturalCourt==	 	1408
replace 	Warren8	= 1 if 	naturalCourt==	 	1408
replace 	Warren9	= 1 if 	naturalCourt==	 	1409
replace 	Warren9	= 1 if 	naturalCourt==	 	1409
replace 	Warren10	= 1 if 	naturalCourt==	 	1410
replace 	Warren10	= 1 if 	naturalCourt==	 	1410
replace 	Warren11	= 1 if 	naturalCourt==	 	1411
replace 	Burger1	= 1 if 	naturalCourt==	 	1501
replace 	Burger2	= 1 if 	naturalCourt==	 	1502
replace 	Burger2	= 1 if 	naturalCourt==	 	1502
replace 	Burger3	= 1 if 	naturalCourt==	 	1503
replace 	Burger4	= 1 if 	naturalCourt==	 	1504
replace 	Burger4	= 1 if 	naturalCourt==	 	1504
replace 	Burger4	= 1 if 	naturalCourt==	 	1504
replace 	Burger4	= 1 if 	naturalCourt==	 	1504
replace 	Burger4	= 1 if 	naturalCourt==	 	1504
replace 	Burger5	= 1 if 	naturalCourt==	 	1505
replace 	Burger6	= 1 if 	naturalCourt==	 	1506
replace 	Burger6	= 1 if 	naturalCourt==	 	1506
replace 	Burger6	= 1 if 	naturalCourt==	 	1506
replace 	Burger6	= 1 if 	naturalCourt==	 	1506
replace 	Burger6	= 1 if 	naturalCourt==	 	1506
replace 	Burger6	= 1 if 	naturalCourt==	 	1506
replace 	Burger7	= 1 if 	naturalCourt==	 	1507
replace 	Burger7	= 1 if 	naturalCourt==	 	1507
replace 	Burger7	= 1 if 	naturalCourt==	 	1507
replace 	Burger7	= 1 if 	naturalCourt==	 	1507
replace 	Burger7	= 1 if 	naturalCourt==	 	1507
replace 	Rehnquist1	= 1 if 	naturalCourt==	 	1601
replace 	Rehnquist2	= 1 if 	naturalCourt==	 	1602
replace 	Rehnquist3	= 1 if 	naturalCourt==	 	1603
replace 	Rehnquist3	= 1 if 	naturalCourt==	 	1603
replace 	Rehnquist3	= 1 if 	naturalCourt==	 	1603
replace 	Rehnquist4	= 1 if 	naturalCourt==	 	1604
replace 	Rehnquist5	= 1 if 	naturalCourt==	 	1605
replace 	Rehnquist5	= 1 if 	naturalCourt==	 	1605
replace 	Rehnquist6	= 1 if 	naturalCourt==	 	1606
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Rehnquist7	= 1 if 	naturalCourt==	 	1607
replace 	Roberts1	= 1 if 	naturalCourt==	 	1701
replace 	Roberts2	= 1 if 	naturalCourt==	 	1702
replace 	Roberts2	= 1 if 	naturalCourt==	 	1702
replace 	Roberts2	= 1 if 	naturalCourt==	 	1702
replace 	Roberts2	= 1 if 	naturalCourt==	 	1702
replace 	Roberts3	= 1 if 	naturalCourt==	 	1703
replace 	Roberts4	= 1 if 	naturalCourt==	 	1704
replace 	Roberts4	= 1 if 	naturalCourt==	 	1704
replace 	Roberts4	= 1 if 	naturalCourt==	 	1704
replace 	Roberts4	= 1 if 	naturalCourt==	 	1704
replace 	Roberts4	= 1 if 	naturalCourt==	 	1704
replace 	Roberts4	= 1 if 	naturalCourt==	 	1704
replace 	Roberts4	= 1 if 	naturalCourt==	 	1704
replace 	Roberts5	= 1 if 	naturalCourt==	 	1705
replace 	Roberts5	= 1 if 	naturalCourt==	 	1705
replace 	Roberts6	= 1 if 	naturalCourt==	 	1706
replace 	Roberts6	= 1 if 	naturalCourt==	 	1706
replace 	Roberts6	= 1 if 	naturalCourt==	 	1706
replace 	Roberts7	= 1 if 	naturalCourt==	 	1707
replace 	Roberts7	= 1 if 	naturalCourt==	 	1707
replace 	Roberts9	= 1 if 	naturalCourt==	 	1709
replace 	Roberts9	= 1 if 	naturalCourt==	 	1709


*The purpose of this is to show that there are more 5-4 decisions when 
*the same justices have been on the court together for longer
gen years_same_court = .

replace 	years_same_court = 0 if 	naturalCourt == 	 1301	& term == 	1946
replace 	years_same_court = 1 if 	naturalCourt == 	 1301	& term == 	1947
replace 	years_same_court = 2 if 	naturalCourt == 	 1301	& term == 	1948
replace 	years_same_court = 0 if 	naturalCourt == 	 1303	& term == 	1949
replace 	years_same_court = 1 if 	naturalCourt == 	 1303	& term == 	1950
replace 	years_same_court = 2 if 	naturalCourt == 	 1303	& term == 	1951
replace 	years_same_court = 3 if 	naturalCourt == 	 1303	& term == 	1952
replace 	years_same_court = 0 if 	naturalCourt == 	 1401	& term == 	1953
replace 	years_same_court = 0 if 	naturalCourt == 	 1402	& term == 	1954
replace 	years_same_court = 0 if 	naturalCourt == 	 1403	& term == 	1954
replace 	years_same_court = 1 if 	naturalCourt == 	 1403	& term == 	1955
replace 	years_same_court = 2 if 	naturalCourt == 	 1403	& term == 	1956
replace 	years_same_court = 0 if 	naturalCourt == 	 1404	& term == 	1956
replace 	years_same_court = 0 if 	naturalCourt == 	 1405	& term == 	1956
replace 	years_same_court = 1 if 	naturalCourt == 	 1405	& term == 	1957
replace 	years_same_court = 2 if 	naturalCourt == 	 1405	& term == 	1958
replace 	years_same_court = 0 if 	naturalCourt == 	 1406	& term == 	1958
replace 	years_same_court = 1 if 	naturalCourt == 	 1406	& term == 	1959
replace 	years_same_court = 2 if 	naturalCourt == 	 1406	& term == 	1960
replace 	years_same_court = 3 if 	naturalCourt == 	 1406	& term == 	1961
replace 	years_same_court = 0 if 	naturalCourt == 	 1407	& term == 	1961
replace 	years_same_court = 0 if 	naturalCourt == 	 1408	& term == 	1962
replace 	years_same_court = 1 if 	naturalCourt == 	 1408	& term == 	1963
replace 	years_same_court = 2 if 	naturalCourt == 	 1408	& term == 	1964
replace 	years_same_court = 0 if 	naturalCourt == 	 1409	& term == 	1965
replace 	years_same_court = 1 if 	naturalCourt == 	 1409	& term == 	1966
replace 	years_same_court = 0 if 	naturalCourt == 	 1410	& term == 	1967
replace 	years_same_court = 1 if 	naturalCourt == 	 1410	& term == 	1968
replace 	years_same_court = 0 if 	naturalCourt == 	 1411	& term == 	1968
replace 	years_same_court = 0 if 	naturalCourt == 	 1501	& term == 	1969
replace 	years_same_court = 0 if 	naturalCourt == 	 1502	& term == 	1969
replace 	years_same_court = 1 if 	naturalCourt == 	 1502	& term == 	1970
replace 	years_same_court = 0 if 	naturalCourt == 	 1503	& term == 	1971
replace 	years_same_court = 0 if 	naturalCourt == 	 1504	& term == 	1971
replace 	years_same_court = 1 if 	naturalCourt == 	 1504	& term == 	1972
replace 	years_same_court = 2 if 	naturalCourt == 	 1504	& term == 	1973
replace 	years_same_court = 3 if 	naturalCourt == 	 1504	& term == 	1974
replace 	years_same_court = 4 if 	naturalCourt == 	 1504	& term == 	1975
replace 	years_same_court = 0 if 	naturalCourt == 	 1505	& term == 	1975
replace 	years_same_court = 1 if 	naturalCourt == 	 1506	& term == 	1975
replace 	years_same_court = 2 if 	naturalCourt == 	 1506	& term == 	1976
replace 	years_same_court = 3 if 	naturalCourt == 	 1506	& term == 	1977
replace 	years_same_court = 4 if 	naturalCourt == 	 1506	& term == 	1978
replace 	years_same_court = 5 if 	naturalCourt == 	 1506	& term == 	1979
replace 	years_same_court = 6 if 	naturalCourt == 	 1506	& term == 	1980
replace 	years_same_court = 0 if 	naturalCourt == 	 1507	& term == 	1981
replace 	years_same_court = 1 if 	naturalCourt == 	 1507	& term == 	1982
replace 	years_same_court = 2 if 	naturalCourt == 	 1507	& term == 	1983
replace 	years_same_court = 3 if 	naturalCourt == 	 1507	& term == 	1984
replace 	years_same_court = 4 if 	naturalCourt == 	 1507	& term == 	1985
replace 	years_same_court = 0 if 	naturalCourt == 	 1601	& term == 	1986
replace 	years_same_court = 1 if 	naturalCourt == 	 1602	& term == 	1987
replace 	years_same_court = 0 if 	naturalCourt == 	 1603	& term == 	1987
replace 	years_same_court = 1 if 	naturalCourt == 	 1603	& term == 	1988
replace 	years_same_court = 2 if 	naturalCourt == 	 1603	& term == 	1989
replace 	years_same_court = 0 if 	naturalCourt == 	 1604	& term == 	1990
replace 	years_same_court = 0 if 	naturalCourt == 	 1605	& term == 	1991
replace 	years_same_court = 1 if 	naturalCourt == 	 1605	& term == 	1992
replace 	years_same_court = 0 if 	naturalCourt == 	 1606	& term == 	1993
replace 	years_same_court = 0 if 	naturalCourt == 	 1607	& term == 	1994
replace 	years_same_court = 1 if 	naturalCourt == 	 1607	& term == 	1995
replace 	years_same_court = 2 if 	naturalCourt == 	 1607	& term == 	1996
replace 	years_same_court = 3 if 	naturalCourt == 	 1607	& term == 	1997
replace 	years_same_court = 4 if 	naturalCourt == 	 1607	& term == 	1998
replace 	years_same_court = 5 if 	naturalCourt == 	 1607	& term == 	1999
replace 	years_same_court = 6 if 	naturalCourt == 	 1607	& term == 	2000
replace 	years_same_court = 7 if 	naturalCourt == 	 1607	& term == 	2001
replace 	years_same_court = 8 if 	naturalCourt == 	 1607	& term == 	2002
replace 	years_same_court = 9 if 	naturalCourt == 	 1607	& term == 	2003
replace 	years_same_court = 10 if 	naturalCourt == 	 1607	& term == 	2004
replace 	years_same_court = 0 if 	naturalCourt == 	 1701	& term == 	2005
replace 	years_same_court = 0 if 	naturalCourt == 	 1702	& term == 	2005
replace 	years_same_court = 1 if 	naturalCourt == 	 1702	& term == 	2006
replace 	years_same_court = 2 if 	naturalCourt == 	 1702	& term == 	2007
replace 	years_same_court = 3 if 	naturalCourt == 	 1702	& term == 	2008
replace 	years_same_court = 0 if 	naturalCourt == 	 1703	& term == 	2009
replace 	years_same_court = 0 if 	naturalCourt == 	 1704	& term == 	2009
replace 	years_same_court = 1 if 	naturalCourt == 	 1704	& term == 	2010
replace 	years_same_court = 2 if 	naturalCourt == 	 1704	& term == 	2011
replace 	years_same_court = 3 if 	naturalCourt == 	 1704	& term == 	2012
replace 	years_same_court = 4 if 	naturalCourt == 	 1704	& term == 	2013
replace 	years_same_court = 5 if 	naturalCourt == 	 1704	& term == 	2014
replace 	years_same_court = 6 if 	naturalCourt == 	 1704	& term == 	2015
replace 	years_same_court = 0 if 	naturalCourt == 	 1705	& term == 	2015
replace 	years_same_court = 1 if 	naturalCourt == 	 1705	& term == 	2016
replace 	years_same_court = 0 if 	naturalCourt == 	 1706	& term == 	2016
replace 	years_same_court = 1 if 	naturalCourt == 	 1706	& term == 	2017
replace 	years_same_court = 2 if 	naturalCourt == 	 1706	& term == 	2018
replace 	years_same_court = 0 if 	naturalCourt == 	 1707	& term == 	2018
replace 	years_same_court = 1 if 	naturalCourt == 	 1707	& term == 	2019
replace 	years_same_court = 0 if 	naturalCourt == 	 1709	& term == 	2020
replace 	years_same_court = 1 if 	naturalCourt == 	 1709	& term == 	2021


tab chief , gen(Chiefdummy)



rename Chiefdummy1 burger
rename Chiefdummy2 rehnquist
rename Chiefdummy3 roberts
rename Chiefdummy4 vinson
rename Chiefdummy5 warren 

********************************************************************************
********************************************************************************
********************************************************************************
* Case outcomes 
********************************************************************************
********************************************************************************
********************************************************************************


********************************************************************************
* Liberal v. conserative outcomes, and the outcome in relation 
* to the lower court's outcome 
********************************************************************************



********************************************************************************
* It is a proven scientific fact that I will never remember the direction of decisionDirection
* So, I am generating a variable that is called it either lib or conservative.
* In the justice data, I call it "justice_lib, etc." 
********************************************************************************



gen lib = 0 if decisionDirection == 1
replace lib = 1 if decisionDirection == 2
replace lib = .5 if decisionDirection == 3

label define lib 0 "Conservative" 1 "Liberal"
label values lib lib

gen con = (lib*-1)+1

label define con 1 "Conservative" 0 "Liberal"
label values con con 

gen lib_lct = 0 if lcDispositionDirection == 1
replace lib_lct = 1 if lcDispositionDirection == 2
replace lib_lct = .5 if lcDispositionDirection == 3
label values lib_lct lib

gen con_lct = (lib_lct*-1)+1

label values con_lct con 



********************************************************************************
* how split the outcome is
********************************************************************************


* n54 n56 n63 n78 n81 n72 unam 


********************************************************************************
********************************************************************************
********************************************************************************
* Note, it wasn"t straightforward for how to code some of them - like is a 4-2 more like a 7-2 or 6-3? 

* So, I put all the #-1 together into the 8-1 category, based on the idea that there is a single dissent 
* And then I created less granular categories of 56- which is 3 or 4 dissents, and 78 which is 1-2 dissents 
********************************************************************************
********************************************************************************
********************************************************************************

gen  vote_coalition =  (majVotes * 10) + minVotes
label var vote_coalition "Coalition size: maj-min == majmin" 

gen n54= 0 
gen n56= 0 
gen n63= 0 
gen n78= 0 
gen n81= 0 
gen n72= 0 
gen unam= 0 

replace n54 = 1 if (vote_coalition == 33 | vote_coalition == 43 | vote_coalition == 44 | vote_coalition == 54) 
label var n54 "Split of 0,1: 5-4, 3-3, 4-3, 4-4"

replace n63 = 1 if (vote_coalition == 42 | vote_coalition == 52 | vote_coalition == 53 | vote_coalition == 63) 
label var n63 "Split of 2,3: 6-3, 4-2, 5-2, 5-3, but NOT 4-1"

replace n72 = 1 if (vote_coalition == 72 | vote_coalition == 62)
label var n72 "Split of 4,5: 7-2, 6-2, but NOT 5-1"

replace n81 = 1 if (vote_coalition == 81 | vote_coalition == 41 | vote_coalition == 51 | vote_coalition == 61 | vote_coalition == 71 ) 

label var n81 "Split with lone dissent: 8-1, 4-1 5-1, 6-1, 7-1" 

replace unam = 1 if (vote_coalition == 50 | vote_coalition == 60 | vote_coalition == 70 | vote_coalition == 80 | vote_coalition == 90) 
label var unam "Unanimous vote outcome"  

replace n56 = 1 if n54 == 1 | n63 == 1 

label var n56 "Contentious: 3 or 4 dissenting, including 4-2 and 5-2"

replace n78 = 1 if n72 == 1 | n81 == 1 

label var n78  "Not as contentious: 1 or 2 dissenting" 


gen vote_contentious = 1 if unam ==1
replace vote_contentious = 2 if n81 ==1
replace vote_contentious = 3 if n72 ==1
replace vote_contentious = 4 if n63 ==1
replace vote_contentious = 5 if n54 ==1

label define vote_contentious 1 "1.Unanimous" 2 "2. 1 dissent" 3 "2 dissents" 4 "3 dissents" 5 "4 dissents" 
label values vote_contentious vote_contentious

********************************************************************************
* The number of each kind of split outcome by decisionDirection
* And each is computed, based on what it did with the lower court
* e.g. n54cl = number of 5-4 splits that take a conservative outcome from a lower court
* and decide it in a liberal direction 
********************************************************************************


gen n54c= 0 
gen n56c= 0 
gen n63c= 0 
gen n78c= 0 
gen n81c= 0 
gen n72c= 0 
gen unaml= 0 
gen unamc= 0 
gen n54l= 0 
gen n56l= 0 
gen n63l= 0 
gen n78l= 0 
gen n81l= 0 
gen n72l= 0 
gen n54cc= 0 
gen n56cc= 0 
gen n63cc= 0 
gen n78cc= 0 
gen n81cc= 0 
gen n72cc= 0 
gen unamcc= 0 
gen n54ll= 0 
gen n56ll= 0 
gen n63ll= 0 
gen n78ll= 0 
gen n81ll= 0 

gen n72ll= 0 
gen unamll= 0 
gen n54lc= 0 
gen n56lc= 0 
gen n63lc= 0 
gen n78lc= 0 
gen n81lc= 0 
gen n72lc= 0 
gen unamlc= 0 
gen n54cl= 0 
gen n56cl= 0 
gen n63cl= 0 
gen n78cl= 0 
gen n81cl= 0 
gen n72cl= 0 
gen unamcl= 0 






replace n54c = 1 if (n54 == 1 & decisionDirection == 1) 

replace n56c = 1 if (n56 == 1 & decisionDirection == 1) 

replace n63c = 1 if (n63 == 1 & decisionDirection == 1) 

replace n78c = 1 if (n78 == 1 & decisionDirection == 1) 

replace n81c = 1 if (n81 & decisionDirection == 1) 

replace n72c = 1 if (n72== 1 & decisionDirection == 1) 

replace unamc = 1 if (unam == 1 & decisionDirection == 1) 

replace n54l = 1 if (n54 == 1 & decisionDirection == 2) 

replace n56l = 1 if (n56 == 1 & decisionDirection == 2) 

replace n63l = 1 if (n63 == 1 & decisionDirection == 2) 

replace n78l = 1 if (n78 == 1 & decisionDirection == 2) 

replace n81l = 1 if (n81 & decisionDirection == 2) 

replace n72l = 1 if (n72== 1 & decisionDirection == 2) 

replace unaml = 1 if (unam == 1 & decisionDirection == 2) 

label var n54c "Conservative 5 4 decision"
label var n54l "Liberal 5 4 decision"

label var n56c "Conservative 5 4 or 6 3 decision"
label var n56l "Liberal 5 4 or 6 3 decision"

label var n63c "Conservative 6 3 decision"
label var n63l "Liberal 6 3 decision"

label var n78c "Conservative 7 2 or 8 1 decision"
label var n78l "Liberal 7 2 or 8 1 decision"

label var n72c "Conservative 7 2 decision"
label var n72l "Liberal 7 2 decision"

label var n81c "Conservative 7 2 or 8 1 decision"
label var n81l "Liberal 7 2 or 8 1 decision"

label var unamc "Conservative unanimous decision"
label var unaml "Liberal unanimous decision"


********************************************************************************
* different outcomes based on lower court outcomes
********************************************************************************




replace n54cc = 1 if (n54 == 1 & decisionDirection == 1 & lcDispositionDirection == 1) 

replace n56cc = 1 if (n56 == 1 & decisionDirection == 1 & lcDispositionDirection == 1) 

replace n63cc = 1 if (n63 == 1 & decisionDirection == 1 & lcDispositionDirection == 1) 

replace n78cc = 1 if (n78 == 1 & decisionDirection == 1 & lcDispositionDirection == 1) 

replace n81cc = 1 if (n81 == 1 & decisionDirection == 1 & lcDispositionDirection == 1) 

replace n72cc = 1 if (n72== 1 & decisionDirection == 1 & lcDispositionDirection == 1) 

replace unamcc = 1 if (unam == 1 & decisionDirection == 1 & lcDispositionDirection == 1) 


replace n54lc = 1 if (n54 == 1 & decisionDirection == 1 & lcDispositionDirection == 2) 

replace n56lc = 1 if (n56 == 1 & decisionDirection == 1 & lcDispositionDirection == 2) 

replace n63lc = 1 if (n63 == 1 & decisionDirection == 1 & lcDispositionDirection == 2) 

replace n78lc = 1 if (n78 == 1 & decisionDirection == 1 & lcDispositionDirection == 2) 

replace n81lc = 1 if (n81 == 1 & decisionDirection == 1 & lcDispositionDirection == 2) 

replace n72lc = 1 if (n72== 1 & decisionDirection == 1 & lcDispositionDirection == 2) 

replace unamlc = 1 if (unam == 1 & decisionDirection == 1 & lcDispositionDirection == 2) 


replace n54ll = 1 if (n54 == 1 & decisionDirection == 2 & lcDispositionDirection == 2) 

replace n56ll = 1 if (n56 == 1 & decisionDirection == 2 & lcDispositionDirection == 2) 

replace n63ll = 1 if (n63 == 1 & decisionDirection == 2 & lcDispositionDirection == 2) 

replace n78ll = 1 if (n78 == 1 & decisionDirection == 2 & lcDispositionDirection == 2) 

replace n81ll = 1 if (n81 == 1 & decisionDirection == 2 & lcDispositionDirection == 2) 

replace n72ll = 1 if (n72== 1 & decisionDirection == 2 & lcDispositionDirection == 2) 

replace unamll = 1 if (unam == 1 & decisionDirection == 2 & lcDispositionDirection == 2) 


replace n54cl = 1 if (n54 == 1 & decisionDirection == 2 & lcDispositionDirection == 1) 

replace n56cl = 1 if (n56 == 1 & decisionDirection == 2 & lcDispositionDirection == 1) 

replace n63cl = 1 if (n63 == 1 & decisionDirection == 2 & lcDispositionDirection == 1) 

replace n78cl = 1 if (n78 == 1 & decisionDirection == 2 & lcDispositionDirection == 1) 

replace n81cl = 1 if (n81 == 1 & decisionDirection == 2 & lcDispositionDirection == 1) 

replace n72cl = 1 if (n72== 1 & decisionDirection == 2 & lcDispositionDirection == 1) 

replace unamcl = 1 if (unam == 1 & decisionDirection == 2 & lcDispositionDirection == 1) 









label var n54cc "Conservative 5 4 decision from a conservative lower court decision"
label var n54cl "Liberal 5 4 decision from a conservative lower court decision"
label var n54lc "Conservative 5 4 decision from a liberal lower court decision"
label var n54ll "Liberal 5 4 decision from a liberal lower court decision"


label var n56cc "Conservative 5 4 or 6 3 decision from a conservative lower court decision"
label var n56cl "Liberal 5 4 or 6 3 decision from a conservative lower court decision"
label var n56lc "Conservative 5 4 or 6 3 decision from a liberal lower court decision"
label var n56ll "Liberal 5 4 or 6 3 decision from a liberal lower court decision"


label var n63cc "Conservative decision from a conservative lower court 6 3 decision"
label var n63cl "Liberal 6 3 decision from a conservative lower court decision"
label var n63lc "Conservative 6 3 decision from a liberal lower court decision"
label var n63ll "Liberal 6 3 decision from a liberal lower court decision"


label var n78cc "Conservative 7 2 or 8 1 decision from a conservative lower court decision"
label var n78cl "Liberal 7 2 or 8 1 decision from a conservative lower court decision"
label var n78lc "Conservative 7 2 or 8 1 decision from a liberal lower court decision"
label var n78ll "Liberal 7 2 or 8 1 decision from a liberal lower court decision"

label var n81cc "Conservative 8 1 decision from a conservative lower court decision"
label var n81cl "Liberal 8 1 decision from a conservative lower court decision"
label var n81lc "Conservative 8 1 decision from a liberal lower court decision"
label var n81ll "Liberal 8 1 decision from a liberal lower court decision"

label var n72cc "Conservative 7 2 decision from a conservative lower court decision"
label var n72cl "Liberal 7 2 decision from a conservative lower court decision"
label var n72lc "Conservative 7 2 decision from a conservative lower court decision"
label var n72ll "Liberal 7 2 decision from a liberal lower court decision"


label var unamcc "Conservative unanimous decision from a conservative lower court decision"
label var unamcl "Liberal unanimous decision from a conservative lower court decision"
label var unamlc "Conservative unanimous decision from a liberal lower court decision"
label var unamll "Liberal unanimous decision from a liberal lower court decision"


********************************************************************************
********************************************************************************
********************************************************************************
* Direct measures of salience: what the Court does with the case  
********************************************************************************
********************************************************************************
********************************************************************************


********************************************************************************
* Declaration of unconstitutionality  
********************************************************************************


gen uncon = 0
gen muni = 0
gen state = 0
gen fed = 0
gen unconl = 0
gen unconc = 0
gen munic = 0
gen munil = 0
gen fedl = 0
gen fedc = 0
gen statel = 0
gen statec = 0



replace 	muni	=	1	if	declarationUncon	==	4
replace 	state	=	1	if	declarationUncon	==	3
replace 	fed		=	1	if	declarationUncon	==	2
replace 	uncon	=	1	if	declarationUncon	>	1



replace 	unconl	=	1	if	decisionDirection	==	2	&	uncon	==	1		
replace 	unconc	=	1	if	decisionDirection	==	1	&	uncon	==	1	

replace 	munil	=	1	if	decisionDirection	==	2	&	muni	==	1		
replace 	munic	=	1	if	decisionDirection	==	1	&	muni	==	1	


replace 	fedl	=	1	if	decisionDirection	==	2	&	fed	==	1	
replace 	fedc	=	1	if	decisionDirection	==	1	&	fed	==	1	


replace 	statel	=	1	if	decisionDirection	==	2	&	state	==	1	
replace 	statec	=	1	if	decisionDirection	==	1	&	state	==	1	

label var uncon "Any declaration of unconstitutionality"
label var muni "Municipal declaration of unconstitutionality"
label var fed "Federal declaration of unconstitutionality"
label var state "State declaration of unconstitutionality"

label var unconl "Liberal declaration of unconstitutionality"
label var unconc "Conservative declaration of unconstitutionality"

label var munil "Liberal municipal declaration of unconstitutionality"
label var munic "Conservative municipal declaration of unconstitutionality"

label var fedl "Liberal federal declaration of unconstitutionality"
label var fedc "Conservative federal declaration of unconstitutionality"
label var statel "Liberal state declaration of unconstitutionality"
label var statec "Conservative state declaration of unconstitutionality"



********************************************************************************
* Legal change: reversals and alteration of precedent   
********************************************************************************


gen rev = 0
replace rev = 1 if caseDisposition == 3 | caseDisposition == 4 | caseDisposition == 5


gen revl = 0
replace revl = 1 if (decisionDirection == 2 & rev == 1)

gen revc = 0
replace revc = 1 if (decisionDirection == 1 & rev == 2)




label var rev "lower court reversal"
label define rev 0 "lower court decision same ideological outcome as sc" 1 "lower court reversal different ideological outcome as sc"

label var revl "lower court conservative SC liberal"
label define revl 0 "lower court not more conservative than SC" 1 "lower court conservative SC liberal"

label var revc "lower court liberal SC conservative"
label define revc 0 "lower court not more liberal than SC" 1 "lower court liberal SC conservative"




clonevar prec = precedentAlteration


gen precc = 0
gen precl = 0

 
replace precl = 1 if prec == 1 & decisionDirection == 2


 
replace precc = 1 if prec == 1 & decisionDirection == 1

label var prec "Formal alteration of precedent"
label define prec 0 "No formal alteration of precedent" 1 "Formal alteration of precedent"
label values prec prec

label var precc "Conservative alteration of precedent"
label var precl "Liberal alteration of precedent"

********************************************************************************
* Salience measured as the reason for cert being what they 
* consider an important question   
********************************************************************************


********************************************************************************
* Though I am not sure that Justices do not pretend that they have to decide a 
* case by blaming it on conflict or confusion, I thought it would be good to record 
* when they say outright that they are taking the case because they think it 
* is a significant question 
********************************************************************************

* Here is the documentation taken from the codebook

* 1	case did not arise on cert or cert not granted
* 2	federal court conflict
* 3	federal court conflict and to resolve important or significant question
* 4	putative conflict
* 5	conflict between federal court and state court
* 6	state court conflict
* 7	federal court confusion or uncertainty
* 8	state court confusion or uncertainty
* 9	federal court and state court confusion or uncertainty
* 10	to resolve important or significant question
* 11	to resolve question presented
* 12	no reason given
* 13	other reason* 

* Here are the frequencies 
* tab certReason
* 
*       reason for granting cert |      Freq.     Percent        Cum.
* -------------------------------+-----------------------------------
*                        no cert |      1,727       19.04       19.04
*            Fed. court conflict |      1,352       14.91       33.95
* Fed. ct. conflict, sig. quest. |        187        2.06       36.01
*              putative conflict |        128        1.41       37.42
*   Fed. ct., state ct. conflict |        107        1.18       38.60
*           state court conflict |         41        0.45       39.05
*           Fed. court confusion |         41        0.45       39.50
*          state court confusion |          5        0.06       39.56
* Fed. ct., state ct. confusion  |         14        0.15       39.71
*           significant question |        776        8.56       48.27
*             question presented |      1,334       14.71       62.98
*                no reason given |      3,270       36.05       99.03
*                   other reason |         88        0.97      100.00
* -------------------------------+-----------------------------------
*                          Total |      9,070      100.00
********************************************************************************


gen cert_cat = certReason
recode cert_cat (1=1) (2=2) (3=2) (4=2) (5=2) (6=2) (10=3) (11=4) (12=5) (7=6) (8=6) (9=6) (13 = 6)
label var cert_cat "Certiorari reduced category"


label define  cert_cat 1 "No cert" 2 "Conflict" 3 "Significant question" 4 "To resolve question presented" 5 "No reason given" 6 "Other"
label values cert_cat cert_cat

gen cert_sal = 0

 
replace cert_sal = 1 if cert_cat == 3 | cert_cat == 4

label var cert_sal "Salience of case based on cert reason (conflict or significant question)"




********************************************************************************
********************************************************************************
********************************************************************************
* Source and origin variables 
********************************************************************************
********************************************************************************
********************************************************************************

* vars: add circuit spec 

* source_cat_gen source_circ source_district source_state source_circuit_spec


gen source_cat_gen = 1
replace source_cat_gen = 2 if caseSource > 40
replace source_cat_gen = 3 if caseSource > 299

label define source_cat_gen 1 "Federal Circuit" 2 "Federal district court" 3 "State court"


label values  source_cat_gen source_cat_gen
label var source_cat_gen "Court in which case is initially filed"



tab source_cat_gen, gen (source_cat_gen)

rename source_cat_gen1 source_circ
rename source_cat_gen2 source_district
rename source_cat_gen3 source_state



gen source_circuit_spec = 0
replace source_circuit_spec = 1 if caseSource==21
replace source_circuit_spec = 2 if caseSource==22
replace source_circuit_spec = 3 if caseSource==23
replace source_circuit_spec = 4 if caseSource==24
replace source_circuit_spec = 5 if caseSource==25
replace source_circuit_spec = 6 if caseSource==26
replace source_circuit_spec = 7 if caseSource==27
replace source_circuit_spec = 8 if caseSource==28
replace source_circuit_spec = 9 if caseSource==29
replace source_circuit_spec = 10 if caseSource==30
replace source_circuit_spec = 11 if caseSource==31
replace source_circuit_spec = 12 if caseSource==32
replace source_circuit_spec = 13 if caseSource < 20


label define source_circuit_spec 0 "0.Not circuit: state or federal district court"  /// 
								1 "1.First Circuit"  /// 
								2 "2.Second Circuit"  /// 
								3 "3.Third Circuit"  /// 
								4 "4.Fourth Circuit"  /// 
								5 "5.Fifth Circuit"  /// 
								6 "6.Sixth Circuit"  /// 
								7 "7.Seventh Circuit"  /// 
								8 "8.Eighth Circuit"  /// 
								9 "9.Ninth Circuit"  /// 
								10 "10.Tenth Circuit"  /// 
								11 "11.Eleventh Circuit"  /// 
								12 "12.D.C. Circuit"  ///
								13 "13.Other Circuit"  

label values source_circuit_spec source_circuit_spec

tab source_circuit_spec if source_circuit_spec > 0, gen (source_circuit_spec) 

rename source_circuit_spec1 FirstCircuit
rename source_circuit_spec2 SecondCircuit
rename source_circuit_spec3 ThirdCircuit
rename source_circuit_spec4 FourthCircuit
rename source_circuit_spec5 FifthCircuit
rename source_circuit_spec6 SixthCircuit
rename source_circuit_spec7 SeventhCircuit
rename source_circuit_spec8 EighthCircuit
rename source_circuit_spec9 NinthCircuit
rename source_circuit_spec10 TenthCircuit
rename source_circuit_spec11 EleventhCircuit
rename source_circuit_spec12 DCCircuit
rename source_circuit_spec13 OtherCircuit


gen origin_cat = 1
replace origin_cat = 2 if caseOrigin > 40
replace origin_cat = 3 if caseOrigin > 299

label define origin_cat 1 "Federal Circuit" 2 "Federal district court" 3 "State court"


label values  origin_cat origin_cat
label var origin_cat "Court in which case is initially filed"



tab origin_cat, gen (origin)

rename origin1 origin_circ
rename origin2 origin_district
rename origin3 origin_state




clonevar lawtype_cat = lawType
replace lawtype_cat = 4 if lawType > 3


gen const_type = 0
replace const_type = 1 if lawtype <3

gen nonconst_type = 0
replace nonconst_type = 1 if lawtype >2

********************************************************************************
********************************************************************************
********************************************************************************
* The following creates party variables 
********************************************************************************
********************************************************************************
********************************************************************************



generate 	pet_code	=	1 	if	petitioner	 ==	1
replace 	pet_code	=	2 	if	petitioner	 ==	2
replace 	pet_code	=	3 	if	petitioner	 ==	3
replace 	pet_code	=	2 	if	petitioner	 ==	4
replace 	pet_code	=	3 	if	petitioner	 ==	5
replace 	pet_code	=	4 	if	petitioner	 ==	6
replace 	pet_code	=	2 	if	petitioner	 ==	7
replace 	pet_code	=	6 	if	petitioner	 ==	8
replace 	pet_code	=	6 	if	petitioner	 ==	9
replace 	pet_code	=	6 	if	petitioner	 ==	10
replace 	pet_code	=	6 	if	petitioner	 ==	11
replace 	pet_code	=	1 	if	petitioner	 ==	12
replace 	pet_code	=	6 	if	petitioner	 ==	13
replace 	pet_code	=	1 	if	petitioner	 ==	14
replace 	pet_code	=	1 	if	petitioner	 ==	15
replace 	pet_code	=	4 	if	petitioner	 ==	16
replace 	pet_code	=	2 	if	petitioner	 ==	17
replace 	pet_code	=	3 	if	petitioner	 ==	18
replace 	pet_code	=	1 	if	petitioner	 ==	19
replace 	pet_code	=	4 	if	petitioner	 ==	20
replace 	pet_code	=	3 	if	petitioner	 ==	21
replace 	pet_code	=	1 	if	petitioner	 ==	22
replace 	pet_code	=	1 	if	petitioner	 ==	23
replace 	pet_code	=	8 	if	petitioner	 ==	24
replace 	pet_code	=	6 	if	petitioner	 ==	25
replace 	pet_code	=	2 	if	petitioner	 ==	26
replace 	pet_code	=	1 	if	petitioner	 ==	27
replace 	pet_code	=	2 	if	petitioner	 ==	28
replace 	pet_code	=	5 	if	petitioner	 ==	100
replace 	pet_code	=	5 	if	petitioner	 ==	101
replace 	pet_code	=	6 	if	petitioner	 ==	102
replace 	pet_code	=	5 	if	petitioner	 ==	103
replace 	pet_code	=	5 	if	petitioner	 ==	104
replace 	pet_code	=	5 	if	petitioner	 ==	105
replace 	pet_code	=	6 	if	petitioner	 ==	106
replace 	pet_code	=	5 	if	petitioner	 ==	107
replace 	pet_code	=	5 	if	petitioner	 ==	108
replace 	pet_code	=	5 	if	petitioner	 ==	109
replace 	pet_code	=	6 	if	petitioner	 ==	110
replace 	pet_code	=	9 	if	petitioner	 ==	111
replace 	pet_code	=	9 	if	petitioner	 ==	112
replace 	pet_code	=	5 	if	petitioner	 ==	113
replace 	pet_code	=	9 	if	petitioner	 ==	114
replace 	pet_code	=	5 	if	petitioner	 ==	115
replace 	pet_code	=	9 	if	petitioner	 ==	116
replace 	pet_code	=	5 	if	petitioner	 ==	117
replace 	pet_code	=	5 	if	petitioner	 ==	118
replace 	pet_code	=	5 	if	petitioner	 ==	119
replace 	pet_code	=	5 	if	petitioner	 ==	120
replace 	pet_code	=	5 	if	petitioner	 ==	121
replace 	pet_code	=	5 	if	petitioner	 ==	122
replace 	pet_code	=	5 	if	petitioner	 ==	123
replace 	pet_code	=	5 	if	petitioner	 ==	124
replace 	pet_code	=	5 	if	petitioner	 ==	125
replace 	pet_code	=	6 	if	petitioner	 ==	126
replace 	pet_code	=	9 	if	petitioner	 ==	127
replace 	pet_code	=	5 	if	petitioner	 ==	128
replace 	pet_code	=	6 	if	petitioner	 ==	129
replace 	pet_code	=	7 	if	petitioner	 ==	130
replace 	pet_code	=	5 	if	petitioner	 ==	131
replace 	pet_code	=	5 	if	petitioner	 ==	132
replace 	pet_code	=	5 	if	petitioner	 ==	133
replace 	pet_code	=	6 	if	petitioner	 ==	134
replace 	pet_code	=	5 	if	petitioner	 ==	135
replace 	pet_code	=	6 	if	petitioner	 ==	136
replace 	pet_code	=	6 	if	petitioner	 ==	137
replace 	pet_code	=	6 	if	petitioner	 ==	138
replace 	pet_code	=	5 	if	petitioner	 ==	139
replace 	pet_code	=	6 	if	petitioner	 ==	140
replace 	pet_code	=	5 	if	petitioner	 ==	141
replace 	pet_code	=	6 	if	petitioner	 ==	142
replace 	pet_code	=	5 	if	petitioner	 ==	143
replace 	pet_code	=	5 	if	petitioner	 ==	144
replace 	pet_code	=	6 	if	petitioner	 ==	145
replace 	pet_code	=	9 	if	petitioner	 ==	146
replace 	pet_code	=	5 	if	petitioner	 ==	147
replace 	pet_code	=	5 	if	petitioner	 ==	148
replace 	pet_code	=	6 	if	petitioner	 ==	149
replace 	pet_code	=	7 	if	petitioner	 ==	150
replace 	pet_code	=	5 	if	petitioner	 ==	151
replace 	pet_code	=	6 	if	petitioner	 ==	152
replace 	pet_code	=	6 	if	petitioner	 ==	153
replace 	pet_code	=	6 	if	petitioner	 ==	154
replace 	pet_code	=	6 	if	petitioner	 ==	155
replace 	pet_code	=	9 	if	petitioner	 ==	156
replace 	pet_code	=	9 	if	petitioner	 ==	157
replace 	pet_code	=	5 	if	petitioner	 ==	158
replace 	pet_code	=	8 	if	petitioner	 ==	159
replace 	pet_code	=	5 	if	petitioner	 ==	160
replace 	pet_code	=	5 	if	petitioner	 ==	161
replace 	pet_code	=	6 	if	petitioner	 ==	162
replace 	pet_code	=	6 	if	petitioner	 ==	163
replace 	pet_code	=	6 	if	petitioner	 ==	164
replace 	pet_code	=	9 	if	petitioner	 ==	165
replace 	pet_code	=	6 	if	petitioner	 ==	166
replace 	pet_code	=	5 	if	petitioner	 ==	167
replace 	pet_code	=	6 	if	petitioner	 ==	168
replace 	pet_code	=	6 	if	petitioner	 ==	169
replace 	pet_code	=	6 	if	petitioner	 ==	170
replace 	pet_code	=	5 	if	petitioner	 ==	171
replace 	pet_code	=	5 	if	petitioner	 ==	172
replace 	pet_code	=	5 	if	petitioner	 ==	173
replace 	pet_code	=	6 	if	petitioner	 ==	174
replace 	pet_code	=	6 	if	petitioner	 ==	175
replace 	pet_code	=	5 	if	petitioner	 ==	176
replace 	pet_code	=	6 	if	petitioner	 ==	177
replace 	pet_code	=	5 	if	petitioner	 ==	178
replace 	pet_code	=	6 	if	petitioner	 ==	179
replace 	pet_code	=	6 	if	petitioner	 ==	180
replace 	pet_code	=	5 	if	petitioner	 ==	181
replace 	pet_code	=	6 	if	petitioner	 ==	182
replace 	pet_code	=	6 	if	petitioner	 ==	183
replace 	pet_code	=	5 	if	petitioner	 ==	184
replace 	pet_code	=	5 	if	petitioner	 ==	185
replace 	pet_code	=	6 	if	petitioner	 ==	186
replace 	pet_code	=	5 	if	petitioner	 ==	187
replace 	pet_code	=	6 	if	petitioner	 ==	188
replace 	pet_code	=	5 	if	petitioner	 ==	189
replace 	pet_code	=	5 	if	petitioner	 ==	190
replace 	pet_code	=	5 	if	petitioner	 ==	191
replace 	pet_code	=	7 	if	petitioner	 ==	192
replace 	pet_code	=	6 	if	petitioner	 ==	193
replace 	pet_code	=	5 	if	petitioner	 ==	194
replace 	pet_code	=	5 	if	petitioner	 ==	195
replace 	pet_code	=	5 	if	petitioner	 ==	196
replace 	pet_code	=	9 	if	petitioner	 ==	197
replace 	pet_code	=	5 	if	petitioner	 ==	198
replace 	pet_code	=	6 	if	petitioner	 ==	199
replace 	pet_code	=	6 	if	petitioner	 ==	200
replace 	pet_code	=	7 	if	petitioner	 ==	201
replace 	pet_code	=	6 	if	petitioner	 ==	202
replace 	pet_code	=	5 	if	petitioner	 ==	203
replace 	pet_code	=	6 	if	petitioner	 ==	204
replace 	pet_code	=	5 	if	petitioner	 ==	205
replace 	pet_code	=	5 	if	petitioner	 ==	206
replace 	pet_code	=	7 	if	petitioner	 ==	207
replace 	pet_code	=	6 	if	petitioner	 ==	208
replace 	pet_code	=	5 	if	petitioner	 ==	209
replace 	pet_code	=	5 	if	petitioner	 ==	210
replace 	pet_code	=	7 	if	petitioner	 ==	211
replace 	pet_code	=	6 	if	petitioner	 ==	212
replace 	pet_code	=	6 	if	petitioner	 ==	213
replace 	pet_code	=	6 	if	petitioner	 ==	214
replace 	pet_code	=	6 	if	petitioner	 ==	215
replace 	pet_code	=	5 	if	petitioner	 ==	216
replace 	pet_code	=	6 	if	petitioner	 ==	217
replace 	pet_code	=	6 	if	petitioner	 ==	218
replace 	pet_code	=	5 	if	petitioner	 ==	219
replace 	pet_code	=	5 	if	petitioner	 ==	220
replace 	pet_code	=	5 	if	petitioner	 ==	221
replace 	pet_code	=	6 	if	petitioner	 ==	222
replace 	pet_code	=	6 	if	petitioner	 ==	223
replace 	pet_code	=	6 	if	petitioner	 ==	224
replace 	pet_code	=	5 	if	petitioner	 ==	225
replace 	pet_code	=	6 	if	petitioner	 ==	226
replace 	pet_code	=	6 	if	petitioner	 ==	227
replace 	pet_code	=	5 	if	petitioner	 ==	228
replace 	pet_code	=	6 	if	petitioner	 ==	229
replace 	pet_code	=	6 	if	petitioner	 ==	230
replace 	pet_code	=	5 	if	petitioner	 ==	231
replace 	pet_code	=	7 	if	petitioner	 ==	232
replace 	pet_code	=	5 	if	petitioner	 ==	233
replace 	pet_code	=	5 	if	petitioner	 ==	234
replace 	pet_code	=	5 	if	petitioner	 ==	235
replace 	pet_code	=	6 	if	petitioner	 ==	236
replace 	pet_code	=	5 	if	petitioner	 ==	237
replace 	pet_code	=	5 	if	petitioner	 ==	238
replace 	pet_code	=	6 	if	petitioner	 ==	239
replace 	pet_code	=	6 	if	petitioner	 ==	240
replace 	pet_code	=	6 	if	petitioner	 ==	241
replace 	pet_code	=	5 	if	petitioner	 ==	242
replace 	pet_code	=	5 	if	petitioner	 ==	243
replace 	pet_code	=	6 	if	petitioner	 ==	244
replace 	pet_code	=	5 	if	petitioner	 ==	245
replace 	pet_code	=	5 	if	petitioner	 ==	246
replace 	pet_code	=	6 	if	petitioner	 ==	247
replace 	pet_code	=	6 	if	petitioner	 ==	248
replace 	pet_code	=	7 	if	petitioner	 ==	249
replace 	pet_code	=	6 	if	petitioner	 ==	250
replace 	pet_code	=	6 	if	petitioner	 ==	251
replace 	pet_code	=	5 	if	petitioner	 ==	252
replace 	pet_code	=	6 	if	petitioner	 ==	253
replace 	pet_code	=	6 	if	petitioner	 ==	254
replace 	pet_code	=	6 	if	petitioner	 ==	255
replace 	pet_code	=	6 	if	petitioner	 ==	256
replace 	pet_code	=	5 	if	petitioner	 ==	257
replace 	pet_code	=	1 	if	petitioner	 ==	258
replace 	pet_code	=	5 	if	petitioner	 ==	259
replace 	pet_code	=	6 	if	petitioner	 ==	260
replace 	pet_code	=	1 	if	petitioner	 ==	301
replace 	pet_code	=	1 	if	petitioner	 ==	302
replace 	pet_code	=	1 	if	petitioner	 ==	303
replace 	pet_code	=	1 	if	petitioner	 ==	304
replace 	pet_code	=	1 	if	petitioner	 ==	305
replace 	pet_code	=	1 	if	petitioner	 ==	306
replace 	pet_code	=	1 	if	petitioner	 ==	307
replace 	pet_code	=	1 	if	petitioner	 ==	308
replace 	pet_code	=	1 	if	petitioner	 ==	310
replace 	pet_code	=	1 	if	petitioner	 ==	311
replace 	pet_code	=	1 	if	petitioner	 ==	312
replace 	pet_code	=	1 	if	petitioner	 ==	313
replace 	pet_code	=	1 	if	petitioner	 ==	314
replace 	pet_code	=	1 	if	petitioner	 ==	315
replace 	pet_code	=	1 	if	petitioner	 ==	316
replace 	pet_code	=	1 	if	petitioner	 ==	317
replace 	pet_code	=	1 	if	petitioner	 ==	318
replace 	pet_code	=	1 	if	petitioner	 ==	319
replace 	pet_code	=	1 	if	petitioner	 ==	320
replace 	pet_code	=	1 	if	petitioner	 ==	321
replace 	pet_code	=	1 	if	petitioner	 ==	322
replace 	pet_code	=	1 	if	petitioner	 ==	323
replace 	pet_code	=	1 	if	petitioner	 ==	324
replace 	pet_code	=	1 	if	petitioner	 ==	325
replace 	pet_code	=	1 	if	petitioner	 ==	326
replace 	pet_code	=	1 	if	petitioner	 ==	327
replace 	pet_code	=	1 	if	petitioner	 ==	328
replace 	pet_code	=	1 	if	petitioner	 ==	329
replace 	pet_code	=	1 	if	petitioner	 ==	330
replace 	pet_code	=	1 	if	petitioner	 ==	331
replace 	pet_code	=	1 	if	petitioner	 ==	332
replace 	pet_code	=	1 	if	petitioner	 ==	333
replace 	pet_code	=	1 	if	petitioner	 ==	334
replace 	pet_code	=	1 	if	petitioner	 ==	335
replace 	pet_code	=	1 	if	petitioner	 ==	336
replace 	pet_code	=	1 	if	petitioner	 ==	337
replace 	pet_code	=	1 	if	petitioner	 ==	338
replace 	pet_code	=	1 	if	petitioner	 ==	339
replace 	pet_code	=	1 	if	petitioner	 ==	340
replace 	pet_code	=	1 	if	petitioner	 ==	341
replace 	pet_code	=	1 	if	petitioner	 ==	342
replace 	pet_code	=	1 	if	petitioner	 ==	343
replace 	pet_code	=	1 	if	petitioner	 ==	344
replace 	pet_code	=	1 	if	petitioner	 ==	345
replace 	pet_code	=	1 	if	petitioner	 ==	346
replace 	pet_code	=	1 	if	petitioner	 ==	347
replace 	pet_code	=	1 	if	petitioner	 ==	348
replace 	pet_code	=	1 	if	petitioner	 ==	349
replace 	pet_code	=	1 	if	petitioner	 ==	350
replace 	pet_code	=	1 	if	petitioner	 ==	351
replace 	pet_code	=	1 	if	petitioner	 ==	352
replace 	pet_code	=	1 	if	petitioner	 ==	353
replace 	pet_code	=	1 	if	petitioner	 ==	354
replace 	pet_code	=	1 	if	petitioner	 ==	355
replace 	pet_code	=	1 	if	petitioner	 ==	356
replace 	pet_code	=	1 	if	petitioner	 ==	357
replace 	pet_code	=	1 	if	petitioner	 ==	358
replace 	pet_code	=	1 	if	petitioner	 ==	359
replace 	pet_code	=	1 	if	petitioner	 ==	360
replace 	pet_code	=	1 	if	petitioner	 ==	361
replace 	pet_code	=	1 	if	petitioner	 ==	362
replace 	pet_code	=	1 	if	petitioner	 ==	363
replace 	pet_code	=	1 	if	petitioner	 ==	364
replace 	pet_code	=	1 	if	petitioner	 ==	366
replace 	pet_code	=	1 	if	petitioner	 ==	367
replace 	pet_code	=	1 	if	petitioner	 ==	368
replace 	pet_code	=	1 	if	petitioner	 ==	369
replace 	pet_code	=	1 	if	petitioner	 ==	370
replace 	pet_code	=	1 	if	petitioner	 ==	371
replace 	pet_code	=	1 	if	petitioner	 ==	372
replace 	pet_code	=	1 	if	petitioner	 ==	373
replace 	pet_code	=	1 	if	petitioner	 ==	374
replace 	pet_code	=	1 	if	petitioner	 ==	375
replace 	pet_code	=	1 	if	petitioner	 ==	376
replace 	pet_code	=	1 	if	petitioner	 ==	377
replace 	pet_code	=	1 	if	petitioner	 ==	378
replace 	pet_code	=	1 	if	petitioner	 ==	379
replace 	pet_code	=	1 	if	petitioner	 ==	380
replace 	pet_code	=	1 	if	petitioner	 ==	381
replace 	pet_code	=	1 	if	petitioner	 ==	382
replace 	pet_code	=	1 	if	petitioner	 ==	383
replace 	pet_code	=	1 	if	petitioner	 ==	384
replace 	pet_code	=	1 	if	petitioner	 ==	385
replace 	pet_code	=	1 	if	petitioner	 ==	386
replace 	pet_code	=	1 	if	petitioner	 ==	387
replace 	pet_code	=	1 	if	petitioner	 ==	388
replace 	pet_code	=	1 	if	petitioner	 ==	389
replace 	pet_code	=	1 	if	petitioner	 ==	390
replace 	pet_code	=	1 	if	petitioner	 ==	391
replace 	pet_code	=	1 	if	petitioner	 ==	392
replace 	pet_code	=	1 	if	petitioner	 ==	393
replace 	pet_code	=	1 	if	petitioner	 ==	394
replace 	pet_code	=	1 	if	petitioner	 ==	395
replace 	pet_code	=	1 	if	petitioner	 ==	396
replace 	pet_code	=	1 	if	petitioner	 ==	397
replace 	pet_code	=	1 	if	petitioner	 ==	398
replace 	pet_code	=	1 	if	petitioner	 ==	399
replace 	pet_code	=	1 	if	petitioner	 ==	400
replace 	pet_code	=	1 	if	petitioner	 ==	401
replace 	pet_code	=	1 	if	petitioner	 ==	402
replace 	pet_code	=	1 	if	petitioner	 ==	403
replace 	pet_code	=	1 	if	petitioner	 ==	404
replace 	pet_code	=	1 	if	petitioner	 ==	405
replace 	pet_code	=	1 	if	petitioner	 ==	406
replace 	pet_code	=	1 	if	petitioner	 ==	407
replace 	pet_code	=	1 	if	petitioner	 ==	408
replace 	pet_code	=	1 	if	petitioner	 ==	409
replace 	pet_code	=	1 	if	petitioner	 ==	410
replace 	pet_code	=	1 	if	petitioner	 ==	411
replace 	pet_code	=	1 	if	petitioner	 ==	412
replace 	pet_code	=	1 	if	petitioner	 ==	413
replace 	pet_code	=	1 	if	petitioner	 ==	414
replace 	pet_code	=	1 	if	petitioner	 ==	415
replace 	pet_code	=	1 	if	petitioner	 ==	416
replace 	pet_code	=	1 	if	petitioner	 ==	417
replace 	pet_code	=	1 	if	petitioner	 ==	418
replace 	pet_code	=	1 	if	petitioner	 ==	419
replace 	pet_code	=	1 	if	petitioner	 ==	420
replace 	pet_code	=	1 	if	petitioner	 ==	421
replace 	pet_code	=	8 	if	petitioner	 ==	600



generate 	res_code	=	1 	if	respondent	 ==	1
replace 	res_code	=	2 	if	respondent	 ==	2
replace 	res_code	=	3 	if	respondent	 ==	3
replace 	res_code	=	2 	if	respondent	 ==	4
replace 	res_code	=	3 	if	respondent	 ==	5
replace 	res_code	=	4 	if	respondent	 ==	6
replace 	res_code	=	2 	if	respondent	 ==	7
replace 	res_code	=	6 	if	respondent	 ==	8
replace 	res_code	=	6 	if	respondent	 ==	9
replace 	res_code	=	6 	if	respondent	 ==	10
replace 	res_code	=	6 	if	respondent	 ==	11
replace 	res_code	=	1 	if	respondent	 ==	12
replace 	res_code	=	6 	if	respondent	 ==	13
replace 	res_code	=	1 	if	respondent	 ==	14
replace 	res_code	=	1 	if	respondent	 ==	15
replace 	res_code	=	4 	if	respondent	 ==	16
replace 	res_code	=	2 	if	respondent	 ==	17
replace 	res_code	=	3 	if	respondent	 ==	18
replace 	res_code	=	1 	if	respondent	 ==	19
replace 	res_code	=	4 	if	respondent	 ==	20
replace 	res_code	=	3 	if	respondent	 ==	21
replace 	res_code	=	1 	if	respondent	 ==	22
replace 	res_code	=	1 	if	respondent	 ==	23
replace 	res_code	=	8 	if	respondent	 ==	24
replace 	res_code	=	6 	if	respondent	 ==	25
replace 	res_code	=	2 	if	respondent	 ==	26
replace 	res_code	=	1 	if	respondent	 ==	27
replace 	res_code	=	2 	if	respondent	 ==	28
replace 	res_code	=	5 	if	respondent	 ==	100
replace 	res_code	=	5 	if	respondent	 ==	101
replace 	res_code	=	6 	if	respondent	 ==	102
replace 	res_code	=	5 	if	respondent	 ==	103
replace 	res_code	=	5 	if	respondent	 ==	104
replace 	res_code	=	5 	if	respondent	 ==	105
replace 	res_code	=	6 	if	respondent	 ==	106
replace 	res_code	=	5 	if	respondent	 ==	107
replace 	res_code	=	5 	if	respondent	 ==	108
replace 	res_code	=	5 	if	respondent	 ==	109
replace 	res_code	=	6 	if	respondent	 ==	110
replace 	res_code	=	9 	if	respondent	 ==	111
replace 	res_code	=	9 	if	respondent	 ==	112
replace 	res_code	=	5 	if	respondent	 ==	113
replace 	res_code	=	9 	if	respondent	 ==	114
replace 	res_code	=	5 	if	respondent	 ==	115
replace 	res_code	=	9 	if	respondent	 ==	116
replace 	res_code	=	5 	if	respondent	 ==	117
replace 	res_code	=	5 	if	respondent	 ==	118
replace 	res_code	=	5 	if	respondent	 ==	119
replace 	res_code	=	5 	if	respondent	 ==	120
replace 	res_code	=	5 	if	respondent	 ==	121
replace 	res_code	=	5 	if	respondent	 ==	122
replace 	res_code	=	5 	if	respondent	 ==	123
replace 	res_code	=	5 	if	respondent	 ==	124
replace 	res_code	=	5 	if	respondent	 ==	125
replace 	res_code	=	6 	if	respondent	 ==	126
replace 	res_code	=	9 	if	respondent	 ==	127
replace 	res_code	=	5 	if	respondent	 ==	128
replace 	res_code	=	6 	if	respondent	 ==	129
replace 	res_code	=	7 	if	respondent	 ==	130
replace 	res_code	=	5 	if	respondent	 ==	131
replace 	res_code	=	5 	if	respondent	 ==	132
replace 	res_code	=	5 	if	respondent	 ==	133
replace 	res_code	=	6 	if	respondent	 ==	134
replace 	res_code	=	5 	if	respondent	 ==	135
replace 	res_code	=	6 	if	respondent	 ==	136
replace 	res_code	=	6 	if	respondent	 ==	137
replace 	res_code	=	6 	if	respondent	 ==	138
replace 	res_code	=	5 	if	respondent	 ==	139
replace 	res_code	=	6 	if	respondent	 ==	140
replace 	res_code	=	5 	if	respondent	 ==	141
replace 	res_code	=	6 	if	respondent	 ==	142
replace 	res_code	=	5 	if	respondent	 ==	143
replace 	res_code	=	5 	if	respondent	 ==	144
replace 	res_code	=	6 	if	respondent	 ==	145
replace 	res_code	=	9 	if	respondent	 ==	146
replace 	res_code	=	5 	if	respondent	 ==	147
replace 	res_code	=	5 	if	respondent	 ==	148
replace 	res_code	=	6 	if	respondent	 ==	149
replace 	res_code	=	7 	if	respondent	 ==	150
replace 	res_code	=	5 	if	respondent	 ==	151
replace 	res_code	=	6 	if	respondent	 ==	152
replace 	res_code	=	6 	if	respondent	 ==	153
replace 	res_code	=	6 	if	respondent	 ==	154
replace 	res_code	=	6 	if	respondent	 ==	155
replace 	res_code	=	9 	if	respondent	 ==	156
replace 	res_code	=	9 	if	respondent	 ==	157
replace 	res_code	=	5 	if	respondent	 ==	158
replace 	res_code	=	8 	if	respondent	 ==	159
replace 	res_code	=	5 	if	respondent	 ==	160
replace 	res_code	=	5 	if	respondent	 ==	161
replace 	res_code	=	6 	if	respondent	 ==	162
replace 	res_code	=	6 	if	respondent	 ==	163
replace 	res_code	=	6 	if	respondent	 ==	164
replace 	res_code	=	9 	if	respondent	 ==	165
replace 	res_code	=	6 	if	respondent	 ==	166
replace 	res_code	=	5 	if	respondent	 ==	167
replace 	res_code	=	6 	if	respondent	 ==	168
replace 	res_code	=	6 	if	respondent	 ==	169
replace 	res_code	=	6 	if	respondent	 ==	170
replace 	res_code	=	5 	if	respondent	 ==	171
replace 	res_code	=	5 	if	respondent	 ==	172
replace 	res_code	=	5 	if	respondent	 ==	173
replace 	res_code	=	6 	if	respondent	 ==	174
replace 	res_code	=	6 	if	respondent	 ==	175
replace 	res_code	=	5 	if	respondent	 ==	176
replace 	res_code	=	6 	if	respondent	 ==	177
replace 	res_code	=	5 	if	respondent	 ==	178
replace 	res_code	=	6 	if	respondent	 ==	179
replace 	res_code	=	6 	if	respondent	 ==	180
replace 	res_code	=	5 	if	respondent	 ==	181
replace 	res_code	=	6 	if	respondent	 ==	182
replace 	res_code	=	6 	if	respondent	 ==	183
replace 	res_code	=	5 	if	respondent	 ==	184
replace 	res_code	=	5 	if	respondent	 ==	185
replace 	res_code	=	6 	if	respondent	 ==	186
replace 	res_code	=	5 	if	respondent	 ==	187
replace 	res_code	=	6 	if	respondent	 ==	188
replace 	res_code	=	5 	if	respondent	 ==	189
replace 	res_code	=	5 	if	respondent	 ==	190
replace 	res_code	=	5 	if	respondent	 ==	191
replace 	res_code	=	7 	if	respondent	 ==	192
replace 	res_code	=	6 	if	respondent	 ==	193
replace 	res_code	=	5 	if	respondent	 ==	194
replace 	res_code	=	5 	if	respondent	 ==	195
replace 	res_code	=	5 	if	respondent	 ==	196
replace 	res_code	=	9 	if	respondent	 ==	197
replace 	res_code	=	5 	if	respondent	 ==	198
replace 	res_code	=	6 	if	respondent	 ==	199
replace 	res_code	=	6 	if	respondent	 ==	200
replace 	res_code	=	7 	if	respondent	 ==	201
replace 	res_code	=	6 	if	respondent	 ==	202
replace 	res_code	=	5 	if	respondent	 ==	203
replace 	res_code	=	6 	if	respondent	 ==	204
replace 	res_code	=	5 	if	respondent	 ==	205
replace 	res_code	=	5 	if	respondent	 ==	206
replace 	res_code	=	7 	if	respondent	 ==	207
replace 	res_code	=	6 	if	respondent	 ==	208
replace 	res_code	=	5 	if	respondent	 ==	209
replace 	res_code	=	5 	if	respondent	 ==	210
replace 	res_code	=	7 	if	respondent	 ==	211
replace 	res_code	=	6 	if	respondent	 ==	212
replace 	res_code	=	6 	if	respondent	 ==	213
replace 	res_code	=	6 	if	respondent	 ==	214
replace 	res_code	=	6 	if	respondent	 ==	215
replace 	res_code	=	5 	if	respondent	 ==	216
replace 	res_code	=	6 	if	respondent	 ==	217
replace 	res_code	=	6 	if	respondent	 ==	218
replace 	res_code	=	5 	if	respondent	 ==	219
replace 	res_code	=	5 	if	respondent	 ==	220
replace 	res_code	=	5 	if	respondent	 ==	221
replace 	res_code	=	6 	if	respondent	 ==	222
replace 	res_code	=	6 	if	respondent	 ==	223
replace 	res_code	=	6 	if	respondent	 ==	224
replace 	res_code	=	5 	if	respondent	 ==	225
replace 	res_code	=	6 	if	respondent	 ==	226
replace 	res_code	=	6 	if	respondent	 ==	227
replace 	res_code	=	5 	if	respondent	 ==	228
replace 	res_code	=	6 	if	respondent	 ==	229
replace 	res_code	=	6 	if	respondent	 ==	230
replace 	res_code	=	5 	if	respondent	 ==	231
replace 	res_code	=	7 	if	respondent	 ==	232
replace 	res_code	=	5 	if	respondent	 ==	233
replace 	res_code	=	5 	if	respondent	 ==	234
replace 	res_code	=	5 	if	respondent	 ==	235
replace 	res_code	=	6 	if	respondent	 ==	236
replace 	res_code	=	5 	if	respondent	 ==	237
replace 	res_code	=	5 	if	respondent	 ==	238
replace 	res_code	=	6 	if	respondent	 ==	239
replace 	res_code	=	6 	if	respondent	 ==	240
replace 	res_code	=	6 	if	respondent	 ==	241
replace 	res_code	=	5 	if	respondent	 ==	242
replace 	res_code	=	5 	if	respondent	 ==	243
replace 	res_code	=	6 	if	respondent	 ==	244
replace 	res_code	=	5 	if	respondent	 ==	245
replace 	res_code	=	5 	if	respondent	 ==	246
replace 	res_code	=	6 	if	respondent	 ==	247
replace 	res_code	=	6 	if	respondent	 ==	248
replace 	res_code	=	7 	if	respondent	 ==	249
replace 	res_code	=	6 	if	respondent	 ==	250
replace 	res_code	=	6 	if	respondent	 ==	251
replace 	res_code	=	5 	if	respondent	 ==	252
replace 	res_code	=	6 	if	respondent	 ==	253
replace 	res_code	=	6 	if	respondent	 ==	254
replace 	res_code	=	6 	if	respondent	 ==	255
replace 	res_code	=	6 	if	respondent	 ==	256
replace 	res_code	=	5 	if	respondent	 ==	257
replace 	res_code	=	1 	if	respondent	 ==	258
replace 	res_code	=	5 	if	respondent	 ==	259
replace 	res_code	=	6 	if	respondent	 ==	260
replace 	res_code	=	1 	if	respondent	 ==	301
replace 	res_code	=	1 	if	respondent	 ==	302
replace 	res_code	=	1 	if	respondent	 ==	303
replace 	res_code	=	1 	if	respondent	 ==	304
replace 	res_code	=	1 	if	respondent	 ==	305
replace 	res_code	=	1 	if	respondent	 ==	306
replace 	res_code	=	1 	if	respondent	 ==	307
replace 	res_code	=	1 	if	respondent	 ==	308
replace 	res_code	=	1 	if	respondent	 ==	310
replace 	res_code	=	1 	if	respondent	 ==	311
replace 	res_code	=	1 	if	respondent	 ==	312
replace 	res_code	=	1 	if	respondent	 ==	313
replace 	res_code	=	1 	if	respondent	 ==	314
replace 	res_code	=	1 	if	respondent	 ==	315
replace 	res_code	=	1 	if	respondent	 ==	316
replace 	res_code	=	1 	if	respondent	 ==	317
replace 	res_code	=	1 	if	respondent	 ==	318
replace 	res_code	=	1 	if	respondent	 ==	319
replace 	res_code	=	1 	if	respondent	 ==	320
replace 	res_code	=	1 	if	respondent	 ==	321
replace 	res_code	=	1 	if	respondent	 ==	322
replace 	res_code	=	1 	if	respondent	 ==	323
replace 	res_code	=	1 	if	respondent	 ==	324
replace 	res_code	=	1 	if	respondent	 ==	325
replace 	res_code	=	1 	if	respondent	 ==	326
replace 	res_code	=	1 	if	respondent	 ==	327
replace 	res_code	=	1 	if	respondent	 ==	328
replace 	res_code	=	1 	if	respondent	 ==	329
replace 	res_code	=	1 	if	respondent	 ==	330
replace 	res_code	=	1 	if	respondent	 ==	331
replace 	res_code	=	1 	if	respondent	 ==	332
replace 	res_code	=	1 	if	respondent	 ==	333
replace 	res_code	=	1 	if	respondent	 ==	334
replace 	res_code	=	1 	if	respondent	 ==	335
replace 	res_code	=	1 	if	respondent	 ==	336
replace 	res_code	=	1 	if	respondent	 ==	337
replace 	res_code	=	1 	if	respondent	 ==	338
replace 	res_code	=	1 	if	respondent	 ==	339
replace 	res_code	=	1 	if	respondent	 ==	340
replace 	res_code	=	1 	if	respondent	 ==	341
replace 	res_code	=	1 	if	respondent	 ==	342
replace 	res_code	=	1 	if	respondent	 ==	343
replace 	res_code	=	1 	if	respondent	 ==	344
replace 	res_code	=	1 	if	respondent	 ==	345
replace 	res_code	=	1 	if	respondent	 ==	346
replace 	res_code	=	1 	if	respondent	 ==	347
replace 	res_code	=	1 	if	respondent	 ==	348
replace 	res_code	=	1 	if	respondent	 ==	349
replace 	res_code	=	1 	if	respondent	 ==	350
replace 	res_code	=	1 	if	respondent	 ==	351
replace 	res_code	=	1 	if	respondent	 ==	352
replace 	res_code	=	1 	if	respondent	 ==	353
replace 	res_code	=	1 	if	respondent	 ==	354
replace 	res_code	=	1 	if	respondent	 ==	355
replace 	res_code	=	1 	if	respondent	 ==	356
replace 	res_code	=	1 	if	respondent	 ==	357
replace 	res_code	=	1 	if	respondent	 ==	358
replace 	res_code	=	1 	if	respondent	 ==	359
replace 	res_code	=	1 	if	respondent	 ==	360
replace 	res_code	=	1 	if	respondent	 ==	361
replace 	res_code	=	1 	if	respondent	 ==	362
replace 	res_code	=	1 	if	respondent	 ==	363
replace 	res_code	=	1 	if	respondent	 ==	364
replace 	res_code	=	1 	if	respondent	 ==	366
replace 	res_code	=	1 	if	respondent	 ==	367
replace 	res_code	=	1 	if	respondent	 ==	368
replace 	res_code	=	1 	if	respondent	 ==	369
replace 	res_code	=	1 	if	respondent	 ==	370
replace 	res_code	=	1 	if	respondent	 ==	371
replace 	res_code	=	1 	if	respondent	 ==	372
replace 	res_code	=	1 	if	respondent	 ==	373
replace 	res_code	=	1 	if	respondent	 ==	374
replace 	res_code	=	1 	if	respondent	 ==	375
replace 	res_code	=	1 	if	respondent	 ==	376
replace 	res_code	=	1 	if	respondent	 ==	377
replace 	res_code	=	1 	if	respondent	 ==	378
replace 	res_code	=	1 	if	respondent	 ==	379
replace 	res_code	=	1 	if	respondent	 ==	380
replace 	res_code	=	1 	if	respondent	 ==	381
replace 	res_code	=	1 	if	respondent	 ==	382
replace 	res_code	=	1 	if	respondent	 ==	383
replace 	res_code	=	1 	if	respondent	 ==	384
replace 	res_code	=	1 	if	respondent	 ==	385
replace 	res_code	=	1 	if	respondent	 ==	386
replace 	res_code	=	1 	if	respondent	 ==	387
replace 	res_code	=	1 	if	respondent	 ==	388
replace 	res_code	=	1 	if	respondent	 ==	389
replace 	res_code	=	1 	if	respondent	 ==	390
replace 	res_code	=	1 	if	respondent	 ==	391
replace 	res_code	=	1 	if	respondent	 ==	392
replace 	res_code	=	1 	if	respondent	 ==	393
replace 	res_code	=	1 	if	respondent	 ==	394
replace 	res_code	=	1 	if	respondent	 ==	395
replace 	res_code	=	1 	if	respondent	 ==	396
replace 	res_code	=	1 	if	respondent	 ==	397
replace 	res_code	=	1 	if	respondent	 ==	398
replace 	res_code	=	1 	if	respondent	 ==	399
replace 	res_code	=	1 	if	respondent	 ==	400
replace 	res_code	=	1 	if	respondent	 ==	401
replace 	res_code	=	1 	if	respondent	 ==	402
replace 	res_code	=	1 	if	respondent	 ==	403
replace 	res_code	=	1 	if	respondent	 ==	404
replace 	res_code	=	1 	if	respondent	 ==	405
replace 	res_code	=	1 	if	respondent	 ==	406
replace 	res_code	=	1 	if	respondent	 ==	407
replace 	res_code	=	1 	if	respondent	 ==	408
replace 	res_code	=	1 	if	respondent	 ==	409
replace 	res_code	=	1 	if	respondent	 ==	410
replace 	res_code	=	1 	if	respondent	 ==	411
replace 	res_code	=	1 	if	respondent	 ==	412
replace 	res_code	=	1 	if	respondent	 ==	413
replace 	res_code	=	1 	if	respondent	 ==	414
replace 	res_code	=	1 	if	respondent	 ==	415
replace 	res_code	=	1 	if	respondent	 ==	416
replace 	res_code	=	1 	if	respondent	 ==	417
replace 	res_code	=	1 	if	respondent	 ==	418
replace 	res_code	=	1 	if	respondent	 ==	419
replace 	res_code	=	1 	if	respondent	 ==	420
replace 	res_code	=	1 	if	respondent	 ==	421
			

label var res_code "Respondent category"
label var pet_code "Petitioner category"

label define respet_code  1 "US" 2 "State" 3 "Local" 4 "Judicial" 5 "Private business" 6 "Private person" 7 "Non-profit" 8 "Foreign" 9 "Person or business" 

label values  res_code pet_code respet_code








gen us_party1 = 0
gen state_party1 = 0
gen local_party1 = 0
gen jud_party1 = 0
gen bus_party1 = 0
gen person_party1 = 0
gen nonprof_party1 = 0
gen foreign_party1 = 0
gen persbus_party1 = 0

gen us_party2 = 0
gen state_party2 = 0
gen local_party2 = 0
gen jud_party2 = 0
gen bus_party2 = 0
gen person_party2 = 0
gen nonprof_party2 = 0
gen foreign_party2 = 0
gen persbus_party2 = 0

gen us_party = 0
gen state_party = 0
gen local_party = 0
gen jud_party = 0
gen bus_party = 0
gen person_party = 0
gen nonprof_party = 0
gen foreign_party = 0
gen persbus_party = 0


replace 	us_party1	=	1	if	pet_code	==	1
replace 	state_party1	=	1	if	pet_code	==	2
replace 	local_party1	=	1	if	pet_code	==	3
replace 	jud_party1	=	1	if	pet_code	==	4
replace 	bus_party1	=	1	if	pet_code	==	5
replace 	person_party1	=	1	if	pet_code	==	6
replace 	nonprof_party1	=	1	if	pet_code	==	7
replace 	foreign_party1	=	1	if	pet_code	==	8
replace 	persbus_party1	=	1	if	pet_code	==	9
							
							
replace 	us_party2	=	1	if	res_code	==	1
replace 	state_party2	=	1	if	res_code	==	2
replace 	local_party2	=	1	if	res_code	==	3
replace 	jud_party2	=	1	if	res_code	==	4
replace 	bus_party2	=	1	if	res_code	==	5
replace 	person_party2	=	1	if	res_code	==	6
replace 	nonprof_party2	=	1	if	res_code	==	7
replace 	foreign_party2	=	1	if	res_code	==	8
replace 	persbus_party2	=	1	if	res_code	==	9

 							
replace 	us_party	=	1	if	res_code	==	1	|	pet_code	==	1		
replace 	state_party	=	1	if	res_code	==	2	|	pet_code	==	2		
replace 	local_party	=	1	if	res_code	==	3	|	pet_code	==	3		
replace 	jud_party	=	1	if	res_code	==	4	|	pet_code	==	4		
replace 	bus_party	=	1	if	res_code	==	5	|	pet_code	==	5		
replace 	person_party	=	1	if	res_code	==	6	|	pet_code	==	6		
replace 	nonprof_party	=	1	if	res_code	==	7	|	pet_code	==	7		
replace 	foreign_party	=	1	if	res_code	==	8	|	pet_code	==	8		
replace 	persbus_party	=	1	if	res_code	==	9	|	pet_code	==	8		



generate 	us_win	=	0	if	res_code	==	1	|	pet_code	==	1		
generate 	state_win	=	0	if	res_code	==	2	|	pet_code	==	2		
generate 	local_win	=	0	if	res_code	==	3	|	pet_code	==	3		
generate 	jud_win	=	0	if	res_code	==	4	|	pet_code	==	4		
generate 	bus_win	=	0	if	res_code	==	5	|	pet_code	==	5		
generate 	person_win	=	0	if	res_code	==	6	|	pet_code	==	6		
generate 	nonprof_win	=	0	if	res_code	==	7	|	pet_code	==	7		
generate 	foreign_win	=	0	if	res_code	==	8	|	pet_code	==	8		
generate 	persbus_win=	0		if	res_code	==	9	|	pet_code	==	8		

replace 	us_win	=	1	if	pet_code	==	1	&	partyWinning	==	1		
replace 	state_win	=	1	if	pet_code	==	2	&	partyWinning	==	1		
replace 	local_win	=	1	if	pet_code	==	3	&	partyWinning	==	1		
replace 	jud_win	=	1	if	pet_code	==	4	&	partyWinning	==	1		
replace 	bus_win	=	1	if	pet_code	==	5	&	partyWinning	==	1		
replace 	person_win	=	1	if	pet_code	==	6	&	partyWinning	==	1		
replace 	nonprof_win	=	1	if	pet_code	==	7	&	partyWinning	==	1		
replace 	foreign_win	=	1	if	pet_code	==	8	&	partyWinning	==	1		
replace 	persbus_win	=	1	if	pet_code	==	9	&	partyWinning	==	1		


replace 	us_win	=	1	if	res_code	==	1	&	partyWinning	==	0		
replace 	state_win	=	1	if	res_code	==	2	&	partyWinning	==	0		
replace 	local_win	=	1	if	res_code	==	3	&	partyWinning	==	0		
replace 	jud_win	=	1	if	res_code	==	4	&	partyWinning	==	0		
replace 	bus_win	=	1	if	res_code	==	5	&	partyWinning	==	0		
replace 	person_win	=	1	if	res_code	==	6	&	partyWinning	==	0		
replace 	nonprof_win	=	1	if	res_code	==	7	&	partyWinning	==	0		
replace 	foreign_win	=	1	if	res_code	==	8	&	partyWinning	==	0		
replace 	persbus_win	=	1	if	res_code	==	9	&	partyWinning	==	0		



gen buswin_low = 0 if bus_party == 1 
replace buswin_low = 1 if bus_win == 1 & (person_party == 1 | nonprof_party == 1 | persbus_party == 1) 


gen buswin_gov = 0 if bus_party == 1  
replace buswin_gov = 1 if bus_win == 1 & (us_party == 1 | state_party == 1 | local_party == 1) 



* I did it like this because the denominator here cannot include cases where there are no business versus government | individuals parties
* that way, when I aggregate it, it is the percent liberal outcomes OF bus v gov | individuals


gen buswin_lowc = 0 if bus_party == 1  & (person_party == 1 | nonprof_party == 1 | persbus_party == 1) 
gen buswin_lowl = 0 if bus_party == 1  & (person_party == 1 | nonprof_party == 1 | persbus_party == 1) 


replace buswin_lowc = 1 if bus_party == 1  & ( decisionDirection  == 1) &  (person_party == 1 | nonprof_party == 1 | persbus_party == 1) 
replace buswin_lowl = 1 if bus_party == 1  & ( decisionDirection  == 2) &  (person_party == 1 | nonprof_party == 1 | persbus_party == 1) 

gen buswin_govc = 0 if bus_party == 1  & (us_party == 1 | state_party == 1 | local_party == 1) 
gen buswin_govl = 0 if bus_party == 1  & (us_party == 1 | state_party == 1 | local_party == 1) 

replace buswin_govc = 1 if bus_party == 1  & ( decisionDirection  == 1) &  (us_party == 1 | state_party == 1 | local_party == 1) 
replace buswin_govl = 1 if bus_party == 1  & ( decisionDirection  == 2) &  (us_party == 1 | state_party == 1 | local_party == 1) 



label var buswin_low "Business wins against private person or non profit - includes persbus"
label var buswin_gov "Business wins against government"
label var us_party2 "US as a respondent" 
label var state_party2 "State as a respondent" 
label var local_party2 "Local govt as a respondent" 
label var jud_party2 "Judiciary as a respondent" 
label var bus_party2 "Private business as a respondent" 
label var person_party2 "Private person as a respondent" 
label var nonprof_party2 "Nonprofit as a respondent" 
label var foreign_party2 "Foreign entity as a respondent" 
label var persbus_party2 "Either person or business as a respondent" 

label var us_party1 "US as a petitioner" 
label var state_party1 "State as a petitioner " 
label var local_party1 "Local govt as a petitioner " 
label var jud_party1 "Judiciary as a petitioner " 
label var bus_party1 "Private business as a petitioner " 
label var person_party1 "Private person as a petitioner " 
label var nonprof_party1 "Nonprofit as a petitioner " 
label var foreign_party1 "Foreign entity as a petitioner " 
label var persbus_party1 "Either person or business as a petitioner " 


label var us_win "US party wins" 
label var state_win "State party wins" 
label var local_win "Local govt party wins" 
label var jud_win "Judiciary party wins" 
label var bus_win "Private business party wins " 
label var person_win "Private person party wins" 
label var nonprof_win "Nonprofit party wins" 
label var foreign_win "Foreign party wins" 
label var persbus_win "Either person or business party wins" 

label var us_party2 "US as a respondent" 
label var state_party2 "State as a respondent " 
label var local_party2 "Local govt as a respondent " 
label var jud_party2 "Judiciary as a respondent " 
label var bus_party2 "Private business as a respondent " 
label var person_party2 "Private person as a respondent " 
label var nonprof_party2 "Nonprofit as a respondent " 
label var foreign_party2 "Foreign entity as a respondent " 
label var persbus_party2 "Either person or business as a respondent " 




save "${sc_Working}2023_SCDB_Baird_CaseId2021Working.dta", replace


* Merge with Amicus Hansford data

merge m:m caseId using  "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/AmicusBriefsCaseId_wide.dta"

save "2023_2_1_SCDB_Baird_CaseWorking.dta", replace

    Result                      Number of obs
    -----------------------------------------
    Not matched                         4,749
        from master                     4,749  (_merge==1)
        from using                          0  (_merge==2)

    Matched                             4,411  (_merge==3)
    -----------------------------------------

gen brief_num_if_data= brief 
replace brief_num_if_data= 0 if term <  1953 | term > 2013

********************************************************************************
********************************************************************************
********************************************************************************
* Adding variables for case complexity and salience  
********************************************************************************
********************************************************************************
********************************************************************************

save "2023_2_1_SCDB_Baird_CaseWorking.dta", replace

drop _merge
sort caseId 

save "2023_2_1_SCDB_Baird_CaseWorking.dta", replace

* Logan Strother data 
* Downloaded from 
* https://dataverse.harvard.edu/dataset.xhtml?persistentId=doi:10.7910/DVN/VFXPQG

* Note that the caseId data excludes these cases 
* tab decisionType if _merge==1

*     type of decision |      Freq.     Percent        Cum.
* ---------------------+-----------------------------------
* opinion of the court |      1,185       81.05       81.05
* per curiam (no oral) |        128        8.76       89.81
*              decrees |          2        0.14       89.95
* equally divided vote |         40        2.74       92.68
*    per curiam (oral) |         60        4.10       96.79
*     judg. of the Ct. |         47        3.21      100.00
* ---------------------+-----------------------------------
 *               Total |      1,462      100.00


use "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/DataOrig/StrotherReplication/Strother_JLC_Constraints_Dataset_1.dta"
rename wordLog_zscore wordLog_zscore_ls
rename PresCourtDist PresCourtDist_ls
rename ConstraintDist ConstraintDist_ls
rename SJchairDist SJchairDist_ls
rename HJchairDist HJchairDist_ls
rename FloorMedianOverModel FloorMedianOverModel_ls
rename FilibusterVeto FilibusterVeto_ls
rename PartyPivotGate PartyPivotGate_ls
rename JudiciaryMedGate JudiciaryMedGate_ls
rename JudiciaryChairGate JudiciaryChairGate_ls
rename lagmood lagmood_ls
rename mood mood_ls
rename pres pres_ls
rename senate senate_ls
rename house house_ls
rename court court_ls
rename cong cong_ls
rename seg_med seg_med_ls
rename lawmakmaj lawmakmaj_ls
rename courtdems courtdems_ls
rename courtreps courtreps_ls
rename dempres dempres_ls
rename sdpercen sdpercen_ls
rename cdpercen cdpercen_ls
rename hdpercen hdpercen_ls
rename demcong demcong_ls
rename repcong repcong_ls
rename divcong divcong_ls
rename demcourt demcourt_ls
rename oppctcn oppctcn_ls
rename p_ct_dist p_ct_dist_ls
rename cn_ct_dist cn_ct_dist_ls
rename regime regime_ls
rename constraint constraint_ls
rename relconglib relconglib_ls
rename regimepres regimepres_ls
rename constraintp constraintp_ls
rename relreglib relreglib_ls
rename swlstrike swlstrike_ls
rename JCSPredProb JCSPredProb_ls
rename bills bills_ls
rename statchal statchal_ls
rename sc_med sc_med_ls
rename unem unem_ls
rename perchcpi perchcpi_ls
rename def_budg def_budg_ls
rename policylib policylib_ls
rename homicide homicide_ls
rename inequality inequality_ls
rename lagcurbbills lagcurbbills_ls
rename lagcurbing lagcurbing_ls
rename curbbills curbbills_ls
rename curbing curbing_ls
rename oppcong oppcong_ls
rename gss_confidence gss_conf_ls
rename divergence divergence_ls
rename appoint appoint_ls





rename petac petac_ls
rename respac respac_ls
rename otherac otherac_ls
rename totalac totalac_ls
rename sgpet sgpet_ls
rename sgresp sgresp_ls
rename sgpetac sgpetac_ls
rename sgrespac sgrespac_ls
rename sgotherac sgotherac_ls
rename sgamicus sgamicus_ls
rename liberalac liberalac_ls
rename conservac conservac_ls
rename sglibparty sglibparty_ls
rename sgconparty sgconparty_ls
rename sglibac sglibac_ls
rename sgconac sgconac_ls
rename pre3 pre3_ls
rename BSJsal BSJsal_ls
rename BSJ_5 BSJ_5_ls
rename pre5 pre5_ls
rename ac15 ac15_ls
rename ac5 ac5_ls
rename earlyCoverage_LAT earlyCoverage_LAT_ls
rename earlyCoverage_WAPO earlyCoverage_WAPO_ls
rename earlyCoverage_NYT earlyCoverage_NYT_ls
rename early_sal early_sal_ls
rename early_sal_dum early_sal_dum_ls
rename CLR_early CLR_early_ls
rename earlysaliencesd earlysaliencesd_ls
rename arg_sal arg_sal_ls
rename arg_sal_dum arg_sal_dum_ls
rename pend_sal pend_sal_ls
rename pend_sal_dum pend_sal_dum_ls
rename pre_dec pre_dec_ls
rename pre_dec_dum pre_dec_dum_ls
rename post_dec post_dec_ls
rename post_dec_dum post_dec_dum_ls
rename sgsupp sgsupp_ls
rename amisupp amisupp_ls
rename amiopp amiopp_ls
rename lat lat_ls
rename cq_salient cq_salient_ls
rename nyt_salient nyt_salient_ls
rename rb_add rb_add_ls



sort caseId 

save "${sc_Working}Strother_JLC_Constraints_Dataset_1_use_for_merge.dta", replace

use "2023_2_1_SCDB_Baird_CaseWorking.dta"



merge 1:1 caseId using "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/ToBeFiled/Strother_JLC_Constraints_Dataset_1_use_for_merge.dta"

save "2023_2_1_SCDB_Baird_CaseWorking_JLC.dta", replace


********************************************************************************
* Merge salience  
********************************************************************************

* downloaded from
* http://scdb.wustl.edu/data.php?s=5

use "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/ToBeFiled/scdbSalience.dta"
sort caseId 

rename nytSalience nyt
rename cqSalience cq

save "${sc_Working}scdbSalience_for_merge.dta", replace

use  "2023_2_1_SCDB_Baird_CaseWorking_JLC.dta"

sort caseId 

drop _merge
merge m:1 caseId using "${sc_Working}scdbSalience_for_merge.dta"

gen nytl = 0
gen nytc = 0

gen cql = 0
gen cqc = 0

replace nytc = 1 if decisionDirection == 1 & nyt == 1

replace nytl = 1 if decisionDirection == 2 & nyt == 1

replace cql = 1 if decisionDirection == 2 & cq == 1

replace cqc = 1 if decisionDirection == 1  & cq == 1

label var nytl "Liberal Salient Epstein and Segal NY Times"
label var nytc "Conservative Salient Epstein and Segal NY Times"

drop _merge
save "${sc_Working}2023_2_1_SCDB_Baird_CaseWorking.dta", replace


********************************************************************************
* Merge complexity data
********************************************************************************

* downloaded from 
* https://dataverse.harvard.edu/dataset.xhtml?persistentId=doi:10.7910/DVN/E1VAPX

use "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/ToBeFiled/complexity_for_merge.dta"
sort caseId 
save "${sc_Working}complexity_for_merge.dta", replace

use "${sc_Working}2023_2_1_SCDB_Baird_CaseWorking.dta"
sort caseId 


sort caseId 
merge 1:1 caseId using "${sc_Working}complexity_for_merge.dta"

save "${sc_Working}2023_2_9_SCDB_Baird_CaseWorking.dta", replace

use "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/DataWorking/2023_SCDB_Baird_Justice2021_wide_for_merge.dta"

 use "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/DataWorking/2023_2_9_SCDB_Baird_CaseWorking.dta"


save "${sc_Working}2023_2_10_SCDB_Baird_CaseWorking.dta", replace
drop _merge
save "${sc_Working}2023_2_10_SCDB_Baird_CaseWorking.dta", replace


merge 1:1 caseId using "${sc_Working}2023_SCDB_Baird_Justice2021_wide.dta"

save "${sc_Working}2023_2_10_SCDB_Baird_CaseJusticeAmicus.dta", replace

* This merges the Justice data with caseId for variables that are not created by Justice.

use "${sc_Working}2023_SCDB_Baird_Justice2021_from_justice_to_Caseid_Working_for_merge.dta"


 drop in 1
sort caseId 

save "${sc_Working}2023_SCDB_Baird_Justice2021_from_justice_to_Caseid_Working.dta", replace





gen num_amici = brief 


gen lib_amici  		= brief_aff if caseDisposition == 2 & lib ==1
replace lib_amici   = brief_rev if (caseDisposition == 3 | caseDisposition ==  4 | caseDisposition ==  5)  & lib ==1

gen cons_amici 		= brief_aff  if caseDisposition == 2 & lib ==0 
replace cons_amici 	= brief_rev  if (caseDisposition == 3 | caseDisposition ==  4 | caseDisposition ==  5)  & lib ==0 

gen lib_cosign  	= brief_aff if caseDisposition == 2 & lib ==1
replace lib_cosign  = brief_rev  if (caseDisposition == 3 | caseDisposition ==  4 | caseDisposition ==  5)  & lib ==1

gen cons_cosign 	= brief_aff  if caseDisposition == 2 & lib ==0 
replace cons_cosign = brief_rev  if (caseDisposition == 3 | caseDisposition ==  4 | caseDisposition ==  5)  & lib ==0 

egen tot_briefs_cosigners = rowtotal (num_amici cosign )

egen tot_briefs_cosigners_lib = rowtotal (lib_amici lib_cosign )
egen tot_briefs_cosigners_cons = rowtotal (cons_amici cons_cosign )

* This merges the Justice data that is NOT wide (justice specific variables), 
* such as the number of kinds of decisions/opinions and the median of the majority 

use  "${sc_Working}2023_SCDB_Baird_Justice2021_from_justice_to_Caseid_Working.dta"



use "${sc_Working}2023_2_10_SCDB_Baird_CaseJusticeAmicus.dta", replace
drop _merge 
merge 1:1 caseId using  "${sc_Working}2023_SCDB_Baird_Justice2021_from_justice_to_Caseid_Working.dta"


* This is for creating the number of cases in aggregate
gen cases = 1
save "${sc_Working}2023_2_10_SCDB_Baird_CaseJusticeAmicus.dta", replace
sort term svalue_gen
save "${sc_Working}2023_2_10_SCDB_Baird_CaseJusticeAmicus.dta", replace


collapse (mean) medmaj_rat_noconcur_jcs medmaj_rat_nospec_jcs /// 
medmaj_vote_nodis_jcs medmaj_vote_dis_jcs ideo_doct ideo_doct01 /// 
years_same_court burger rehnquist roberts vinson warren vote_coalition vote_contentious ///
(sum) cases lib con lib_lct con_lct  n54 n56 n63 n78 n81 n72 unam  ///
n54c n56c n63c n78c n81c n72c unaml unamc n54l n56l n63l n78l n81l n72l n54cc ///
n56cc n63cc n78cc n81cc n72cc unamcc n54ll n56ll n63ll n78ll n81ll n72ll ///
unamll n54lc n56lc n63lc n78lc n81lc n72lc unamlc n54cl n56cl n63cl n78cl ///
n81cl n72cl unamcl uncon muni state fed unconl unconc munic munil fedl fedc ///
statel statec rev revl revc prec precc precl cert_cat cert_sal ///
nyt cq nytl nytc cql cqc salienceest saliencesd ///
source_circ source_district source_state FirstCircuit SecondCircuit ///
ThirdCircuit FourthCircuit FifthCircuit SixthCircuit SeventhCircuit ///
EighthCircuit NinthCircuit TenthCircuit EleventhCircuit DCCircuit ///
OtherCircuit origin_circ origin_district origin_state const_type nonconst_type ///
us_party state_party local_party jud_party bus_party person_party nonprof_party ///
foreign_party persbus_party us_win state_win local_win jud_win bus_win person_win ///
nonprof_win foreign_win persbus_win buswin_low buswin_gov buswin_lowc ///
buswin_lowl buswin_govc buswin_govl lib_amici cons_amici ///
lib_cosign cons_cosign num_amici tot_briefs_cosigners tot_briefs_cosigners_lib /// 
tot_briefs_cosigners_cons /// 
special_concur reg_concur any_concur special_concur_opin ///
reg_concur_opin any_concur_opin dissent_opin NoDissent Dissent4 ///
Dissent4Opin Dissent3 Dissent3Opin Dissent2 Dissent2Opin Dissent1 ///
Dissent1Opin concur_opin libdissent_opin condissent_opin disnum disc disl connum conl conc ///
(mean) latentComplexity wordLog_zscore_ls PresCourtDist_ls ConstraintDist_ls SJchairDist_ls ///
HJchairDist_ls FloorMedianOverModel_ls FilibusterVeto_ls PartyPivotGate_ls ///
JudiciaryMedGate_ls JudiciaryChairGate_ls lagmood_ls mood_ls pres_ls senate_ls ///
house_ls court_ls cong_ls seg_med_ls lawmakmaj_ls courtdems_ls courtreps_ls ///
dempres_ls sdpercen_ls cdpercen_ls hdpercen_ls demcong_ls repcong_ls divcong_ls ///
demcourt_ls oppctcn_ls p_ct_dist_ls cn_ct_dist_ls regime_ls constraint_ls ///
relconglib_ls regimepres_ls constraintp_ls relreglib_ls swlstrike_ls ///
JCSPredProb_ls bills_ls statchal_ls sc_med_ls unem_ls perchcpi_ls ///
def_budg_ls policylib_ls homicide_ls inequality_ls lagcurbbills_ls ///
lagcurbing_ls curbbills_ls curbing_ls oppcong_ls gss_conf_ls divergence_ls ///
appoint_ls     (sum) petac_ls respac_ls otherac_ls totalac_ls sgpet_ls ///
sgresp_ls sgpetac_ls sgrespac_ls sgotherac_ls sgamicus_ls liberalac_ls ///
conservac_ls sglibparty_ls sgconparty_ls sglibac_ls sgconac_ls pre3_ls ///
BSJsal_ls BSJ_5_ls pre5_ls ac15_ls ac5_ls earlyCoverage_LAT_ls ///
earlyCoverage_WAPO_ls earlyCoverage_NYT_ls early_sal_ls early_sal_dum_ls ///
CLR_early_ls earlysaliencesd_ls arg_sal_ls arg_sal_dum_ls pend_sal_ls ///
pend_sal_dum_ls pre_dec_ls pre_dec_dum_ls post_dec_ls post_dec_dum_ls ///
sgsupp_ls amisupp_ls amiopp_ls lat_ls cq_salient_ls nyt_salient_ls rb_add_ls  , by ( term svalue_gen)


save "${sc_Working}2023_2_10_SCDB_Baird_CaseJusticeAmicus_svalue_term.dta", replace

drop if svalue_gen ==.
drop if term ==.

save "${sc_Working}2023_2_10_SCDB_Baird_CaseJusticeAmicus_svalue_term.dta", replace






* This is for creating the number of cases in aggregate
gen cases = 1

label var svalue_gen "General policy area"
label var medmaj_rat_noconcur_jcs "Mean doctrine, no conc"
label var medmaj_rat_nospec_jcs "Mean doctrine, no special conc"
label var medmaj_vote_nodis_jcs "Mean doctrine, median of all incl conc"
label var medmaj_vote_dis_jcs "Median of dissenting votes"
label var ideo_doct "Mean doctrine, no special conc"
label var ideo_doct01 "Mean doctrine, no special conc"
label var years_same_court "Number of years since new Justice"
label var vote_coalition "Average size of majority"
label var vote_contentious "Average number of dissenters"
label var cases "Number of cases"
label var lib "Number of cases"
label var con "Number of cases"
label var lib_lct "Number of cases with liberal lower Court"
label var con_lct "Number of cases with conservative lower Court"
label var n54 "Number of 5-4 cases"
label var n56 "Number of 5-4 or 6-3 cases"
label var n63 "Number of 6-3 cases"
label var n78 "Number of 7-2 or 8-1 cases"
label var n81 "Number of 8-1 cases"
label var n72 "Number of 7-2 cases"
label var unam "Number of unanimous cases"
label var n54c "Number of 5-4 conservative cases"
label var n56c "Number of 5-4 or 6-3 conservative cases"
label var n63c "Number of 6-3 conservative cases"
label var n78c "Number of 7-2 or 8-1 conservative cases"
label var n81c "Number of 8-1 conservative cases"
label var n72c "Number of 7-2 conservative cases"
label var unamc "Number of unanimous conservative cases"

label var n54l "Number of 5-4 liberal cases"
label var n56l "Number of 5-4 or 6-3 liberal cases"
label var n63l "Number of 6-3 liberal cases"
label var n78l "Number of 7-2 or 8-1 liberal cases"
label var n81l "Number of 8-1 liberal cases"
label var n72l "Number of 7-2 liberal cases"
label var unaml "Number of unanimous liberal cases"

label var n54lc "Number of 5-4 conservative cases overturning a liberal lower court"
label var n56lc "Number of 5-4 or 6-3 conservative cases overturning a liberal lower court"
label var n63lc "Number of 6-3 conservative cases overturning a liberal lower court"
label var n78lc "Number of 7-2 or 8-1 conservative cases overturning a liberal lower court"
label var n81lc "Number of 8-1 conservative cases overturning a liberal lower court"
label var n72lc "Number of 7-2 conservative cases overturning a liberal lower court"
label var unamlc "Number of unanimous conservative cases overturning a liberal lower court"

label var n54cl "Number of 5-4 liberal cases overturning a conservative lower court"
label var n56cl "Number of 5-4 or 6-3 liberal cases overturning a conservative lower court"
label var n63cl "Number of 6-3 liberal cases overturning a conservative lower court"
label var n78cl "Number of 7-2 or 8-1 liberal cases overturning a conservative lower court"
label var n81cl "Number of 8-1 liberal cases overturning a conservative lower court"
label var n72cl "Number of 7-2 liberal cases overturning a conservative lower court"
label var unamcl "Number of unanimous liberal cases overturning a conservative lower court"

label var n54cc "Number of 5-4 conservative cases affirming a conservative lower court"
label var n56cc "Number of 5-4 or 6-3 conservative cases affirming a conservative lower court"
label var n63cc "Number of 6-3 conservative cases affirming a conservative lower court"
label var n78cc "Number of 7-2 or 8-1 conservative cases affirming a conservative lower court"
label var n81cc "Number of 8-1 conservative cases affirming a conservative lower court"
label var n72cc "Number of 7-2 conservative cases affirming a conservative lower court"
label var unamcc "Number of unanimous conservative cases affirming a conservative lower court"

label var n54ll "Number of 5-4 liberal cases affirming a liberal lower court"
label var n56ll "Number of 5-4 or 6-3 liberal cases affirming a liberal lower court"
label var n63ll "Number of 6-3 liberal cases affirming a liberal lower court"
label var n78ll "Number of 7-2 or 8-1 liberal cases affirming a liberal lower court"
label var n81ll "Number of 8-1 liberal cases affirming a liberal lower court"
label var n72ll "Number of 7-2 liberal cases affirming a liberal lower court"
label var unamll "Number of unanimous liberal cases affirming a liberal lower court"


label var uncon "Number of declarations of unconstitutionality"
label var muni "Number of municipal declarations of unconstitutionality"
label var state "Number of state declarations of unconstitutionality"
label var fed "Number of federal declarations of unconstitutionality"

label var unconc "Number of conservative declarations of unconstitutionality"
label var munic "Number of conservative municipal declarations of unconstitutionality"
label var statec "Number of conservative state declarations of unconstitutionality"
label var fedc "Number of conservative federal declarations of unconstitutionality"

label var unconl "Number of liberal declarations of unconstitutionality"
label var munil "Number of liberal municipal declarations of unconstitutionality"
label var statel "Number of liberal state declarations of unconstitutionality"
label var fedl "Number of liberal federal declarations of unconstitutionality"


label var rev "Number of reversals"
label var revl "Number of liberal reversals"
label var revc "Number of conservative reversals"
label var prec "Number of alterations of precedent"
label var precc "Number of alterations of conservative precedent"
label var precl "Number of alterations of liberal precedent"
label var cert_sal "Number of cert decisions based on issue importance"
label var nyt "Number of cases on front page of the NYT"
label var cq "Number of cases reported in Congressional Quarterly"

label var nytl "Number of liberal cases on front page of the NYT"
label var cql "Number of liberal cases reported in Congressional Quarterly"

label var nytc "Number of conservative cases on front page of the NYT"
label var cqc "Number of conservative cases reported in Congressional Quarterly"


label var salienceest "Sum of salience estimates"

label var source_circ "Number of cases coming from Circuits"
label var source_district "Number of cases coming straight from federal district court"
label var source_state "Number of cases coming from a state court"
label var FirstCircuit "Number of cases coming from First Circuit"
label var SecondCircuit "Number of cases coming from Second Circuit"
label var ThirdCircuit "Number of cases coming from Third Circuit"
label var FourthCircuit "Number of cases coming from Fourth Circuit"
label var FifthCircuit "Number of cases coming from Five Circuit"
label var SixthCircuit "Number of cases coming from Sixth Circuit"
label var SeventhCircuit "Number of cases coming from Seventh Circuit"
label var EighthCircuit "Number of cases coming from Eighth Circuit"
label var NinthCircuit "Number of cases coming from Ninth Circuit"
label var TenthCircuit "Number of cases coming from Ten Circuit"
label var EleventhCircuit "Number of cases coming from Eleventh Circuit"
label var DCCircuit "Number of cases coming from DC Circuit"
label var OtherCircuit "Number of cases coming from `other' Circuit"
label var origin_circ "Number of cases originating in a Circuit"
label var origin_district "Number of cases originating in a federal district"
label var origin_state "Number of cases originating in a state"
label var const_type "Number of constitutional review"
label var nonconst_type "Number of statutory review"
label var us_party "Number of cases with U.S. as a party"
label var state_party "Number of cases with a state as a party"
label var local_party "Number of cases with a city as a party"
label var jud_party "Number of cases with a court as a party"
label var bus_party "Number of cases with a business as a party"
label var person_party "Number of cases with a person as a party"
label var nonprof_party "Number of cases with a non-profit as a party"
label var foreign_party "Number of cases with a foreign state as a party"
label var persbus_party "Number of cases with a personal business as a party"
label var us_win "Number of cases with U.S. win"
label var state_win "Number of cases with a state winning"
label var local_win "Number of cases with a city winning"
label var jud_win "Number of cases with a court winning"
label var bus_win "Number of cases with a business winning"
label var person_win "Number of cases with a person winning"
label var nonprof_win "Number of cases with a non-profit winning"
label var foreign_win "Number of cases with a foreign state winning"
label var persbus_win "Number of cases with a person as business winning"
label var buswin_low "Number of cases with a business winning against non-government"
label var buswin_gov "Number of cases with a business winning government"

label var buswin_lowl "Number of liberal cases with a business winning against non-government"
label var buswin_govl "Number of liberal cases with a business winning government"

label var buswin_lowc "Number of conservative cases with a business winning against non-government"
label var buswin_govc "Number of conservative cases with a business winning government"

label var lib_amici "Number of liberal amicus briefs"
label var cons_amici "Number of conservative amicus briefs"
label var lib_cosign "Number of liberal cosigners"
label var cons_cosign "Number of conservative cosigners"
label var num_amici "Number of amici"
label var tot_briefs_cosigners "Total number of briefs and cosigners"
label var tot_briefs_cosigners_lib "Total number of liberal briefs and cosigners"
label var tot_briefs_cosigners_cons "Total number of conservative briefs and cosigners"
label var special_concur "Number of special concurrences"
label var reg_concur "Number of regular concurrences"
label var any_concur "Number of concurrences"

label var special_concur_opin "Number of special concurrence opinions"
label var reg_concur_opin "Number of regular concurrences opinions"
label var any_concur_opin "Number of concurrences opinions"

label var dissent_opin "Number of dissenting opinions"

label var Dissent4 "Number of four Justice dissents"
label var Dissent4Opin "Number of four Justice dissents with opinion"
label var Dissent3 "Number of three Justice dissents"
label var Dissent3Opin "Number of three Justice dissents with opinion"
label var Dissent2 "Number of two Justice dissents"
label var Dissent2Opin "Number of two Justice dissents with opinion"
label var Dissent1 "Number of single Justice dissents"
label var Dissent1Opin "Number of single Justice dissents with opinion"
label var concur_opin "Number of concurrences with opinion"
label var libdissent_opin "Number of liberal dissents with opinions"
label var condissent_opin "Number of conservative dissents with opinions"
label var disnum "Number of dissents"
label var disc "Number of conservative dissents"
label var disl "Number of liberal dissents"
label var connum "Number of concurrences"
label var conl "Number of liberal concurrences"
label var conc "Number of conservative concurrences"
label var latentComplexity "Mean complexity"
label var wordLog_zscore_ls "Number of words per case, logged"

label var petac_ls "Number of amicus curiae briefs filed for petitioner"
label var respac_ls "Number of amicus curiae briefs filed for respondent"
label var otherac_ls  "Number of other amicus curiae briefs"
label var totalac_ls  "Total number of amicus curiae briefs filed"
label var sgpet_ls  "Solicitor General represented petitioner"
label var sgresp_ls  "Solicitor General represented respondent"
label var sgpetac_ls "Solicitor General filed an amicus brief for petitioner"
label var sgrespac_ls "Solicitor General filed an amicus brief for respondent"
label var sgotherac_ls  "Solicitor General filed an other amicus brief"
label var sgamicus_ls  "Solicitor General filed an amicus brief"
label var liberalac_ls "Number of amicus briefs advocating the liberal position"
label var conservac_ls "Number of amicus briefs advocating the conservative position"
label var sglibparty_ls "Solicitor General advocated the liberal position as a litigant"
label var sgconparty_ls "Solicitor General advocated the conservative position as a litigant"
label var sglibac_ls "Solicitor General filed an amicus brief advocating the liberal position"
label var sgconac_ls "Solicitor General filed an amicus brief advocating the conservative position"
label var earlyCoverage_LAT_ls "Early coverage LA Times"
label var earlyCoverage_WAPO_ls "Early coverage WaPo Times"
label var earlyCoverage_NYT_ls "Early coverage NY Times"
label var early_sal_ls "Early salience"

label var CLR_early_ls "CLR early coverage"




use "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Supreme Court Final OneDrive/2023_2_11_SCDB_Baird_CaseJusticeAmicus.dta"


replace 	years_same_court = 0 if 	term == 	1946
replace 	years_same_court = 1 if 	term == 	1947
replace 	years_same_court = 2 if 	term == 	1948
replace 	years_same_court = 0 if 	term == 	1949
replace 	years_same_court = 1 if 	term == 	1950
replace 	years_same_court = 2 if 	term == 	1951
replace 	years_same_court = 3 if 	term == 	1952
replace 	years_same_court = 0 if 	term == 	1953
replace 	years_same_court = 0 if 	term == 	1954
replace 	years_same_court = 0 if 	term == 	1954
replace 	years_same_court = 1 if 	term == 	1955
replace 	years_same_court = 2 if 	term == 	1956
replace 	years_same_court = 0 if 	term == 	1956
replace 	years_same_court = 0 if 	term == 	1956
replace 	years_same_court = 1 if 	term == 	1957
replace 	years_same_court = 2 if 	term == 	1958
replace 	years_same_court = 0 if 	term == 	1958
replace 	years_same_court = 1 if 	term == 	1959
replace 	years_same_court = 2 if 	term == 	1960
replace 	years_same_court = 3 if 	term == 	1961
replace 	years_same_court = 0 if 	term == 	1961
replace 	years_same_court = 0 if 	term == 	1962
replace 	years_same_court = 1 if 	term == 	1963
replace 	years_same_court = 2 if 	term == 	1964
replace 	years_same_court = 0 if 	term == 	1965
replace 	years_same_court = 1 if 	term == 	1966
replace 	years_same_court = 0 if 	term == 	1967
replace 	years_same_court = 1 if 	term == 	1968
replace 	years_same_court = 0 if 	term == 	1968
replace 	years_same_court = 0 if 	term == 	1969
replace 	years_same_court = 0 if 	term == 	1969
replace 	years_same_court = 1 if 	term == 	1970
replace 	years_same_court = 0 if 	term == 	1971
replace 	years_same_court = 0 if 	term == 	1971
replace 	years_same_court = 1 if 	term == 	1972
replace 	years_same_court = 2 if 	term == 	1973
replace 	years_same_court = 3 if 	term == 	1974
replace 	years_same_court = 4 if 	term == 	1975
replace 	years_same_court = 0 if 	term == 	1975
replace 	years_same_court = 1 if 	term == 	1975
replace 	years_same_court = 2 if 	term == 	1976
replace 	years_same_court = 3 if 	term == 	1977
replace 	years_same_court = 4 if 	term == 	1978
replace 	years_same_court = 5 if 	term == 	1979
replace 	years_same_court = 6 if 	term == 	1980
replace 	years_same_court = 0 if 	term == 	1981
replace 	years_same_court = 1 if 	term == 	1982
replace 	years_same_court = 2 if 	term == 	1983
replace 	years_same_court = 3 if 	term == 	1984
replace 	years_same_court = 4 if 	term == 	1985
replace 	years_same_court = 0 if 	term == 	1986
replace 	years_same_court = 1 if 	term == 	1987
replace 	years_same_court = 0 if 	term == 	1987
replace 	years_same_court = 1 if 	term == 	1988
replace 	years_same_court = 2 if 	term == 	1989
replace 	years_same_court = 0 if 	term == 	1990
replace 	years_same_court = 0 if 	term == 	1991
replace 	years_same_court = 1 if 	term == 	1992
replace 	years_same_court = 0 if 	term == 	1993
replace 	years_same_court = 0 if 	term == 	1994
replace 	years_same_court = 1 if 	term == 	1995
replace 	years_same_court = 2 if 	term == 	1996
replace 	years_same_court = 3 if 	term == 	1997
replace 	years_same_court = 4 if 	term == 	1998
replace 	years_same_court = 5 if 	term == 	1999
replace 	years_same_court = 6 if 	term == 	2000
replace 	years_same_court = 7 if 	term == 	2001
replace 	years_same_court = 8 if 	term == 	2002
replace 	years_same_court = 9 if 	term == 	2003
replace 	years_same_court = 10 if 	term == 	2004
replace 	years_same_court = 0 if 	term == 	2005
replace 	years_same_court = 0 if 	term == 	2005
replace 	years_same_court = 1 if 	term == 	2006
replace 	years_same_court = 2 if 	term == 	2007
replace 	years_same_court = 3 if 	term == 	2008
replace 	years_same_court = 0 if 	term == 	2009
replace 	years_same_court = 0 if 	term == 	2009
replace 	years_same_court = 1 if 	term == 	2010
replace 	years_same_court = 2 if 	term == 	2011
replace 	years_same_court = 3 if 	term == 	2012
replace 	years_same_court = 4 if 	term == 	2013
replace 	years_same_court = 5 if 	term == 	2014
replace 	years_same_court = 6 if 	term == 	2015
replace 	years_same_court = 0 if 	term == 	2015
replace 	years_same_court = 1 if 	term == 	2016
replace 	years_same_court = 0 if 	term == 	2016
replace 	years_same_court = 1 if 	term == 	2017
replace 	years_same_court = 2 if 	term == 	2018
replace 	years_same_court = 0 if 	term == 	2018
replace 	years_same_court = 1 if 	term == 	2019
replace 	years_same_court = 0 if 	term == 	2020
replace 	years_same_court = 1 if 	term == 	2021


sort term svalue

save "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Supreme Court Final OneDrive/2023_6_20_SCDB_Baird_CaseJusticeAmicus.dta", replace

collapse (mean) medmaj_rat_noconcur_jcs medmaj_rat_nospec_jcs /// 
medmaj_vote_nodis_jcs medmaj_vote_dis_jcs ideo_doct ideo_doct01 /// 
years_same_court burger rehnquist roberts vinson warren vote_coalition vote_contentious ///
(sum) cases lib con lib_lct con_lct  n54 n56 n63 n78 n81 n72 unam  ///
n54c n56c n63c n78c n81c n72c unaml unamc n54l n56l n63l n78l n81l n72l n54cc ///
n56cc n63cc n78cc n81cc n72cc unamcc n54ll n56ll n63ll n78ll n81ll n72ll ///
unamll n54lc n56lc n63lc n78lc n81lc n72lc unamlc n54cl n56cl n63cl n78cl ///
n81cl n72cl unamcl uncon muni state fed unconl unconc munic munil fedl fedc ///
statel statec rev revl revc prec precc precl cert_cat cert_sal ///
nyt cq nytl nytc cql cqc salienceest saliencesd ///
source_circ source_district source_state FirstCircuit SecondCircuit ///
ThirdCircuit FourthCircuit FifthCircuit SixthCircuit SeventhCircuit ///
EighthCircuit NinthCircuit TenthCircuit EleventhCircuit DCCircuit ///
OtherCircuit origin_circ origin_district origin_state const_type nonconst_type ///
us_party state_party local_party jud_party bus_party person_party nonprof_party ///
foreign_party persbus_party us_win state_win local_win jud_win bus_win person_win ///
nonprof_win foreign_win persbus_win buswin_low buswin_gov buswin_lowc ///
buswin_lowl buswin_govc buswin_govl lib_amici cons_amici ///
lib_cosign cons_cosign num_amici tot_briefs_cosigners tot_briefs_cosigners_lib /// 
tot_briefs_cosigners_cons /// 
special_concur reg_concur any_concur special_concur_opin ///
reg_concur_opin any_concur_opin dissent_opin NoDissent Dissent4 ///
Dissent4Opin Dissent3 Dissent3Opin Dissent2 Dissent2Opin Dissent1 ///
Dissent1Opin concur_opin libdissent_opin condissent_opin disnum disc disl connum conl conc ///
(mean) latentComplexity wordLog_zscore_ls PresCourtDist_ls ConstraintDist_ls SJchairDist_ls ///
HJchairDist_ls FloorMedianOverModel_ls FilibusterVeto_ls PartyPivotGate_ls ///
JudiciaryMedGate_ls JudiciaryChairGate_ls lagmood_ls mood_ls pres_ls senate_ls ///
house_ls court_ls cong_ls seg_med_ls lawmakmaj_ls courtdems_ls courtreps_ls ///
dempres_ls sdpercen_ls cdpercen_ls hdpercen_ls demcong_ls repcong_ls divcong_ls ///
demcourt_ls oppctcn_ls p_ct_dist_ls cn_ct_dist_ls regime_ls constraint_ls ///
relconglib_ls regimepres_ls constraintp_ls relreglib_ls swlstrike_ls ///
JCSPredProb_ls bills_ls statchal_ls sc_med_ls unem_ls perchcpi_ls ///
def_budg_ls  homicide_ls inequality_ls lagcurbbills_ls ///
lagcurbing_ls curbbills_ls curbing_ls oppcong_ls gss_conf_ls divergence_ls ///
appoint_ls     (sum) petac_ls respac_ls otherac_ls totalac_ls sgpet_ls ///
sgresp_ls sgpetac_ls sgrespac_ls sgotherac_ls sgamicus_ls liberalac_ls ///
conservac_ls sglibparty_ls sgconparty_ls sglibac_ls sgconac_ls pre3_ls ///
BSJsal_ls BSJ_5_ls pre5_ls ac15_ls ac5_ls earlyCoverage_LAT_ls ///
earlyCoverage_WAPO_ls earlyCoverage_NYT_ls early_sal_ls early_sal_dum_ls ///
CLR_early_ls earlysaliencesd_ls arg_sal_ls arg_sal_dum_ls pend_sal_ls ///
pend_sal_dum_ls pre_dec_ls pre_dec_dum_ls post_dec_ls post_dec_dum_ls ///
sgsupp_ls amisupp_ls amiopp_ls lat_ls cq_salient_ls nyt_salient_ls rb_add_ls  , by ( term svalue)


save "${sc_Working}2023_6_20_SCDB_Baird_CaseJusticeAmicus_svalue_term.dta", replace

merge 1:1 caseId using  "${sc_Working}2023_SCDB_Baird_Justice2021_from_justice_to_Caseid_Working.dta"

rename term year 

merge 1:1 year svalue using "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/ToBeFiled/year svalue zeroes.dta"

drop if svalue == 0

drop if year > 2020

drop if svalue == .





sort svalue term 
by svalue_gen: gen lag1 = x[_n-1]









lib con lib_lct con_lct  n54 n56 n63 n78 n81 n72 unam  ///
n54c n56c n63c n78c n81c n72c unaml unamc n54l n56l n63l n78l n81l n72l n54cc ///
n56cc n63cc n78cc n81cc n72cc unamcc n54ll n56ll n63ll n78ll n81ll n72ll ///
unamll n54lc n56lc n63lc n78lc n81lc n72lc unamlc n54cl n56cl n63cl n78cl ///
n81cl n72cl unamcl uncon muni state fed unconl unconc munic munil fedl fedc ///
statel statec rev revl revc prec precc precl cert_cat cert_sal ///
nyt cq nytl nytc cql cqc salienceest saliencesd ///
source_circ source_district source_state FirstCircuit SecondCircuit ///
ThirdCircuit FourthCircuit FifthCircuit SixthCircuit SeventhCircuit ///
EighthCircuit NinthCircuit TenthCircuit EleventhCircuit DCCircuit ///
OtherCircuit origin_circ origin_district origin_state const_type nonconst_type ///
us_party state_party local_party jud_party bus_party person_party nonprof_party ///
foreign_party persbus_party us_win state_win local_win jud_win bus_win person_win ///
nonprof_win foreign_win persbus_win buswin_low buswin_gov buswin_lowc ///
buswin_lowl buswin_govc buswin_govl lib_amici cons_amici ///
lib_cosign cons_cosign num_amici tot_briefs_cosigners tot_briefs_cosigners_lib /// 
tot_briefs_cosigners_cons /// 
special_concur reg_concur any_concur special_concur_opin ///
reg_concur_opin any_concur_opin dissent_opin NoDissent Dissent4 ///
Dissent4Opin Dissent3 Dissent3Opin Dissent2 Dissent2Opin Dissent1 ///
Dissent1Opin concur_opin libdissent_opin condissent_opin disnum disc disl connum conl conc



recode lib (. = 0) 
recode con (. = 0) 
recode lib_lct (. = 0) 
recode con_lct (. = 0) 

recode n54 (. = 0) 
recode n56 (. = 0) 
recode n63 (. = 0) 
recode n78 (. = 0) 
recode n81 (. = 0) 
recode n72 (. = 0) 
recode unam (. = 0) 

recode n54c (. = 0) 
recode n56c (. = 0) 
recode n63c (. = 0) 
recode n78c (. = 0) 
recode n81c (. = 0) 
recode n72c (. = 0) 
recode unaml (. = 0) 
recode unamc (. = 0) 
recode n54l (. = 0) 
recode n56l (. = 0) 
recode n63l (. = 0) 
recode n78l (. = 0) 
recode n81l (. = 0) 
recode n72l (. = 0) 
recode n54cc (. = 0) 
recode n56cc (. = 0) 
recode n63cc (. = 0) 
recode n78cc (. = 0) 
recode n81cc (. = 0) 
recode n72cc (. = 0) 
recode unamcc (. = 0) 
recode n54ll (. = 0) 
recode n56ll (. = 0) 
recode n63ll (. = 0) 
recode n78ll (. = 0) 
recode n81ll (. = 0) 
recode n72ll (. = 0) 
recode unamll (. = 0) 
recode n54lc (. = 0) 
recode n56lc (. = 0) 
recode n63lc (. = 0) 
recode n78lc (. = 0) 
recode n81lc (. = 0) 
recode n72lc (. = 0) 
recode unamlc (. = 0) 
recode n54cl (. = 0) 
recode n56cl (. = 0) 
recode n63cl (. = 0) 
recode n78cl (. = 0) 
recode n81cl (. = 0) 
recode n72cl (. = 0) 
recode unamcl (. = 0) 
recode uncon (. = 0) 
recode muni (. = 0) 
recode state (. = 0) 
recode fed (. = 0) 
recode unconl (. = 0) 
recode unconc (. = 0) 
recode munic (. = 0) 
recode munil (. = 0) 
recode fedl (. = 0) 
recode fedc (. = 0) 
recode statel (. = 0) 
recode statec (. = 0) 
recode rev (. = 0) 
recode revl (. = 0) 
recode revc (. = 0) 
recode prec (. = 0) 
recode precc (. = 0) 
recode precl (. = 0) 
recode cert_cat (. = 0) 
recode cert_sal (. = 0) 
recode nyt (. = 0) 
recode cq (. = 0) 
recode nytl (. = 0) 
recode nytc (. = 0) 
recode cql (. = 0) 
recode cqc (. = 0) 
recode salienceest (. = 0) 
recode saliencesd (. = 0) 
recode source_circ (. = 0) 
recode source_district (. = 0) 
recode source_state (. = 0) 
recode FirstCircuit (. = 0) 
recode SecondCircuit (. = 0) 
recode ThirdCircuit (. = 0) 
recode FourthCircuit (. = 0) 
recode FifthCircuit (. = 0) 
recode SixthCircuit (. = 0) 
recode SeventhCircuit (. = 0) 
recode EighthCircuit (. = 0) 
recode NinthCircuit (. = 0) 
recode TenthCircuit (. = 0) 
recode EleventhCircuit (. = 0) 
recode DCCircuit (. = 0) 
recode OtherCircuit (. = 0) 
recode origin_circ (. = 0) 
recode origin_district (. = 0) 
recode origin_state (. = 0) 
recode const_type (. = 0) 
recode nonconst_type (. = 0) 
recode us_party (. = 0) 
recode state_party (. = 0) 
recode local_party (. = 0) 
recode jud_party (. = 0) 
recode bus_party (. = 0) 
recode person_party (. = 0) 
recode nonprof_party (. = 0) 
recode foreign_party (. = 0) 
recode persbus_party (. = 0) 
recode us_win (. = 0) 
recode state_win (. = 0) 
recode local_win (. = 0) 
recode jud_win (. = 0) 
recode bus_win (. = 0) 
recode person_win (. = 0) 
recode nonprof_win (. = 0) 
recode foreign_win (. = 0) 
recode persbus_win (. = 0) 
recode buswin_low (. = 0) 
recode buswin_gov (. = 0) 
recode buswin_lowc (. = 0) 
recode buswin_lowl (. = 0) 
recode buswin_govc (. = 0) 
recode buswin_govl (. = 0) 
recode lib_amici (. = 0) 
recode cons_amici (. = 0) 
recode lib_cosign (. = 0) 
recode cons_cosign (. = 0) 
recode num_amici (. = 0) 
recode tot_briefs_cosigners (. = 0) 
recode tot_briefs_cosigners_lib (. = 0) 
recode tot_briefs_cosigners_cons (. = 0) 
recode special_concur (. = 0) 
recode reg_concur (. = 0) 
recode any_concur (. = 0) 
recode special_concur_opin (. = 0) 
recode reg_concur_opin (. = 0) 
recode any_concur_opin (. = 0) 
recode dissent_opin (. = 0) 
recode NoDissent (. = 0) 
recode Dissent4 (. = 0) 
recode Dissent4Opin (. = 0) 
recode Dissent3 (. = 0) 
recode Dissent3Opin (. = 0) 
recode Dissent2 (. = 0) 
recode Dissent2Opin (. = 0) 
recode Dissent1 (. = 0) 
recode Dissent1Opin (. = 0) 
recode concur_opin (. = 0) 
recode libdissent_opin (. = 0) 
recode condissent_opin (. = 0) 
recode disnum (. = 0) 
recode disc (. = 0) 
recode disl (. = 0) 
recode connum (. = 0) 
recode conl (. = 0) 
recode conc  (. = 0) 


save "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/2023_6_20_SCDB_Baird_term_JCSmedian.dta"

use "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/2023_6_20_SCDB_Baird_CaseJusticeAmicus_svalue_term.dta"

merge m:1 term using  "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/2023_6_20_SCDB_Baird_term_JCSmedian.dta"

save "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/2023_6_20_SCDB_Baird_CaseJusticeAmicus_svalue_term.dta", replace

    sum JCS_SCmedian
    gen JCS_SCmedian01 = ((JCS_SCmedian - `r(min)') / (`r(max)' - `r(min)')) 

use "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Supreme Court Final OneDrive/2023_2_12_SCDB_Baird_All_term.dta"

keep term ideo_doct_rev ideo_doct_revc ideo_doct_revl ideo_doct_aff ideo_doct_affc ideo_doct_affl ideo_doct_lib ideo_doct_cons bus_party bus_win buswin_low buswin_gov buswin_lowc buswin_lowl buswin_govc buswin_govl Dissent4Opin Dissent3Opin Dissent2Opin Dissent1Opin libdissent_opin condissent_opin house_median lhouse_median l2house_median l3house_median l4house_median l5house_median l6house_median senate_median lsenate_median l2senate_median l3senate_median l4senate_median l5senate_median l6senate_median

rename term year 

rename ideo_doct_rev ideo_doct_rev_term
rename ideo_doct_revc ideo_doct_revc_term
rename ideo_doct_revl ideo_doct_revl_term
rename ideo_doct_aff ideo_doct_aff_term
rename ideo_doct_affc ideo_doct_affc_term
rename ideo_doct_affl ideo_doct_affl_term
rename ideo_doct_lib ideo_doct_lib_term
rename ideo_doct_cons ideo_doct_cons_term
rename bus_party bus_party_term
rename bus_win bus_win_term
rename buswin_low buswin_low_term
rename buswin_gov buswin_gov_term
rename buswin_lowc buswin_lowc_term
rename buswin_lowl buswin_lowl_term
rename buswin_govc buswin_govc_term
rename buswin_govl buswin_govl_term
rename Dissent4Opin Dissent4Opin_term
rename Dissent3Opin Dissent3Opin_term
rename Dissent2Opin Dissent2Opin_term
rename Dissent1Opin Dissent1Opin_term
rename libdissent_opin libdissent_opin_term
rename condissent_opin condissent_opin_term
rename house_median house_median_term
rename senate_median senate_median_term
rename lhouse_median lhouse_median_term
rename lsenate_median lsenate_median_term
rename l2house_median l2house_median_term
rename l2senate_median l2senate_median_term
rename l3house_median l3house_median_term
rename l3senate_median l3senate_median_term
rename l4house_median l4house_median_term
rename l4senate_median l4senate_median_term
rename l5house_median l5house_median_term
rename l5senate_median l5senate_median_term
rename l6house_median l6house_median_term
rename l6senate_median l6senate_median_term


save "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/2023_6_20_SCDB_Baird_All_term_limited.dta", replace



use "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/2023_6_20_SCDB_Baird_CaseJusticeAmicus_svalue_term.dta"

sort year 
drop _merge
merge m:1 year using  "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/2023_6_20_SCDB_Baird_All_term_limited.dta"

replace medmaj_rat_noconcur_jcs = JCS_SCmedian if medmaj_rat_noconcur_jcs ==.
replace medmaj_rat_nospec_jcs  = JCS_SCmedian if medmaj_rat_nospec_jcs ==.
replace medmaj_vote_nodis_jcs = JCS_SCmedian if medmaj_vote_nodis_jcs ==.
replace medmaj_vote_dis_jcs = JCS_SCmedian if medmaj_vote_dis_jcs ==.
replace ideo_doct  = JCS_SCmedian if ideo_doct ==.

replace ideo_doct01 = JCS_SCmedian01 if ideo_doct01 ==.

save "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Supreme Court/Working/2023_6_20_SCDB_Baird_CaseJusticeAmicus_svalue_term.dta", replace







sum rev
gen rev01 = ((rev - `r(min)') / (`r(max)' - `r(min)')) 


sum revl
gen revl01 = ((revl - `r(min)') / (`r(max)' - `r(min)')) 


sum revc
gen revc01 = ((revc - `r(min)') / (`r(max)' - `r(min)')) 


sum prec
gen prec01 = ((prec - `r(min)') / (`r(max)' - `r(min)')) 


sum precl
gen precl01 = ((precl - `r(min)') / (`r(max)' - `r(min)')) 


sum precc
gen precc01 = ((precc - `r(min)') / (`r(max)' - `r(min)')) 



sum cert_sal
gen cert_sal01 = ((cert_sal - `r(min)') / (`r(max)' - `r(min)')) 


sum nyt
gen nyt01 = ((nyt - `r(min)') / (`r(max)' - `r(min)')) 


sum nytl
gen nytl01 = ((nytl - `r(min)') / (`r(max)' - `r(min)')) 


sum nytc
gen nytc01 = ((nytc - `r(min)') / (`r(max)' - `r(min)')) 



sum uncon
gen uncon01 = ((uncon - `r(min)') / (`r(max)' - `r(min)')) 


sum unconl
gen unconl01 = ((unconl - `r(min)') / (`r(max)' - `r(min)')) 


sum unconc
gen unconc01 = ((unconc - `r(min)') / (`r(max)' - `r(min)')) 


 

sum concur_opin
gen concur_opin01 = ((concur_opin - `r(min)') / (`r(max)' - `r(min)')) 


 

sum dissent_opin
gen dissent_opin01 = ((dissent_opin - `r(min)') / (`r(max)' - `r(min)')) 


sum libdissent_opin
gen libdissent_opin01 = ((libdissent_opin - `r(min)') / (`r(max)' - `r(min)')) 

sum condissent_opin
gen condissent_opin01 = ((condissent_opin - `r(min)') / (`r(max)' - `r(min)')) 



order year svalue



order cases JCS_SCmedian ideo_doct ideo_doct01 /// 
ideo_doct_rev_term ideo_doct_revc_term ideo_doct_revl_term /// 
ideo_doct_aff_term ideo_doct_affc_term ideo_doct_affl_term /// 
ideo_doct_lib_term ideo_doct_cons_term bus_party_term bus_win_term /// 
buswin_low_term buswin_gov_term buswin_lowc_term buswin_lowl_term /// 
buswin_govc_term buswin_govl_term Dissent4Opin_term Dissent3Opin_term /// 
Dissent2Opin_term Dissent1Opin_term libdissent_opin_term condissent_opin_term /// 
house_median_term senate_median_term ///
medmaj_rat_noconcur_jcs medmaj_rat_nospec_jcs /// 
medmaj_vote_nodis_jcs medmaj_vote_dis_jcs /// 
years_same_court burger rehnquist roberts vinson warren vote_coalition vote_contentious ///
 lib con lib_lct con_lct  n54 n56 n63 n78 n81 n72 unam  ///
n54c n56c n63c n78c n81c n72c unaml unamc n54l n56l n63l n78l n81l n72l n54cc ///
n56cc n63cc n78cc n81cc n72cc unamcc n54ll n56ll n63ll n78ll n81ll n72ll ///
unamll n54lc n56lc n63lc n78lc n81lc n72lc unamlc n54cl n56cl n63cl n78cl ///
n81cl n72cl unamcl uncon muni state fed unconl unconc munic munil fedl fedc ///
statel statec rev revl revc prec precc precl cert_cat cert_sal ///
nyt cq nytl nytc cql cqc salienceest saliencesd ///
source_circ source_district source_state FirstCircuit SecondCircuit ///
ThirdCircuit FourthCircuit FifthCircuit SixthCircuit SeventhCircuit ///
EighthCircuit NinthCircuit TenthCircuit EleventhCircuit DCCircuit ///
OtherCircuit origin_circ origin_district origin_state const_type nonconst_type ///
us_party state_party local_party jud_party bus_party person_party nonprof_party ///
foreign_party persbus_party us_win state_win local_win jud_win bus_win person_win ///
nonprof_win foreign_win persbus_win buswin_low buswin_gov buswin_lowc ///
buswin_lowl buswin_govc buswin_govl lib_amici cons_amici ///
lib_cosign cons_cosign num_amici tot_briefs_cosigners tot_briefs_cosigners_lib /// 
tot_briefs_cosigners_cons /// 
lhouse_median_term lsenate_median_term /// 
l2house_median_term l2senate_median_term l3house_median_term l3senate_median_term /// 
l4house_median_term l4senate_median_term l5house_median_term /// 
l5senate_median_term l6house_median_term l6senate_median_term ///
special_concur reg_concur any_concur special_concur_opin ///
reg_concur_opin any_concur_opin dissent_opin NoDissent Dissent4 ///
Dissent4Opin Dissent3 Dissent3Opin Dissent2 Dissent2Opin Dissent1 ///
Dissent1Opin concur_opin libdissent_opin condissent_opin disnum disc disl connum conl conc ///
latentComplexity wordLog_zscore_ls PresCourtDist_ls ConstraintDist_ls SJchairDist_ls ///
HJchairDist_ls FloorMedianOverModel_ls FilibusterVeto_ls PartyPivotGate_ls ///
JudiciaryMedGate_ls JudiciaryChairGate_ls lagmood_ls mood_ls pres_ls senate_ls ///
house_ls court_ls cong_ls seg_med_ls lawmakmaj_ls courtdems_ls courtreps_ls ///
dempres_ls sdpercen_ls cdpercen_ls hdpercen_ls demcong_ls repcong_ls divcong_ls ///
demcourt_ls oppctcn_ls p_ct_dist_ls cn_ct_dist_ls regime_ls constraint_ls ///
relconglib_ls regimepres_ls constraintp_ls relreglib_ls swlstrike_ls ///
JCSPredProb_ls bills_ls statchal_ls sc_med_ls unem_ls perchcpi_ls ///
def_budg_ls  homicide_ls inequality_ls lagcurbbills_ls ///
lagcurbing_ls curbbills_ls curbing_ls oppcong_ls gss_conf_ls divergence_ls ///
appoint_ls  petac_ls respac_ls otherac_ls totalac_ls sgpet_ls ///
sgresp_ls sgpetac_ls sgrespac_ls sgotherac_ls sgamicus_ls liberalac_ls ///
conservac_ls sglibparty_ls sgconparty_ls sglibac_ls sgconac_ls pre3_ls ///
BSJsal_ls BSJ_5_ls pre5_ls ac15_ls ac5_ls earlyCoverage_LAT_ls ///
earlyCoverage_WAPO_ls earlyCoverage_NYT_ls early_sal_ls early_sal_dum_ls ///
CLR_early_ls earlysaliencesd_ls arg_sal_ls arg_sal_dum_ls pend_sal_ls ///
pend_sal_dum_ls pre_dec_ls pre_dec_dum_ls post_dec_ls post_dec_dum_ls ///
sgsupp_ls amisupp_ls amiopp_ls lat_ls cq_salient_ls nyt_salient_ls rb_add_ls  , after (  svalue)

egen ipp_cs = rowmean (rev01 prec01 cert_sal01 nyt01 uncon01 concur_opin01 dissent_opin01)


egen ipp = rowmean (rev01 prec01  nyt01 uncon01 concur_opin01 dissent_opin01)

egen ippl = rowmean (revl01 precl01  nytl01 unconl01 )

egen ippc = rowmean (revc01 precc01  nytc01 unconc01 )


sort   svalue year

by svalue: gen lcases = cases[_n-1]

by svalue: gen l2cases = lcases[_n-1]
by svalue: gen l3cases = l2cases[_n-1]
by svalue: gen l4cases = l3cases[_n-1]
by svalue: gen l5cases = l4cases[_n-1]
by svalue: gen l6cases = l5cases[_n-1]
by svalue: gen l7cases = l6cases[_n-1]


by svalue: gen lipp = ipp[_n-1]
by svalue: gen l2ipp = lipp[_n-1]
by svalue: gen l3ipp = l2ipp[_n-1]
by svalue: gen l4ipp = l3ipp[_n-1]
by svalue: gen l5ipp = l4ipp[_n-1]
by svalue: gen l6ipp = l5ipp[_n-1]
by svalue: gen l7ipp = l6ipp[_n-1]

by svalue: gen lippl = ippl[_n-1]
by svalue: gen l2ippl = lippl[_n-1]
by svalue: gen l3ippl = l2ippl[_n-1]
by svalue: gen l4ippl = l3ippl[_n-1]
by svalue: gen l5ippl = l4ippl[_n-1]
by svalue: gen l6ippl = l5ippl[_n-1]
by svalue: gen l7ippl = l6ippl[_n-1]

by svalue: gen lippc = ippc[_n-1]
by svalue: gen l2ippc = lippc[_n-1]
by svalue: gen l3ippc = l2ippc[_n-1]
by svalue: gen l4ippc = l3ippc[_n-1]
by svalue: gen l5ippc = l4ippc[_n-1]
by svalue: gen l6ippc = l5ippc[_n-1]
by svalue: gen l7ippc = l6ippc[_n-1]


by svalue: gen lcert_sal = cert_sal[_n-1]
by svalue: gen l2cert_sal = lcert_sal[_n-1]
by svalue: gen l3cert_sal = l2cert_sal[_n-1]
by svalue: gen l4cert_sal = l3cert_sal[_n-1]
by svalue: gen l5cert_sal = l4cert_sal[_n-1]
by svalue: gen l6cert_sal = l5cert_sal[_n-1]
by svalue: gen l7cert_sal = l6cert_sal[_n-1]




by svalue: gen ln54 = n54[_n-1]
by svalue: gen l2n54 = ln54[_n-1]
by svalue: gen l3n54 = l2n54[_n-1]
by svalue: gen l4n54 = l3n54[_n-1]
by svalue: gen l5n54 = l4n54[_n-1]
by svalue: gen l6n54 = l5n54[_n-1]
by svalue: gen l7n54 = l6n54[_n-1]

by svalue: gen ln54c = n54c[_n-1]
by svalue: gen l2n54c = ln54c[_n-1]
by svalue: gen l3n54c = l2n54c[_n-1]
by svalue: gen l4n54c = l3n54c[_n-1]
by svalue: gen l5n54c = l4n54c[_n-1]
by svalue: gen l6n54c = l5n54c[_n-1]
by svalue: gen l7n54c = l6n54c[_n-1]

by svalue: gen ln54l = n54l[_n-1]
by svalue: gen l2n54l = ln54l[_n-1]
by svalue: gen l3n54l = l2n54l[_n-1]
by svalue: gen l4n54l = l3n54l[_n-1]
by svalue: gen l5n54l = l4n54l[_n-1]
by svalue: gen l6n54l = l5n54l[_n-1]
by svalue: gen l7n54l = l6n54l[_n-1]

by svalue: gen ln54ll = n54ll[_n-1]
by svalue: gen l2n54ll = ln54ll[_n-1]
by svalue: gen l3n54ll = l2n54ll[_n-1]
by svalue: gen l4n54ll = l3n54ll[_n-1]
by svalue: gen l5n54ll = l4n54ll[_n-1]
by svalue: gen l6n54ll = l5n54ll[_n-1]
by svalue: gen l7n54ll = l6n54ll[_n-1]

by svalue: gen ln54cc = n54cc[_n-1]
by svalue: gen l2n54cc = ln54cc[_n-1]
by svalue: gen l3n54cc = l2n54cc[_n-1]
by svalue: gen l4n54cc = l3n54cc[_n-1]
by svalue: gen l5n54cc = l4n54cc[_n-1]
by svalue: gen l6n54cc = l5n54cc[_n-1]
by svalue: gen l7n54cc = l6n54cc[_n-1]

by svalue: gen ln54cl = n54cl[_n-1]
by svalue: gen l2n54cl = ln54cl[_n-1]
by svalue: gen l3n54cl = l2n54cl[_n-1]
by svalue: gen l4n54cl = l3n54cl[_n-1]
by svalue: gen l5n54cl = l4n54cl[_n-1]
by svalue: gen l6n54cl = l5n54cl[_n-1]
by svalue: gen l7n54cl = l6n54cl[_n-1]











by svalue: gen ln56 = n56[_n-1]
by svalue: gen l2n56 = ln56[_n-1]
by svalue: gen l3n56 = l2n56[_n-1]
by svalue: gen l4n56 = l3n56[_n-1]
by svalue: gen l5n56 = l4n56[_n-1]
by svalue: gen l6n56 = l5n56[_n-1]
by svalue: gen l7n56 = l6n56[_n-1]

by svalue: gen ln56c = n56c[_n-1]
by svalue: gen l2n56c = ln56c[_n-1]
by svalue: gen l3n56c = l2n56c[_n-1]
by svalue: gen l4n56c = l3n56c[_n-1]
by svalue: gen l5n56c = l4n56c[_n-1]
by svalue: gen l6n56c = l5n56c[_n-1]
by svalue: gen l7n56c = l6n56c[_n-1]

by svalue: gen ln56l = n56l[_n-1]
by svalue: gen l2n56l = ln56l[_n-1]
by svalue: gen l3n56l = l2n56l[_n-1]
by svalue: gen l4n56l = l3n56l[_n-1]
by svalue: gen l5n56l = l4n56l[_n-1]
by svalue: gen l6n56l = l5n56l[_n-1]
by svalue: gen l7n56l = l6n56l[_n-1]

by svalue: gen ln56ll = n56ll[_n-1]
by svalue: gen l2n56ll = ln56ll[_n-1]
by svalue: gen l3n56ll = l2n56ll[_n-1]
by svalue: gen l4n56ll = l3n56ll[_n-1]
by svalue: gen l5n56ll = l4n56ll[_n-1]
by svalue: gen l6n56ll = l5n56ll[_n-1]
by svalue: gen l7n56ll = l6n56ll[_n-1]

by svalue: gen ln56cc = n56cc[_n-1]
by svalue: gen l2n56cc = ln56cc[_n-1]
by svalue: gen l3n56cc = l2n56cc[_n-1]
by svalue: gen l4n56cc = l3n56cc[_n-1]
by svalue: gen l5n56cc = l4n56cc[_n-1]
by svalue: gen l6n56cc = l5n56cc[_n-1]
by svalue: gen l7n56cc = l6n56cc[_n-1]

by svalue: gen ln56cl = n56cl[_n-1]
by svalue: gen l2n56cl = ln56cl[_n-1]
by svalue: gen l3n56cl = l2n56cl[_n-1]
by svalue: gen l4n56cl = l3n56cl[_n-1]
by svalue: gen l5n56cl = l4n56cl[_n-1]
by svalue: gen l6n56cl = l5n56cl[_n-1]
by svalue: gen l7n56cl = l6n56cl[_n-1]











by svalue: gen ln63 = n63[_n-1]
by svalue: gen l2n63 = ln63[_n-1]
by svalue: gen l3n63 = l2n63[_n-1]
by svalue: gen l4n63 = l3n63[_n-1]
by svalue: gen l5n63 = l4n63[_n-1]
by svalue: gen l6n63 = l5n63[_n-1]
by svalue: gen l7n63 = l6n63[_n-1]

by svalue: gen ln63c = n63c[_n-1]
by svalue: gen l2n63c = ln63c[_n-1]
by svalue: gen l3n63c = l2n63c[_n-1]
by svalue: gen l4n63c = l3n63c[_n-1]
by svalue: gen l5n63c = l4n63c[_n-1]
by svalue: gen l6n63c = l5n63c[_n-1]
by svalue: gen l7n63c = l6n63c[_n-1]

by svalue: gen ln63l = n63l[_n-1]
by svalue: gen l2n63l = ln63l[_n-1]
by svalue: gen l3n63l = l2n63l[_n-1]
by svalue: gen l4n63l = l3n63l[_n-1]
by svalue: gen l5n63l = l4n63l[_n-1]
by svalue: gen l6n63l = l5n63l[_n-1]
by svalue: gen l7n63l = l6n63l[_n-1]

by svalue: gen ln63ll = n63ll[_n-1]
by svalue: gen l2n63ll = ln63ll[_n-1]
by svalue: gen l3n63ll = l2n63ll[_n-1]
by svalue: gen l4n63ll = l3n63ll[_n-1]
by svalue: gen l5n63ll = l4n63ll[_n-1]
by svalue: gen l6n63ll = l5n63ll[_n-1]
by svalue: gen l7n63ll = l6n63ll[_n-1]

by svalue: gen ln63cc = n63cc[_n-1]
by svalue: gen l2n63cc = ln63cc[_n-1]
by svalue: gen l3n63cc = l2n63cc[_n-1]
by svalue: gen l4n63cc = l3n63cc[_n-1]
by svalue: gen l5n63cc = l4n63cc[_n-1]
by svalue: gen l6n63cc = l5n63cc[_n-1]
by svalue: gen l7n63cc = l6n63cc[_n-1]

by svalue: gen ln63cl = n63cl[_n-1]
by svalue: gen l2n63cl = ln63cl[_n-1]
by svalue: gen l3n63cl = l2n63cl[_n-1]
by svalue: gen l4n63cl = l3n63cl[_n-1]
by svalue: gen l5n63cl = l4n63cl[_n-1]
by svalue: gen l6n63cl = l5n63cl[_n-1]
by svalue: gen l7n63cl = l6n63cl[_n-1]












by svalue: gen ln78 = n78[_n-1]
by svalue: gen l2n78 = ln78[_n-1]
by svalue: gen l3n78 = l2n78[_n-1]
by svalue: gen l4n78 = l3n78[_n-1]
by svalue: gen l5n78 = l4n78[_n-1]
by svalue: gen l6n78 = l5n78[_n-1]
by svalue: gen l7n78 = l6n78[_n-1]

by svalue: gen ln78c = n78c[_n-1]
by svalue: gen l2n78c = ln78c[_n-1]
by svalue: gen l3n78c = l2n78c[_n-1]
by svalue: gen l4n78c = l3n78c[_n-1]
by svalue: gen l5n78c = l4n78c[_n-1]
by svalue: gen l6n78c = l5n78c[_n-1]
by svalue: gen l7n78c = l6n78c[_n-1]

by svalue: gen ln78l = n78l[_n-1]
by svalue: gen l2n78l = ln78l[_n-1]
by svalue: gen l3n78l = l2n78l[_n-1]
by svalue: gen l4n78l = l3n78l[_n-1]
by svalue: gen l5n78l = l4n78l[_n-1]
by svalue: gen l6n78l = l5n78l[_n-1]
by svalue: gen l7n78l = l6n78l[_n-1]

by svalue: gen ln78ll = n78ll[_n-1]
by svalue: gen l2n78ll = ln78ll[_n-1]
by svalue: gen l3n78ll = l2n78ll[_n-1]
by svalue: gen l4n78ll = l3n78ll[_n-1]
by svalue: gen l5n78ll = l4n78ll[_n-1]
by svalue: gen l6n78ll = l5n78ll[_n-1]
by svalue: gen l7n78ll = l6n78ll[_n-1]

by svalue: gen ln78cc = n78cc[_n-1]
by svalue: gen l2n78cc = ln78cc[_n-1]
by svalue: gen l3n78cc = l2n78cc[_n-1]
by svalue: gen l4n78cc = l3n78cc[_n-1]
by svalue: gen l5n78cc = l4n78cc[_n-1]
by svalue: gen l6n78cc = l5n78cc[_n-1]
by svalue: gen l7n78cc = l6n78cc[_n-1]

by svalue: gen ln78cl = n78cl[_n-1]
by svalue: gen l2n78cl = ln78cl[_n-1]
by svalue: gen l3n78cl = l2n78cl[_n-1]
by svalue: gen l4n78cl = l3n78cl[_n-1]
by svalue: gen l5n78cl = l4n78cl[_n-1]
by svalue: gen l6n78cl = l5n78cl[_n-1]
by svalue: gen l7n78cl = l6n78cl[_n-1]







by svalue: gen ln81 = n81[_n-1]
by svalue: gen l2n81 = ln81[_n-1]
by svalue: gen l3n81 = l2n81[_n-1]
by svalue: gen l4n81 = l3n81[_n-1]
by svalue: gen l5n81 = l4n81[_n-1]
by svalue: gen l6n81 = l5n81[_n-1]
by svalue: gen l7n81 = l6n81[_n-1]

by svalue: gen ln81c = n81c[_n-1]
by svalue: gen l2n81c = ln81c[_n-1]
by svalue: gen l3n81c = l2n81c[_n-1]
by svalue: gen l4n81c = l3n81c[_n-1]
by svalue: gen l5n81c = l4n81c[_n-1]
by svalue: gen l6n81c = l5n81c[_n-1]
by svalue: gen l7n81c = l6n81c[_n-1]

by svalue: gen ln81l = n81l[_n-1]
by svalue: gen l2n81l = ln81l[_n-1]
by svalue: gen l3n81l = l2n81l[_n-1]
by svalue: gen l4n81l = l3n81l[_n-1]
by svalue: gen l5n81l = l4n81l[_n-1]
by svalue: gen l6n81l = l5n81l[_n-1]
by svalue: gen l7n81l = l6n81l[_n-1]

by svalue: gen ln81ll = n81ll[_n-1]
by svalue: gen l2n81ll = ln81ll[_n-1]
by svalue: gen l3n81ll = l2n81ll[_n-1]
by svalue: gen l4n81ll = l3n81ll[_n-1]
by svalue: gen l5n81ll = l4n81ll[_n-1]
by svalue: gen l6n81ll = l5n81ll[_n-1]
by svalue: gen l7n81ll = l6n81ll[_n-1]

by svalue: gen ln81cc = n81cc[_n-1]
by svalue: gen l2n81cc = ln81cc[_n-1]
by svalue: gen l3n81cc = l2n81cc[_n-1]
by svalue: gen l4n81cc = l3n81cc[_n-1]
by svalue: gen l5n81cc = l4n81cc[_n-1]
by svalue: gen l6n81cc = l5n81cc[_n-1]
by svalue: gen l7n81cc = l6n81cc[_n-1]

by svalue: gen ln81cl = n81cl[_n-1]
by svalue: gen l2n81cl = ln81cl[_n-1]
by svalue: gen l3n81cl = l2n81cl[_n-1]
by svalue: gen l4n81cl = l3n81cl[_n-1]
by svalue: gen l5n81cl = l4n81cl[_n-1]
by svalue: gen l6n81cl = l5n81cl[_n-1]
by svalue: gen l7n81cl = l6n81cl[_n-1]









by svalue: gen ln72 = n72[_n-1]
by svalue: gen l2n72 = ln72[_n-1]
by svalue: gen l3n72 = l2n72[_n-1]
by svalue: gen l4n72 = l3n72[_n-1]
by svalue: gen l5n72 = l4n72[_n-1]
by svalue: gen l6n72 = l5n72[_n-1]
by svalue: gen l7n72 = l6n72[_n-1]

by svalue: gen ln72c = n72c[_n-1]
by svalue: gen l2n72c = ln72c[_n-1]
by svalue: gen l3n72c = l2n72c[_n-1]
by svalue: gen l4n72c = l3n72c[_n-1]
by svalue: gen l5n72c = l4n72c[_n-1]
by svalue: gen l6n72c = l5n72c[_n-1]
by svalue: gen l7n72c = l6n72c[_n-1]

by svalue: gen ln72l = n72l[_n-1]
by svalue: gen l2n72l = ln72l[_n-1]
by svalue: gen l3n72l = l2n72l[_n-1]
by svalue: gen l4n72l = l3n72l[_n-1]
by svalue: gen l5n72l = l4n72l[_n-1]
by svalue: gen l6n72l = l5n72l[_n-1]
by svalue: gen l7n72l = l6n72l[_n-1]

by svalue: gen ln72ll = n72ll[_n-1]
by svalue: gen l2n72ll = ln72ll[_n-1]
by svalue: gen l3n72ll = l2n72ll[_n-1]
by svalue: gen l4n72ll = l3n72ll[_n-1]
by svalue: gen l5n72ll = l4n72ll[_n-1]
by svalue: gen l6n72ll = l5n72ll[_n-1]
by svalue: gen l7n72ll = l6n72ll[_n-1]

by svalue: gen ln72cc = n72cc[_n-1]
by svalue: gen l2n72cc = ln72cc[_n-1]
by svalue: gen l3n72cc = l2n72cc[_n-1]
by svalue: gen l4n72cc = l3n72cc[_n-1]
by svalue: gen l5n72cc = l4n72cc[_n-1]
by svalue: gen l6n72cc = l5n72cc[_n-1]
by svalue: gen l7n72cc = l6n72cc[_n-1]

by svalue: gen ln72cl = n72cl[_n-1]
by svalue: gen l2n72cl = ln72cl[_n-1]
by svalue: gen l3n72cl = l2n72cl[_n-1]
by svalue: gen l4n72cl = l3n72cl[_n-1]
by svalue: gen l5n72cl = l4n72cl[_n-1]
by svalue: gen l6n72cl = l5n72cl[_n-1]
by svalue: gen l7n72cl = l6n72cl[_n-1]










by svalue: gen lunam = unam[_n-1]
by svalue: gen l2unam = lunam[_n-1]
by svalue: gen l3unam = l2unam[_n-1]
by svalue: gen l4unam = l3unam[_n-1]
by svalue: gen l5unam = l4unam[_n-1]
by svalue: gen l6unam = l5unam[_n-1]
by svalue: gen l7unam = l6unam[_n-1]

by svalue: gen lunamc = unamc[_n-1]
by svalue: gen l2unamc = lunamc[_n-1]
by svalue: gen l3unamc = l2unamc[_n-1]
by svalue: gen l4unamc = l3unamc[_n-1]
by svalue: gen l5unamc = l4unamc[_n-1]
by svalue: gen l6unamc = l5unamc[_n-1]
by svalue: gen l7unamc = l6unamc[_n-1]

by svalue: gen lunaml = unaml[_n-1]
by svalue: gen l2unaml = lunaml[_n-1]
by svalue: gen l3unaml = l2unaml[_n-1]
by svalue: gen l4unaml = l3unaml[_n-1]
by svalue: gen l5unaml = l4unaml[_n-1]
by svalue: gen l6unaml = l5unaml[_n-1]
by svalue: gen l7unaml = l6unaml[_n-1]

by svalue: gen lunamll = unamll[_n-1]
by svalue: gen l2unamll = lunamll[_n-1]
by svalue: gen l3unamll = l2unamll[_n-1]
by svalue: gen l4unamll = l3unamll[_n-1]
by svalue: gen l5unamll = l4unamll[_n-1]
by svalue: gen l6unamll = l5unamll[_n-1]
by svalue: gen l7unamll = l6unamll[_n-1]

by svalue: gen lunamcc = unamcc[_n-1]
by svalue: gen l2unamcc = lunamcc[_n-1]
by svalue: gen l3unamcc = l2unamcc[_n-1]
by svalue: gen l4unamcc = l3unamcc[_n-1]
by svalue: gen l5unamcc = l4unamcc[_n-1]
by svalue: gen l6unamcc = l5unamcc[_n-1]
by svalue: gen l7unamcc = l6unamcc[_n-1]

by svalue: gen lunamcl = unamcl[_n-1]
by svalue: gen l2unamcl = lunamcl[_n-1]
by svalue: gen l3unamcl = l2unamcl[_n-1]
by svalue: gen l4unamcl = l3unamcl[_n-1]
by svalue: gen l5unamcl = l4unamcl[_n-1]
by svalue: gen l6unamcl = l5unamcl[_n-1]
by svalue: gen l7unamcl = l6unamcl[_n-1]










by svalue: gen lus_party = us_party[_n-1]
by svalue: gen l2us_party = lus_party[_n-1]
by svalue: gen l3us_party = l2us_party[_n-1]
by svalue: gen l4us_party = l3us_party[_n-1]
by svalue: gen l5us_party = l4us_party[_n-1]
by svalue: gen l6us_party = l5us_party[_n-1]
by svalue: gen l7us_party = l6us_party[_n-1]



by svalue: gen lstate_party = state_party[_n-1]
by svalue: gen l2state_party = lstate_party[_n-1]
by svalue: gen l3state_party = l2state_party[_n-1]
by svalue: gen l4state_party = l3state_party[_n-1]
by svalue: gen l5state_party = l4state_party[_n-1]
by svalue: gen l6state_party = l5state_party[_n-1]
by svalue: gen l7state_party = l6state_party[_n-1]

by svalue: gen llocal_party = local_party[_n-1]
by svalue: gen l2local_party = llocal_party[_n-1]
by svalue: gen l3local_party = l2local_party[_n-1]
by svalue: gen l4local_party = l3local_party[_n-1]
by svalue: gen l5local_party = l4local_party[_n-1]
by svalue: gen l6local_party = l5local_party[_n-1]
by svalue: gen l7local_party = l6local_party[_n-1]

by svalue: gen ljud_party = jud_party[_n-1]
by svalue: gen l2jud_party = ljud_party[_n-1]
by svalue: gen l3jud_party = l2jud_party[_n-1]
by svalue: gen l4jud_party = l3jud_party[_n-1]
by svalue: gen l5jud_party = l4jud_party[_n-1]
by svalue: gen l6jud_party = l5jud_party[_n-1]
by svalue: gen l7jud_party = l6jud_party[_n-1]

by svalue: gen lbus_party = bus_party[_n-1]
by svalue: gen l2bus_party = lbus_party[_n-1]
by svalue: gen l3bus_party = l2bus_party[_n-1]
by svalue: gen l4bus_party = l3bus_party[_n-1]
by svalue: gen l5bus_party = l4bus_party[_n-1]
by svalue: gen l6bus_party = l5bus_party[_n-1]
by svalue: gen l7bus_party = l6bus_party[_n-1]

by svalue: gen lperson_party = person_party[_n-1]
by svalue: gen l2person_party = lperson_party[_n-1]
by svalue: gen l3person_party = l2person_party[_n-1]
by svalue: gen l4person_party = l3person_party[_n-1]
by svalue: gen l5person_party = l4person_party[_n-1]
by svalue: gen l6person_party = l5person_party[_n-1]
by svalue: gen l7person_party = l6person_party[_n-1]

by svalue: gen lnonprof_party = nonprof_party[_n-1]
by svalue: gen l2nonprof_party = lnonprof_party[_n-1]
by svalue: gen l3nonprof_party = l2nonprof_party[_n-1]
by svalue: gen l4nonprof_party = l3nonprof_party[_n-1]
by svalue: gen l5nonprof_party = l4nonprof_party[_n-1]
by svalue: gen l6nonprof_party = l5nonprof_party[_n-1]
by svalue: gen l7nonprof_party = l6nonprof_party[_n-1]






by svalue: gen lforeign_party = foreign_party[_n-1]
by svalue: gen l2foreign_party = lforeign_party[_n-1]
by svalue: gen l3foreign_party = l2foreign_party[_n-1]
by svalue: gen l4foreign_party = l3foreign_party[_n-1]
by svalue: gen l5foreign_party = l4foreign_party[_n-1]
by svalue: gen l6foreign_party = l5foreign_party[_n-1]
by svalue: gen l7foreign_party = l6foreign_party[_n-1]



by svalue: gen lpersbus_party = persbus_party[_n-1]
by svalue: gen l2persbus_party = lpersbus_party[_n-1]
by svalue: gen l3persbus_party = l2persbus_party[_n-1]
by svalue: gen l4persbus_party = l3persbus_party[_n-1]
by svalue: gen l5persbus_party = l4persbus_party[_n-1]
by svalue: gen l6persbus_party = l5persbus_party[_n-1]
by svalue: gen l7persbus_party = l6persbus_party[_n-1]



by svalue: gen lus_win = us_win[_n-1]
by svalue: gen l2us_win = lus_win[_n-1]
by svalue: gen l3us_win = l2us_win[_n-1]
by svalue: gen l4us_win = l3us_win[_n-1]
by svalue: gen l5us_win = l4us_win[_n-1]
by svalue: gen l6us_win = l5us_win[_n-1]
by svalue: gen l7us_win = l6us_win[_n-1]



by svalue: gen lperson_win = person_win[_n-1]
by svalue: gen l2person_win = lperson_win[_n-1]
by svalue: gen l3person_win = l2person_win[_n-1]
by svalue: gen l4person_win = l3person_win[_n-1]
by svalue: gen l5person_win = l4person_win[_n-1]
by svalue: gen l6person_win = l5person_win[_n-1]
by svalue: gen l7person_win = l6person_win[_n-1]



by svalue: gen lnonprof_win = nonprof_win[_n-1]
by svalue: gen l2nonprof_win = lnonprof_win[_n-1]
by svalue: gen l3nonprof_win = l2nonprof_win[_n-1]
by svalue: gen l4nonprof_win = l3nonprof_win[_n-1]
by svalue: gen l5nonprof_win = l4nonprof_win[_n-1]
by svalue: gen l6nonprof_win = l5nonprof_win[_n-1]
by svalue: gen l7nonprof_win = l6nonprof_win[_n-1]



by svalue: gen lforeign_win = foreign_win[_n-1]
by svalue: gen l2foreign_win = lforeign_win[_n-1]
by svalue: gen l3foreign_win = l2foreign_win[_n-1]
by svalue: gen l4foreign_win = l3foreign_win[_n-1]
by svalue: gen l5foreign_win = l4foreign_win[_n-1]
by svalue: gen l6foreign_win = l5foreign_win[_n-1]
by svalue: gen l7foreign_win = l6foreign_win[_n-1]



by svalue: gen lpersbus_win = persbus_win[_n-1]
by svalue: gen l2persbus_win = lpersbus_win[_n-1]
by svalue: gen l3persbus_win = l2persbus_win[_n-1]
by svalue: gen l4persbus_win = l3persbus_win[_n-1]
by svalue: gen l5persbus_win = l4persbus_win[_n-1]
by svalue: gen l6persbus_win = l5persbus_win[_n-1]
by svalue: gen l7persbus_win = l6persbus_win[_n-1]



by svalue: gen lbuswin_low = buswin_low[_n-1]
by svalue: gen l2buswin_low = lbuswin_low[_n-1]
by svalue: gen l3buswin_low = l2buswin_low[_n-1]
by svalue: gen l4buswin_low = l3buswin_low[_n-1]
by svalue: gen l5buswin_low = l4buswin_low[_n-1]
by svalue: gen l6buswin_low = l5buswin_low[_n-1]
by svalue: gen l7buswin_low = l6buswin_low[_n-1]



by svalue: gen lbuswin_gov = buswin_gov[_n-1]
by svalue: gen l2buswin_gov = lbuswin_gov[_n-1]
by svalue: gen l3buswin_gov = l2buswin_gov[_n-1]
by svalue: gen l4buswin_gov = l3buswin_gov[_n-1]
by svalue: gen l5buswin_gov = l4buswin_gov[_n-1]
by svalue: gen l6buswin_gov = l5buswin_gov[_n-1]
by svalue: gen l7buswin_gov = l6buswin_gov[_n-1]






by svalue: gen lbuswin_govl = buswin_govl[_n-1]
by svalue: gen l2buswin_govl = lbuswin_govl[_n-1]
by svalue: gen l3buswin_govl = l2buswin_govl[_n-1]
by svalue: gen l4buswin_govl = l3buswin_govl[_n-1]
by svalue: gen l5buswin_govl = l4buswin_govl[_n-1]
by svalue: gen l6buswin_govl = l5buswin_govl[_n-1]
by svalue: gen l7buswin_govl = l6buswin_govl[_n-1]



by svalue: gen lbuswin_govc = buswin_govc[_n-1]
by svalue: gen l2buswin_govc = lbuswin_govc[_n-1]
by svalue: gen l3buswin_govc = l2buswin_govc[_n-1]
by svalue: gen l4buswin_govc = l3buswin_govc[_n-1]
by svalue: gen l5buswin_govc = l4buswin_govc[_n-1]
by svalue: gen l6buswin_govc = l5buswin_govc[_n-1]
by svalue: gen l7buswin_govc = l6buswin_govc[_n-1]




 
by svalue: gen lbuswin_lowc = buswin_lowc[_n-1]
by svalue: gen l2buswin_lowc = lbuswin_lowc[_n-1]
by svalue: gen l3buswin_lowc = l2buswin_lowc[_n-1]
by svalue: gen l4buswin_lowc = l3buswin_lowc[_n-1]
by svalue: gen l5buswin_lowc = l4buswin_lowc[_n-1]
by svalue: gen l6buswin_lowc = l5buswin_lowc[_n-1]
by svalue: gen l7buswin_lowc = l6buswin_lowc[_n-1]



by svalue: gen lbuswin_lowl = buswin_lowl[_n-1]
by svalue: gen l2buswin_lowl = lbuswin_lowl[_n-1]
by svalue: gen l3buswin_lowl = l2buswin_lowl[_n-1]
by svalue: gen l4buswin_lowl = l3buswin_lowl[_n-1]
by svalue: gen l5buswin_lowl = l4buswin_lowl[_n-1]
by svalue: gen l6buswin_lowl = l5buswin_lowl[_n-1]
by svalue: gen l7buswin_lowl = l6buswin_lowl[_n-1]




by svalue: gen lmuni = muni[_n-1]
by svalue: gen l2muni = lmuni[_n-1]
by svalue: gen l3muni = l2muni[_n-1]
by svalue: gen l4muni = l3muni[_n-1]
by svalue: gen l5muni = l4muni[_n-1]
by svalue: gen l6muni = l5muni[_n-1]
by svalue: gen l7muni = l6muni[_n-1]



by svalue: gen lmunic = munic[_n-1]
by svalue: gen l2munic = lmunic[_n-1]
by svalue: gen l3munic = l2munic[_n-1]
by svalue: gen l4munic = l3munic[_n-1]
by svalue: gen l5munic = l4munic[_n-1]
by svalue: gen l6munic = l5munic[_n-1]
by svalue: gen l7munic = l6munic[_n-1]



by svalue: gen lmunil = munil[_n-1]
by svalue: gen l2munil = lmunil[_n-1]
by svalue: gen l3munil = l2munil[_n-1]
by svalue: gen l4munil = l3munil[_n-1]
by svalue: gen l5munil = l4munil[_n-1]
by svalue: gen l6munil = l5munil[_n-1]
by svalue: gen l7munil = l6munil[_n-1]



by svalue: gen lstate = state[_n-1]
by svalue: gen l2state = lstate[_n-1]
by svalue: gen l3state = l2state[_n-1]
by svalue: gen l4state = l3state[_n-1]
by svalue: gen l5state = l4state[_n-1]
by svalue: gen l6state = l5state[_n-1]
by svalue: gen l7state = l6state[_n-1]



by svalue: gen lstatel = statel[_n-1]
by svalue: gen l2statel = lstatel[_n-1]
by svalue: gen l3statel = l2statel[_n-1]
by svalue: gen l4statel = l3statel[_n-1]
by svalue: gen l5statel = l4statel[_n-1]
by svalue: gen l6statel = l5statel[_n-1]
by svalue: gen l7statel = l6statel[_n-1]



by svalue: gen lstatec = statec[_n-1]
by svalue: gen l2statec = lstatec[_n-1]
by svalue: gen l3statec = l2statec[_n-1]
by svalue: gen l4statec = l3statec[_n-1]
by svalue: gen l5statec = l4statec[_n-1]
by svalue: gen l6statec = l5statec[_n-1]
by svalue: gen l7statec = l6statec[_n-1]



by svalue: gen lfed = fed[_n-1]
by svalue: gen l2fed = lfed[_n-1]
by svalue: gen l3fed = l2fed[_n-1]
by svalue: gen l4fed = l3fed[_n-1]
by svalue: gen l5fed = l4fed[_n-1]
by svalue: gen l6fed = l5fed[_n-1]
by svalue: gen l7fed = l6fed[_n-1]



by svalue: gen lfedl = fedl[_n-1]
by svalue: gen l2fedl = lfedl[_n-1]
by svalue: gen l3fedl = l2fedl[_n-1]
by svalue: gen l4fedl = l3fedl[_n-1]
by svalue: gen l5fedl = l4fedl[_n-1]
by svalue: gen l6fedl = l5fedl[_n-1]
by svalue: gen l7fedl = l6fedl[_n-1]



by svalue: gen lfedc = fedc[_n-1]
by svalue: gen l2fedc = lfedc[_n-1]
by svalue: gen l3fedc = l2fedc[_n-1]
by svalue: gen l4fedc = l3fedc[_n-1]
by svalue: gen l5fedc = l4fedc[_n-1]
by svalue: gen l6fedc = l5fedc[_n-1]
by svalue: gen l7fedc = l6fedc[_n-1]


by svalue: gen lprec = prec[_n-1]
by svalue: gen l2prec = lprec[_n-1]
by svalue: gen l3prec = l2prec[_n-1]
by svalue: gen l4prec = l3prec[_n-1]
by svalue: gen l5prec = l4prec[_n-1]
by svalue: gen l6prec = l5prec[_n-1]
by svalue: gen l7prec = l6prec[_n-1]



by svalue: gen lprecc = precc[_n-1]
by svalue: gen l2precc = lprecc[_n-1]
by svalue: gen l3precc = l2precc[_n-1]
by svalue: gen l4precc = l3precc[_n-1]
by svalue: gen l5precc = l4precc[_n-1]
by svalue: gen l6precc = l5precc[_n-1]
by svalue: gen l7precc = l6precc[_n-1]



by svalue: gen lprecl = precl[_n-1]
by svalue: gen l2precl = lprecl[_n-1]
by svalue: gen l3precl = l2precl[_n-1]
by svalue: gen l4precl = l3precl[_n-1]
by svalue: gen l5precl = l4precl[_n-1]
by svalue: gen l6precl = l5precl[_n-1]
by svalue: gen l7precl = l6precl[_n-1]



by svalue: gen luncon = uncon[_n-1]
by svalue: gen l2uncon = luncon[_n-1]
by svalue: gen l3uncon = l2uncon[_n-1]
by svalue: gen l4uncon = l3uncon[_n-1]
by svalue: gen l5uncon = l4uncon[_n-1]
by svalue: gen l6uncon = l5uncon[_n-1]
by svalue: gen l7uncon = l6uncon[_n-1]



by svalue: gen lunconl = unconl[_n-1]
by svalue: gen l2unconl = lunconl[_n-1]
by svalue: gen l3unconl = l2unconl[_n-1]
by svalue: gen l4unconl = l3unconl[_n-1]
by svalue: gen l5unconl = l4unconl[_n-1]
by svalue: gen l6unconl = l5unconl[_n-1]
by svalue: gen l7unconl = l6unconl[_n-1]



by svalue: gen lunconc = unconc[_n-1]
by svalue: gen l2unconc = lunconc[_n-1]
by svalue: gen l3unconc = l2unconc[_n-1]
by svalue: gen l4unconc = l3unconc[_n-1]
by svalue: gen l5unconc = l4unconc[_n-1]
by svalue: gen l6unconc = l5unconc[_n-1]
by svalue: gen l7unconc = l6unconc[_n-1]



by svalue: gen lrev = rev[_n-1]
by svalue: gen l2rev = lrev[_n-1]
by svalue: gen l3rev = l2rev[_n-1]
by svalue: gen l4rev = l3rev[_n-1]
by svalue: gen l5rev = l4rev[_n-1]
by svalue: gen l6rev = l5rev[_n-1]
by svalue: gen l7rev = l6rev[_n-1]



by svalue: gen lrevl = revl[_n-1]
by svalue: gen l2revl = lrevl[_n-1]
by svalue: gen l3revl = l2revl[_n-1]
by svalue: gen l4revl = l3revl[_n-1]
by svalue: gen l5revl = l4revl[_n-1]
by svalue: gen l6revl = l5revl[_n-1]
by svalue: gen l7revl = l6revl[_n-1]



by svalue: gen lrevc = revc[_n-1]
by svalue: gen l2revc = lrevc[_n-1]
by svalue: gen l3revc = l2revc[_n-1]
by svalue: gen l4revc = l3revc[_n-1]
by svalue: gen l5revc = l4revc[_n-1]
by svalue: gen l6revc = l5revc[_n-1]
by svalue: gen l7revc = l6revc[_n-1]



by svalue: gen lcq = cq[_n-1]
by svalue: gen l2cq = lcq[_n-1]
by svalue: gen l3cq = l2cq[_n-1]
by svalue: gen l4cq = l3cq[_n-1]
by svalue: gen l5cq = l4cq[_n-1]
by svalue: gen l6cq = l5cq[_n-1]
by svalue: gen l7cq = l6cq[_n-1]



by svalue: gen lcql = cql[_n-1]
by svalue: gen l2cql = lcql[_n-1]
by svalue: gen l3cql = l2cql[_n-1]
by svalue: gen l4cql = l3cql[_n-1]
by svalue: gen l5cql = l4cql[_n-1]
by svalue: gen l6cql = l5cql[_n-1]
by svalue: gen l7cql = l6cql[_n-1]



by svalue: gen lcqc = cqc[_n-1]
by svalue: gen l2cqc = lcqc[_n-1]
by svalue: gen l3cqc = l2cqc[_n-1]
by svalue: gen l4cqc = l3cqc[_n-1]
by svalue: gen l5cqc = l4cqc[_n-1]
by svalue: gen l6cqc = l5cqc[_n-1]
by svalue: gen l7cqc = l6cqc[_n-1]



by svalue: gen lnyt = nyt[_n-1]
by svalue: gen l2nyt = lnyt[_n-1]
by svalue: gen l3nyt = l2nyt[_n-1]
by svalue: gen l4nyt = l3nyt[_n-1]
by svalue: gen l5nyt = l4nyt[_n-1]
by svalue: gen l6nyt = l5nyt[_n-1]
by svalue: gen l7nyt = l6nyt[_n-1]



by svalue: gen lnytl = nytl[_n-1]
by svalue: gen l2nytl = lnytl[_n-1]
by svalue: gen l3nytl = l2nytl[_n-1]
by svalue: gen l4nytl = l3nytl[_n-1]
by svalue: gen l5nytl = l4nytl[_n-1]
by svalue: gen l6nytl = l5nytl[_n-1]
by svalue: gen l7nytl = l6nytl[_n-1]



by svalue: gen lnytc = nytc[_n-1]
by svalue: gen l2nytc = lnytc[_n-1]
by svalue: gen l3nytc = l2nytc[_n-1]
by svalue: gen l4nytc = l3nytc[_n-1]
by svalue: gen l5nytc = l4nytc[_n-1]
by svalue: gen l6nytc = l5nytc[_n-1]
by svalue: gen l7nytc = l6nytc[_n-1]





by svalue: gen ldissent_opin = dissent_opin[_n-1]
by svalue: gen l2dissent_opin = ldissent_opin[_n-1]
by svalue: gen l3dissent_opin = l2dissent_opin[_n-1]
by svalue: gen l4dissent_opin = l3dissent_opin[_n-1]
by svalue: gen l5dissent_opin = l4dissent_opin[_n-1]
by svalue: gen l6dissent_opin = l5dissent_opin[_n-1]
by svalue: gen l7dissent_opin = l6dissent_opin[_n-1]

by svalue: gen lconcur_opin = concur_opin[_n-1]
by svalue: gen l2concur_opin = lconcur_opin[_n-1]
by svalue: gen l3concur_opin = l2concur_opin[_n-1]
by svalue: gen l4concur_opin = l3concur_opin[_n-1]
by svalue: gen l5concur_opin = l4concur_opin[_n-1]
by svalue: gen l6concur_opin = l5concur_opin[_n-1]
by svalue: gen l7concur_opin = l6concur_opin[_n-1]

by svalue: gen llibdissent_opin = libdissent_opin[_n-1]
by svalue: gen l2libdissent_opin = llibdissent_opin[_n-1]
by svalue: gen l3libdissent_opin = l2libdissent_opin[_n-1]
by svalue: gen l4libdissent_opin = l3libdissent_opin[_n-1]
by svalue: gen l5libdissent_opin = l4libdissent_opin[_n-1]
by svalue: gen l6libdissent_opin = l5libdissent_opin[_n-1]
by svalue: gen l7libdissent_opin = l6libdissent_opin[_n-1]

by svalue: gen lcondissent_opin = condissent_opin[_n-1]
by svalue: gen l2condissent_opin = lcondissent_opin[_n-1]
by svalue: gen l3condissent_opin = l2condissent_opin[_n-1]
by svalue: gen l4condissent_opin = l3condissent_opin[_n-1]
by svalue: gen l5condissent_opin = l4condissent_opin[_n-1]
by svalue: gen l6condissent_opin = l5condissent_opin[_n-1]
by svalue: gen l7condissent_opin = l6condissent_opin[_n-1]

by svalue: gen ldissent_opin01 = dissent_opin01[_n-1]
by svalue: gen l2dissent_opin01 = ldissent_opin01[_n-1]
by svalue: gen l3dissent_opin01 = l2dissent_opin01[_n-1]
by svalue: gen l4dissent_opin01 = l3dissent_opin01[_n-1]
by svalue: gen l5dissent_opin01 = l4dissent_opin01[_n-1]
by svalue: gen l6dissent_opin01 = l5dissent_opin01[_n-1]
by svalue: gen l7dissent_opin01 = l6dissent_opin01[_n-1]

        



by svalue: gen lconcur_opin01 = concur_opin01[_n-1]
by svalue: gen l2concur_opin01 = lconcur_opin01[_n-1]
by svalue: gen l3concur_opin01 = l2concur_opin01[_n-1]
by svalue: gen l4concur_opin01 = l3concur_opin01[_n-1]
by svalue: gen l5concur_opin01 = l4concur_opin01[_n-1]
by svalue: gen l6concur_opin01 = l5concur_opin01[_n-1]
by svalue: gen l7concur_opin01 = l6concur_opin01[_n-1]

by svalue: gen llibdissent_opin01 = libdissent_opin01[_n-1]
by svalue: gen l2libdissent_opin01 = llibdissent_opin01[_n-1]
by svalue: gen l3libdissent_opin01 = l2libdissent_opin01[_n-1]
by svalue: gen l4libdissent_opin01 = l3libdissent_opin01[_n-1]
by svalue: gen l5libdissent_opin01 = l4libdissent_opin01[_n-1]
by svalue: gen l6libdissent_opin01 = l5libdissent_opin01[_n-1]
by svalue: gen l7libdissent_opin01 = l6libdissent_opin01[_n-1]

by svalue: gen lcondissent_opin01 = condissent_opin01[_n-1]
by svalue: gen l2condissent_opin01 = lcondissent_opin01[_n-1]
by svalue: gen l3condissent_opin01 = l2condissent_opin01[_n-1]
by svalue: gen l4condissent_opin01 = l3condissent_opin01[_n-1]
by svalue: gen l5condissent_opin01 = l4condissent_opin01[_n-1]
by svalue: gen l6condissent_opin01 = l5condissent_opin01[_n-1]
by svalue: gen l7condissent_opin01 = l6condissent_opin01[_n-1]


egen congress_cs = rowmean (house senate) 
by svalue: gen cong_scmed_dist = congress_cs - JCS_SCmedian
by svalue: gen cong_doctrat_dist = congress_cs - medmaj_rat_nospec_jcs
by svalue: gen cong_doctnc_dist = congress_cs - medmaj_rat_noconcur_jcs
by svalue: gen cong_doctnd_dist = congress_cs - medmaj_vote_nodis_jcs


by svalue: gen lcong_scmed_dist = cong_scmed_dist[_n-1]
by svalue: gen l2cong_scmed_dist = lcong_scmed_dist[_n-1]
by svalue: gen l3cong_scmed_dist = l2cong_scmed_dist[_n-1]
by svalue: gen l4cong_scmed_dist = l3cong_scmed_dist[_n-1]
by svalue: gen l5cong_scmed_dist = l4cong_scmed_dist[_n-1]
by svalue: gen l6cong_scmed_dist = l5cong_scmed_dist[_n-1]
by svalue: gen l7cong_scmed_dist = l6cong_scmed_dist[_n-1]


by svalue: gen lcong_doctrat_dist = cong_doctrat_dist[_n-1]
by svalue: gen l2cong_doctrat_dist = lcong_doctrat_dist[_n-1]
by svalue: gen l3cong_doctrat_dist = l2cong_doctrat_dist[_n-1]
by svalue: gen l4cong_doctrat_dist = l3cong_doctrat_dist[_n-1]
by svalue: gen l5cong_doctrat_dist = l4cong_doctrat_dist[_n-1]
by svalue: gen l6cong_doctrat_dist = l5cong_doctrat_dist[_n-1]
by svalue: gen l7cong_doctrat_dist = l6cong_doctrat_dist[_n-1]


by svalue: gen lcong_doctnc_dist = cong_doctnc_dist[_n-1]
by svalue: gen l2cong_doctnc_dist = lcong_doctnc_dist[_n-1]
by svalue: gen l3cong_doctnc_dist = l2cong_doctnc_dist[_n-1]
by svalue: gen l4cong_doctnc_dist = l3cong_doctnc_dist[_n-1]
by svalue: gen l5cong_doctnc_dist = l4cong_doctnc_dist[_n-1]
by svalue: gen l6cong_doctnc_dist = l5cong_doctnc_dist[_n-1]
by svalue: gen l7cong_doctnc_dist = l6cong_doctnc_dist[_n-1]


by svalue: gen lcong_doctnd_dist = cong_doctnd_dist[_n-1]
by svalue: gen l2cong_doctnd_dist = lcong_doctnd_dist[_n-1]
by svalue: gen l3cong_doctnd_dist = l2cong_doctnd_dist[_n-1]
by svalue: gen l4cong_doctnd_dist = l3cong_doctnd_dist[_n-1]
by svalue: gen l5cong_doctnd_dist = l4cong_doctnd_dist[_n-1]
by svalue: gen l6cong_doctnd_dist = l5cong_doctnd_dist[_n-1]
by svalue: gen l7cong_doctnd_dist = l6cong_doctnd_dist[_n-1]
 
by svalue: gen lJCS_SCmedian = JCS_SCmedian[_n-1]
by svalue: gen l2JCS_SCmedian = lJCS_SCmedian[_n-1]
by svalue: gen l3JCS_SCmedian= l2JCS_SCmedian[_n-1]
by svalue: gen l4JCS_SCmedian = l3JCS_SCmedian[_n-1]
by svalue: gen l5JCS_SCmedian = l4JCS_SCmedian[_n-1]
by svalue: gen l6JCS_SCmedian = l5JCS_SCmedian[_n-1]
by svalue: gen l7JCS_SCmedian = l6JCS_SCmedian[_n-1]



gen mch =  (JCS_SCmedian - lJCS_SCmedian)
gen abmch = abs(mch)

by svalue: gen labmch = abmch[_n-1]
by svalue: gen l2abmch = labmch[_n-1]
by svalue: gen l3abmch= l2abmch[_n-1]
by svalue: gen l4abmch = l3abmch[_n-1]
by svalue: gen l5abmch = l4abmch[_n-1]
by svalue: gen l6abmch = l5abmch[_n-1]
by svalue: gen l7abmch = l6abmch[_n-1]


by svalue: gen lideo_doct = ideo_doct[_n-1]
by svalue: gen l2ideo_doct = lideo_doct[_n-1]
by svalue: gen l3ideo_doct= l2ideo_doct[_n-1]
by svalue: gen l4ideo_doct = l3ideo_doct[_n-1]
by svalue: gen l5ideo_doct = l4ideo_doct[_n-1]
by svalue: gen l6ideo_doct = l5ideo_doct[_n-1]
by svalue: gen l7ideo_doct = l6ideo_doct[_n-1]

gen ideo_ch = ideo_doct - lideo_doct
gen abs_ideo_ch = abs(ideo_doct - lideo_doct)

by svalue: gen lideo_ch = ideo_ch[_n-1]
by svalue: gen l2ideo_ch = lideo_ch[_n-1]
by svalue: gen l3ideo_ch= l2ideo_ch[_n-1]
by svalue: gen l4ideo_ch = l3ideo_ch[_n-1]
by svalue: gen l5ideo_ch = l4ideo_ch[_n-1]
by svalue: gen l6ideo_ch = l5ideo_ch[_n-1]
by svalue: gen l7ideo_ch = l6ideo_ch[_n-1]

by svalue: gen labs_ideo_ch = abs_ideo_ch[_n-1]
by svalue: gen l2abs_ideo_ch = labs_ideo_ch[_n-1]
by svalue: gen l3abs_ideo_ch= l2abs_ideo_ch[_n-1]
by svalue: gen l4abs_ideo_ch = l3abs_ideo_ch[_n-1]
by svalue: gen l5abs_ideo_ch = l4abs_ideo_ch[_n-1]
by svalue: gen l6abs_ideo_ch = l5abs_ideo_ch[_n-1]
by svalue: gen l7abs_ideo_ch = l6abs_ideo_ch[_n-1]


gen l1l2_ideo_ch = lideo_ch-l2ideo_ch
gen l1l3_ideo_ch = lideo_ch-l3ideo_ch
gen l1l4_ideo_ch = lideo_ch-l4ideo_ch
gen l1l5_ideo_ch = lideo_ch-l5ideo_ch
gen l1l6_ideo_ch = lideo_ch-l6ideo_ch

gen ideo_med_dist = ideo_doct - JCS_SCmedian
by svalue: gen lideo_med_dist = ideo_med_dist[_n-1]
by svalue: gen l2ideo_med_dist = lideo_med_dist[_n-1]
by svalue: gen l3ideo_med_dist= l2ideo_med_dist[_n-1]
by svalue: gen l4ideo_med_dist = l3ideo_med_dist[_n-1]
by svalue: gen l5ideo_med_dist = l4ideo_med_dist[_n-1]
by svalue: gen l6ideo_med_dist = l5ideo_med_dist[_n-1]
by svalue: gen l7ideo_med_dist = l6ideo_med_dist[_n-1]

by svalue: gen lmch = mch[_n-1]
by svalue: gen l2mch = lmch[_n-1]
by svalue: gen l3mch= l2mch[_n-1]
by svalue: gen l4mch = l3mch[_n-1]
by svalue: gen l5mch = l4mch[_n-1]
by svalue: gen l6mch = l5mch[_n-1]
by svalue: gen l7mch = l6mch[_n-1]

gen abs_ideo_med_dist = abs(ideo_doct - JCS_SCmedian)
by svalue: gen labs_ideo_med_dist = abs_ideo_med_dist[_n-1]
by svalue: gen l2abs_ideo_med_dist = labs_ideo_med_dist[_n-1]
by svalue: gen l3abs_ideo_med_dist= l2abs_ideo_med_dist[_n-1]
by svalue: gen l4abs_ideo_med_dist = l3abs_ideo_med_dist[_n-1]
by svalue: gen l5abs_ideo_med_dist = l4abs_ideo_med_dist[_n-1]
by svalue: gen l6abs_ideo_med_dist = l5abs_ideo_med_dist[_n-1]
by svalue: gen l7abs_ideo_med_dist = l6abs_ideo_med_dist[_n-1]

label var ideo_med_dist "Doctrine is to the right of the median"
tabulate svalue, generate(svalue)

* Replicate Figure 4.2 The Effect of Index of Signals on the Number of Cases on the U.S. Supreme Court Agenda, 1953-1995
xtpcse ideo_med_dist lideo_med_dist lippl l2ippl l3ippl l4ippl l5ippl l6ippl l7ippl ///
			 lippc l2ippc l3ippc l4ippc l5ippc l6ippc l7ippc burger  rehn  /// 
			svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail


xtpcse ideo_med_dist lideo_med_dist  ///
			 lippc l2ippc l3ippc l4ippc l5ippc l6ippc l7ippc burger  rehn  /// 
			svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail


xtpcse ideo_med_dist lideo_med_dist lippl l2ippl l3ippl l4ippl l5ippl l6ippl l7ippl ///
			  l7ippc burger  rehn  /// 
			svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail

abs_ideo_ch

xtline ideo_doct if unam ~=0, overlay

xtpcse cases lcases  labmch l2abmch l3abmch l4abmch l5abmch l6abmch l7abmch  ///
			  lipp l2ipp l3ipp l4ipp l5ipp l6ipp l7ipp burger  rehn  /// 
			svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail

xtpcse rev lrev  labmch l2abmch l3abmch l4abmch l5abmch l6abmch l7abmch  ///
			  lipp l2ipp l3ipp l4ipp l5ipp l6ipp l7ipp burger  rehn  /// 
			svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail



xtpcse revc lrevc  labmch l2abmch l3abmch l4abmch l5abmch l6abmch l7abmch  ///
			  lipp l2ipp l3ipp l4ipp l5ipp l6ipp l7ipp burger  rehn  /// 
			svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail


xtpcse ideo_doct JCS_SCmedian  lideo_doct l2ideo_doct l3ideo_doct l4ideo_doct l5ideo_doct l6ideo_doct l7ideo_doct burger  rehn  /// 
		labmch l2abmch l3abmch l4abmch l5abmch l6abmch l7abmch /// 
		lJCS_SCmedian l2JCS_SCmedian l3JCS_SCmedian l4JCS_SCmedian l5JCS_SCmedian l6JCS_SCmedian l7JCS_SCmedian ///
		svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail



xtpcse abs_ideo_med_dist labs_ideo_med_dist l2abs_ideo_med_dist l3abs_ideo_med_dist l4abs_ideo_med_dist /// 
		l5abs_ideo_med_dist l6abs_ideo_med_dist l7abs_ideo_med_dist burger  rehn  /// 
		labmch l2abmch l3abmch l4abmch l5abmch l6abmch l7abmch ///
		svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail




* This one holds promise, re: lags of ideo_doct. 
* The weird thing is that there is a positive effect on the third lag, but there IS a negative one on the 5th. 
* If I add lags of abmch, the weird thing goes away, but this effect and its lags are weird too. 
* For now, this construction seems to work. 
xtpcse ideo_med_dist  lideo_med_dist ///
lippl l2ippl l3ippl l4ippl l5ippl l6ippl l7ippl ///
	svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail

sum ideo_doct unam JCS_SCmedian lideo_doct l2ideo_doct l3ideo_doct l4ideo_doct l5ideo_doct l6ideo_doct  /// 
	svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10 


* This is a good one. Liberal signals cause future SC doctrine to be more conservative than the median. 
xtpcse ideo_doct  JCS_SCmedian  lideo_doct l2ideo_doct l3ideo_doct l4ideo_doct l5ideo_doct l6ideo_doct l7ideo_doct ///
lippl l2ippl l3ippl l4ippl l5ippl l6ippl l7ippl lippc l2ippc l3ippc l4ippc l5ippc l6ippc l7ippc ///
	svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail


xtpcse abs_ideo_med_dist years_same_court cases    ///
lipp l2ipp l3ipp l4ipp l5ipp l6ipp l7ipp  ///
	svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail



lippc l2ippc l3ippc l4ippc l5ippc l6ippc l7ippc


xtpcse ideo_med_dist  lideo_med_dist ///
lippc l2ippc l3ippc l4ippc l5ippc l6ippc l7ippc ///
	svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail


xtpcse ideo_med_dist lideo_med_dist /// 
burger  rehn    /// 
lippl l2ippl l3ippl l4ippl l5ippl l6ippl l7ippl ///
	svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail



xtpcse ideo_doct JCS_SCmedian  lideo_doct l2ideo_doct l3ideo_doct l4ideo_doct l5ideo_doct l6ideo_doct l7ideo_doct burger  rehn  /// 
		labmch l2abmch l3abmch l4abmch l5abmch l6abmch l7abmch /// 
		lJCS_SCmedian l2JCS_SCmedian l3JCS_SCmedian l4JCS_SCmedian l5JCS_SCmedian l6JCS_SCmedian l7JCS_SCmedian ///
		svalue1 svalue2 svalue3 svalue4 svalue5 svalue6  svalue7 svalue8 svalue9 svalue10  , corr (ar1) rhotype (dw) detail



